#!/usr/bin/perl
# key word to replase
#

use Getopt::Long qw(:config no_ignore_case);

$result = GetOptions(
    "h"  	    => \$opt_h,
    "s=s"	    => \$opt_s,
    "S=s"	    => \$opt_S,
    "f=s"	    => \@opt_f,
    "c=s"	    => \$opt_c,
    "C=s"	    => \@opt_C,
    "R=s"	    => \@opt_R,
    "N"  	    => \$opt_N,
    "n=s"	    => \$opt_n,
    "CA"	    => \$opt_CA,
    "r"		    => \$opt_r,
    "l=s"   	    => \$opt_l,
    "v"		    => \$opt_v,
    "t=s"           => \$opt_t,
    "F"		    => \$opt_F,
    "gui"	    => \$is_gui,
    "T=s"	    => \@opt_T,
    "TN=s"	    => \$top_name,
    "no_vendor_uvm" => \$no_vendor_uvm,
    "profile"	    => \$opt_profile,
    "mem"           => \$opt_mem,
);

if ($opt_h) {
    print "run_asim.pl -t test [options] \n";
    print "   -s vcs|mti|nc|ncx|vcs64|mti64|nc64   simulators (def: mti)\n";
    print "   -S uvm1.1                            uvm\n";
    print "   -f <file list>     		   file list for simulation\n";
    print "   -n <run seed>			   random seed(def: 1234)\n";
    print "   -N      				   do Not actually run\n";
    print "   -CA				   complie all file, do not run\n";
    print "   -r				   run simulation with pre-compiled library\n";
    print "   -l <precompiled library path>	   pre-compiled library path\n";
    print "   -F				   dump FSDB\n";
    print "   -c clean				   clean up temp files\n";
    print "Example:\n\trun_asim.pl -s mti -f \n";
    print "\trun_asim.pl -s nc -CA\n";
    print "\trun_asim.pl -s mti -r -i ../\n";
    print "\trun_asim.pl -s mti -S uvm1.1\n";

    exit (1);
}

if ($opt_c eq "clean") {
    $cmd = "rm -rf core* simv* csrc INCA* work/ vsim.wlf *.log *txt *cmd tb.f nc* ucli.key vc_hdrs.h waves.shm *dat *ucdb";
    print "Performing clean up: $cmd\n";
    system $cmd;
    exit;
}


$UVM_HOME  = $ENV{"UVM_HOME"};
$AVERY_PLI = $ENV{"AVERY_PLI"};
$is_uvm    = 1 if ($opt_S eq "uvm" || $opt_S eq "UVM" || $opt_S eq "uvm1.1" || $opt_S eq "uvm1.2" || $opt_S eq "uvm1800.2");
if ($opt_S =~ /uvm(.*)/) {
    $uvm_ver = "$1";
}
$uvm_ver = "1.1" if ($uvm_ver eq "");
$sim      =  "mti";
$sim      =  $opt_s if $opt_s;
$sim64    =  64 if ($sim =~ m/64/);
$sim      =~ s/64//;
$sim      =  "mti" if ($sim eq "ms");
check_env();

# prepare simulator options
foreach(@opt_R)  { $runtime .= " $_ ";}

$test     =  $opt_t if $opt_t;
$seed     =  ($opt_n)? $opt_n : 1234;

# prepare UVM files, ...
if ($is_uvm) {
    $files .= "### UVM ###\n";
    $files .= "+define+AVERY_UVM\n";
    $files .= "+define+UVM_REPORT_DISABLE_FILE_LINE\n";
    if ($uvm_ver ne "1.1"){
        $files .= "+define+UVM_NO_DEPRECATED\n";
    }

    if (!$no_vendor_uvm) {
	$files .= "+incdir+$UVM_HOME/src\n";
	if ($sim =~ /vcs/) {
	    $files .= "$UVM_HOME/src/uvm_pkg.sv\n";
            if ($UVM_OPTION eq "") {
                $files .= "$UVM_HOME/src/dpi/uvm_dpi.cc\n";
            }
	}
    } else {
	$files .= "\$UVM_HOME/src/uvm_pkg.sv\n";
	$files .= "+incdir+\$UVM_HOME/src\n";
	$files .= "\$UVM_HOME/src/dpi/uvm_dpi.cc\n";

	if ($sim =~ /nc/) {
	    $files .= "-uvmnocdnsextra -access rw -uvmhome \$UVM_HOME -DINCA -uvmnoautocompile\n";
	} elsif ($sim =~ /mti/ || $sim =~ /msv/) {
	    $files .= " -ccflags \"-D QUESTA\"\n";
	}
    }
}

$files .= "### FILE List ###\n";
foreach(@opt_f)  { 
    $files .= "-f $_\n";
}
$files .= "### TEST TOP ###\n";
foreach (@opt_T) {
    $files .= "$_\n";
}
$files .= "### Compile arguments ###\n";
foreach(@opt_C) {  
    $files .= "$_\n";
}

if ($opt_l eq "") { @pre_cmds = ("-f tb.f"); }
else              { @pre_cmds = ("");        }

$files .= "### Runtime arguments ###\n";
@runtime = split(" ", $runtime);

# run command
if ($sim eq "vcs" || $sim eq "vcsi") {
    # PLI
    $pli_lib = "$AVERY_PLI/lib.$os/libtb_vcs$sim64.so";
    die "$pli_lib: not found" if (! -e $pli_lib);
    $pli  = "$pli_lib -P $AVERY_PLI/tb_vcs.tab -lpthread";

    if ($opt_F) {
        $pli_lib_ext ="$VERDI_HOME/share/PLI/VCS/LINUX$sim64/pli.a";
        $pli_ext ="$pli_lib_ext -P $VERDI_HOME/share/PLI/VCS/LINUX$sim64/novas.tab -debug_pp";
    }

    if ($opt_IEEE) {
        push @pre_cmds, " -lca";
    }
    if ($is_uvm && !$opt_r && (!$no_vendor_uvm)) {
        if ($UVM_OPTION ne "") {
            push @pre_cmds, $UVM_OPTION;
        }
    }

    # profile
    push @pre_cmds, " +race=all -lca -simprofile +dmprof " if $opt_profile;
    push @runtime, " +dmprof " if $opt_profile;

    if (!$opt_r) {
	@cmds = (
	    "$sim",
	    @pre_cmds,
            "-l vcs_compile.log",
	    "-sverilog",
	    "$pli $pli_ext",
	    "+plusarg_save",
	    "+ntb_disable_cnst_null_object_warning=1",
	    "+vpi",
	    @runtime,
	    "+plusarg_ignore",
	    "+vcs+lic+wait"
	);
	if ($is_uvm) { push @cmds, "-timescale=1ps/1ps -CFLAGS -DVCS"; }
	else         { push @cmds, "+ntb_opts"; } 
	if ($sim64 eq "64") { push @cmds, "-full64"; }
	push @cmds, ";";
    }

    if (!$opt_CA) {
	$opt_l = "./" if ($opt_l eq "");
	$opt_l .= "simv";

	push @cmds, " $opt_l -l vcs.log +ntb_random_seed=$seed +vcs+lic+wait";
	push @cmds, " -cm_name $test" if ($opt_v);
	push @cmds, @runtime;
    }

} elsif ($sim eq "nc" || $sim eq "ncx") {

    if   ($sim eq "nc" ) {$nc_sim = "irun"}
    elsif($sim eq "ncx") {$nc_sim = "xrun"}

    # PLI
    $pli_lib = "$AVERY_PLI/lib.$os/libwizard$sim64.so";
    die "$pli_lib: not found" if (! -e $pli_lib);
    $pli = "+loadpli1=$pli_lib:wizard_bootstrap";
    
    if ($is_uvm && !$opt_r && (!$no_vendor_uvm)) {
        if ($UVM_OPTION ne "") {
            push @pre_cmds, $UVM_OPTION;
        } else {
            push @pre_cmds, "-uvmhome $UVM_VD_HOME";
        }
    }

    # profile
    push @pre_cmds, " -simprofile -memdetail +ncprofile" if $opt_profile;

    @cmds = (
	$nc_sim,
	@pre_cmds,
	@runtime,
	"-l nc.log",
	"-svseed $seed",
	"+nowarn_AAMNSD",
	"+nowarn_CUVIHR",
        "+access+rw",
	"$pli",
	"+sv",
	"-licq"
	);

    if ($opt_CA) {
        push @cmds, "-elaborate",
    } elsif ($opt_r) {
	if ($opt_l eq "") { push @cmds, "-R"; } 
	else              { push @cmds, "-R -xmlibdirname $opt_l/xcelium.d"; }
	#else              { push @cmds, "-R -nclibdirname $opt_l/INCA_libs"; }
    }

    if ($sim64 eq "64") { push @cmds, "+nc64bit";}
    if ($opt_v) {
	print "gen functional coverage ...\n";
	push @cmds, "-coverage U -covdut $top_name  -covworkdir cov_work -covscope scope -covtest $test -covoverwrite";
    };
    #$cmd = "ncprep -svseed $seed +ncstatus +define+AUSB_NC +nowarn+AAMNSD +nowarn+INTWID $cgroup $pli $runtime $files $test +sv -l nc.log $compile $test_top;";
    #$cmd .= "ncvlog -f ncvlog.args;";
    #$cmd .= "ncelab -f ncelab.args;";
    #$cmd .= "ncsim -f ncsim.args";

} elsif ($sim eq "mti" || $sim eq "msv") {

    # PLI
    $pli_lib = "$AVERY_PLI/lib.$os/libtb_ms$sim64.so";
    die "$pli_lib: not found" if (! -e $pli_lib);
    $pli = " -pli $pli_lib";
    # To dump fsdb in MS, Both PLI link and LD_LIBRARY_PATH setting are necerrary.
    # EX: setenv LD_LIBRARY_PATH ${VERDI_HOME}/share/PLI/MODELSIM/LINUX:
    if ($opt_F) {
        $pli_ext ="-pli $VERDI_HOME/share/PLI/MODELSIM/LINUX$sim64/novas_fli.so";
    }
    push @pre_cmds, " +define+AVERY_MTI";

    if ($is_uvm && (!$no_vendor_uvm)) {
	if (!$opt_r) {
            if ($UVM_OPTION ne "") {
                push @pre_cmds, $UVM_OPTION;
            } else {
                push @pre_cmds, "-L $UVM_VD_HOME";
            }
	}
    }

    if ($opt_CA) {
        @cmds = (
	   "vlib work;",
	   "vlog -l mti.log",
	   @pre_cmds
    	);
    } elsif ($opt_r) {
	$opt_l .= "work" ;
	
        @cmds = (
	   "vsim",
	   "-lib $opt_l",
	   "-l mti.log",
	   "-sv_seed $seed",
	   "$pli", "$pli_ext",
	   @runtime,
	   "-permit_unmatched_virtual_intf",
	   "-vopt"
	);
	push @cmds, "-c" if ($opt_g == "");
	if ($opt_v)  { push @cmds, "+cover -coverage -onfinish stop -do \"run -all; coverage report -detail -file $test.dat; coverage save -onexit $test.ucdb; exit\" ";}
	else         { push @cmds, "-do \"run -all; quit -f\"";}
	push @cmds, "$top_name";
    } else {
	# open gui
	push @gui, "-gui -visualizer -qwavedb=signal+transaction+class+memory=1024,3" if $is_gui;
	# profile
	push @runtime, " -autoprofile=mti_prof.pdb" if $opt_profile;

        if   ($sim eq "mti" ) {$q_sim = "qrun"}
        elsif($sim eq "msv")  {$q_sim = "qverilog"}

        @cmds = (
	   $q_sim,
           @gui,
	   @pre_cmds,
	   "-l mti.log",
            # assignment, use -novopt instead of -O0
            # -novopt will be removed, use -cellaccess -bitscalars -primitiveaccess
            # After version 2020.4, remove option -cellaccess
	   #"-novopt",
           "-bitscalars",
           "-primitiveaccess",
	   "-sv",
	   "-R -sv_seed $seed",
	   "$pli",
	   "$pli_ext",
	   @runtime,
	   "-permit_unmatched_virtual_intf"
    	);
	if ($opt_v) {
	    print "gen functional coverage ...\n";
	    push ( @cmds, "\"+cover bcstef \" -coverage -onfinish stop -do \"run -all; coverage report -detail -file $test.dat; coverage save -onexit -directive -cvg -codeAll $test.ucdb; exit\" ");
	};
        if ($opt_mem) {
	    print "gen memory capacity report ...\n";
            push ( @cmds, "-capacity=line \-onfinish stop -do \"run -all; capstats -du+summary+details -line -decl -filename mti_mem.txt; exit\" ");
        }
    }
    if ($sim64 eq "64") { push @cmds, "-64";}
} elsif ($sim eq "vck"){
} else {
    print "Error: unsupported simulator $sim.\n";
    exit 1;
}

# add \ and \n
foreach $t (@cmds) {
    $cmd .= "$t \\\n";
}
if (!$opt_r) {
    print "\n$files\n";
    open(FILE, ">tb.f");
    print FILE "$files\n";
    close(FILE);
}
print "\n$cmd\n";
open(CMD, ">$sim.cmd");
print CMD "$cmd\n";
close(CMD);
system $cmd if $opt_N eq "";


####################################### End Main ############################################

sub check_env()
{
    if (! -e "$AVERY_PLI") {
        die "Error: env variable \$AVERY_PLI does not point to a valid path";
    }

    if ($is_uvm) {
	if ($no_vendor_uvm && (! -e "$UVM_HOME")) {
	    die "Error: env variable \$UVM_HOME does not point to a valid path";
	} elsif (-e "$UVM_HOME") {
            $no_vendor_uvm = 1;
        } else {
            $no_vendor_uvm = 0;
            if ($sim =~ /vcs/) {
                $VCS_HOME = $ENV{"VCS_HOME"};
                if ($uvm_ver eq "1.1") {
                    $UVM_OPTION  = "-ntb_opts uvm";
                    $UVM_HOME = "$VCS_HOME/etc/uvm-1.1";
                } elsif ($uvm_ver eq "1.2") {
                    $UVM_OPTION  = "-ntb_opts uvm-1.2";
                    $UVM_HOME = "$VCS_HOME/etc/uvm-1.2";
                } else {
                    $UVM_HOME = "$VCS_HOME/etc/uvm-ieee";
                }
            } elsif ($sim =~ /mti/ || $sim =~ /ms/) {
                $MS_HOME  = $ENV{"MS_HOME"};
                if ($uvm_ver eq "1.1") {
                    $UVM_OPTION  = "-uvm";
                    $UVM_VD_HOME = "$MS_HOME/uvm-1.1d";
                    $UVM_HOME    = "$MS_HOME/verilog_src/uvm-1.1d";
                } elsif ($uvm_ver eq "1.2") {
                    $UVM_OPTION  = "-uvmhome uvm-1.2";
                    $UVM_VD_HOME = "$MS_HOME/uvm-1.2";
                    $UVM_HOME    = "$MS_HOME/verilog_src/uvm-1.2";
                } else {
                    die "\$MS_HOME did not have UVM-IEEE";
                }
            } elsif ($sim =~ /nc/) {
                $CADENCE_HOME = $ENV{"CADENCE_HOME"};
                if ($uvm_ver eq "1.1") {
                    $UVM_OPTION  = "-uvm";
                    $UVM_VD_HOME = "$CADENCE_HOME/tools/methodology/UVM/CDNS-1.1d";
                } elsif ($uvm_ver eq "1.2") {
                    $UVM_OPTION  = "-uvmhome CDNS-1.2";
                    $UVM_VD_HOME = "$CADENCE_HOME/tools/methodology/UVM/CDNS-1.2";
                } else {
                    $UVM_VD_HOME = "$CADENCE_HOME/tools/methodology/UVM/CDNS-IEEE";
                }
                $UVM_HOME = "$UVM_VD_HOME/sv";
            }
        }
    }

    # check for fsdb dump
    if ($opt_F) {
        $VERDI_HOME = $ENV{"VERDI_HOME"};
        $LD_LIBRARY_PATH = $ENV{"LD_LIBRARY_PATH"};
        if ($VERDI_HOME eq "") {
            die "ERROR: Can not find environment variable \$VERDI_HOME, please set it before turn on -F option";
        }   
        if ($LD_LIBRARY_PATH eq "" && $sim ne "vcs" && $sim ne "vcsi") {
            die "ERROR: Can not find environment variable \$LD_LIBRARY_PATH, please set it before turn on -F option";
        }   
    }

    $a = `uname`; 
    if ($a =~ /Linux/i) {
        $os = "linux";
    } elsif ($a =~ /SunOS/i) {
        $os = "sunos";
    } else { # can't get `uname
        use POSIX;
        @a = uname(); 
        if ($a[0] =~ /Linux/i) {
            $os = "linux";
        } elsif ($a[0] =~ /SunOS/i) {
            $os = "sunos";
        } else { # windows
	    $os = "";
        }
    }
}

