/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */

`ifndef avery_defines_svh
`define avery_defines_svh

`ifndef _VCP
`ifndef __FILE__
    `ifndef AVERY_NC
	`define __FILE__ `"`"
    `endif
`endif

`ifndef __LINE__
    `ifndef AVERY_NC
	`define __LINE__ 0 
    `endif
`endif
`endif

`ifndef avery_fileline
`define avery_fileline $psprintf("%s", `__LINE__ == 0 ? "" : $psprintf("@%s:%0d", `__FILE__, `__LINE__))
`endif

`ifndef avery_fline
`define avery_fline    $psprintf("%s", `__LINE__ == 0 ? "" : $psprintf("@%s:%0d", `__FILE__, `__LINE__))
`endif

`ifdef AVERY_UVM
    `define AVERY_UVM_OBJECT_UTILS(T) `uvm_object_utils(T)
    `define AVERY_NEW(T, name) T::type_id::create(name)
`else
    `define AVERY_UVM_OBJECT_UTILS(T)
    `define AVERY_NEW(T, name) new(name)
`endif

`ifdef AVERY_UVM
    `define AVERY_NEW_PARENT(T, name, parent) T::type_id::create(name, parent)
`else
    `define AVERY_NEW_PARENT(T, name, parent) new(name, parent)
`endif


`ifndef avery_xvm_parent
    `ifdef AVERY_UVM
        `define avery_xvm_parent uvm_component   parent = null
    `elsif AVERY_OVM
        `define avery_xvm_parent ovm_component   parent = null
    `elsif AVERY_VMM                        
        `define avery_xvm_parent int             parent = 0    // stream_id for VMM
    `else
        `define avery_xvm_parent avery_component parent = null
    `endif
`endif 

`ifdef AVERY_NAMED_CONSTRUCTOR
    // for UVM 1.2 requirement
    `define  avery_new_named(x) new(string name="", x)
    `define  avery_strname      string name="",
    `define  avery_new1(x)      new("", x)
    `define  avery_new2(x, y)   new("", x, y)
    `define  avery_strarg       "",
    `define  avery_namearg      name,
    `define  avery_super_new    super.new(name)
`else
    `define  avery_new_named(x) new(x)
    `define  avery_strname  
    `define  avery_new1(x)      new(x)
    `define  avery_new2(x, y)   new(x, y)
    `define  avery_strarg
    `define  avery_namearg      
    `define  avery_super_new    super.new()
`endif

`ifdef AVERY_USE_CLK_DELAY
    `define avery_pound_ns(x) \
	do begin \
	    if (int'(x/1ns) == 0)  begin \
		@(posedge avery_pkg::avery_base_clk); \
	    end else \
		repeat (x/1ns) @(posedge avery_pkg::avery_base_clk); \
	end while (0)
    `define avery_pound_us(x) \
	do begin \
	    $display("avery_pound_us(%0t)", x); \
	    if (int'(x/1us) == 0)  begin \
		@(posedge avery_pkg::avery_base_clk1k); \
	    end else \
		repeat (x/1us) @(posedge avery_pkg::avery_base_clk1k); \
	end while (0)
`else
    `define avery_pound_ns(x) #(x)
    `define avery_pound_us(x) #(x)
`endif

// Wait or die if timed out
`ifndef avery_wait_die
`define avery_wait_die(cond, timer, LOG, msg) \
    fork begin \
        fork \
            wait (cond);\
	    #timer LOG.fatal($psprintf("%0dns elapsed: %s %s", timer/1ns, msg, `avery_fileline)); \
	join_any \
        disable fork; \
    end join
`endif


// wait in background and die when timed out.
`ifndef avery_wait_die_bg
`define avery_wait_die_bg(cond, timer, LOG, msg) \
    fork begin \
        fork \
            wait (cond);\
	    #timer LOG.fatal($psprintf("%0dns elapsed: %s %s", timer/1ns, msg, `avery_fileline)); \
	join_any \
        disable fork; \
    end join_none
`endif

`ifndef avery_fork
    `define avery_fork fork begin fork
`endif

`ifndef avery_join_any
    `define avery_join_any join_any disable fork; end join
`endif


`define avery_ring_len(tail, head, DEPTH)  \
	((tail + DEPTH - head) % DEPTH)
`define avery_ring_space(tail, head, DEPTH)  \
	((head + DEPTH - tail - 1) % DEPTH)  // one less


`define avery_reg_f_m(f, n_bits, lsb, def_val, sticky, acc, rand_default, rand_sticky, rand_acc) \
    rand avery_reg_field f = new(`"f`", this, n_bits, lsb, def_val, sticky, acc, \
                                rand_default, rand_sticky, rand_acc, 1)

`ifndef avery_print_stack
    `ifdef AVERY_VCS
	`define avery_print_stack $stack()
    `elsif AVERY_NC
	`define avery_print_stack $stacktrace
    `elsif AVERY_ALDEC
         // do nothing
         `define avery_print_stack do begin end while (0)
    `else
	// not needed after MTI10.2 `define avery_print_stack do if ($test$plusargs("avery_stack")) begin avery_pkg::avery_data_base a; a.up = null; end while (0)
	`define avery_print_stack $stacktrace
    `endif
`endif

`ifndef avery_finish
    `define avery_finish do begin $fflush(); `avery_print_stack; $finish; end while (0)
`endif

// USE for register test case in avery_pkg_test or UVM 
`ifndef avery_test_reg
    `ifdef AVERY_SV_TEST_CASE
        `define avery_test_reg(T) avery_pkg_test::avy_test_registry #(T, `"T`") test_id;
    `elsif AVERY_UVM
        `define avery_test_reg(T) `uvm_component_utils(T)
    `else
        `define avery_test_reg(T) avery_pkg_test::avy_test_registry #(T, `"T`") test_id;
    `endif
`endif 

`ifndef avery_test_reg_new
    `ifdef AVERY_SV_TEST_CASE
        `define avery_test_reg_new(T) `avery_test_reg(T) \
	    function new(string name, avery_component parent = null); \
	        super.new(`"T`", parent); \
	    endfunction
    `else
        `define avery_test_reg_new(T) `avery_test_reg(T) \
	    function new(string name, `avery_xvm_parent); \
	        super.new(`"T`", parent); \
	    endfunction
    `endif
`endif 

// USE for convert MACRO string to verilog string, 
// EXP: string s = `avery_stringify(`MACRO) or `include `avery_stringify(`MACRO)
`ifndef avery_stringify
    `define avery_stringify(x) `"x`"
`endif 

// USE for register test sequence for UVM 
`ifndef avery_seq_reg
    `ifdef AVERY_UVM
        `define avery_seq_reg(T, S) \
	    `uvm_object_utils(T) \
	    `uvm_declare_p_sequencer(S)
    `else
        `define avery_seq_reg(T, S)
    `endif
`endif 



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
Rq7rYvHHNHun+noMTdvRJk5qEKKXJ+5DfLJGb8YBhj8ImHz2L1WgzixL58Xq2ds/
3YAB2lGDcEcqhkhPKSSVrIewmI9mfB4MjXy7e4PvlFpXOCYnRrECX95HKziEeB5V
8QGwa+uPEGVPFmIy8SS1lPoNCJz32Vkll9s3RJOVHAE=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
FG/Otr7rqciuLW5nAg+SLyHDcn3GtgbERKRk1maYa+5/jPUkaAhF59vIO9neFkg9
DtkOr6LtVNc6yn24QdrILg0qajc9cRlgmzdp7J/XxUgTTnub9vFJX5YRcJRYeHNR
5jb/xa8LXe8sjrGttVrOL2behur0f4hZZnpKqN3BlLg=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
o7znQExdQUPWDgtsJ5Ll43p66FTWOjDRflv3mR+BXVWEQvhrsPRnfbuf83yTQgE7
koIhVp5ntTDAmXoZGAgsEA==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
kFJ7Zn7BSk9Hz3BdsWhw6BX4SN7/RuD/88kMWFtktZZLd55jS0Q41aMQaa5Ijin3
TWFq9i08PEUMb0wkYwnfMdMwbqKyxxFq7FwL4E0+IWf4+ebpkddJi5aJZoHA6ayK
bOEQP7WMJ/Q0h81LNJnRfRSdcA5W2+1U+AH9Y4I0McTjAzGNiHA/Y6qEJb1GKBt/
7x0xUDEOMHjaqyaVG+fAw/aS7I1y5CSzNv1GNWQmDxW/Gq5h4PFqZys8TOnEGfel
o6cmV099mOJCFAj2lIq3ifHglqHsb0x+EuPm0SRnr+j+MuIGlDIbilzV7YI6ZPIR
MPbIdaU4iLTBle/Q6ZQCSQ==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
EHpfylkwjafNH6eHJevyvjtA1yv8uX2H9R5PJygMHZ5hQGVmPhChMaHD/Z8DTyDV
7vUuP7/f1F22XgqVrMDQfkLhgvm44Vonx6AoK9k9QN8HuSVeEGoseY3D1OvJXwzF
nrVfyRGNph8qHV0+L5/AEq7n59gKeG9kU8KVaeLeuTg=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
RnXvj30lKMW2Q4ZsECkTXv3eXbeYLVWs/h010oULmYfvZ8pwPhHh+lk2qFAD0SUP
tAYMtbJCxIKFUxDDQIvyKJ9x31Hgof8maHxBh58nMFrqJTaRT6WySm2ZrrsYKXxY
WIobxp7X5ITUjNmgCC45axvJONkrMWL/h6VGCGZ7cx8gOAhhkxDGEsO+4eDx88pF
dkLrPvKPj1b2nt0mwWJY1C2zAhVzMgmWRhhzDdgnLmlGrowE4Lu7WgAHIZzkHxcq
4ftWa5X6D+9LN3fEauyBYtbh0QoHvn7Yj+A7nY07gt6U7DVYlMdgKnMr6gOav05I
3oU63B7kItWNQopa8gHRiA==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
FqQhAav8dcDsOND5ttV2uBTPaJEBpskthvGN9aU1IePnXnmPGgd/VjjzLVx1bSYh
sxr7qmOOIu6aRwY7MpneIymnYYMTqkWInQGcPDCUk3XajuKRRTbf8Qi4fWNGP7VE
FprAIP9QoIzD11z1mLXXxwbHolXNhzI911rmvLveCmc5SqHym2sf9yZS6s+IoLij
r80055q2bZwFXVXCJwPaW1dAsMW6+hIr6b09i77N8CBcjpV9elmzpqDMpFZLdx+C
hhsskobz2rHtNA0ojt+0H9aEnjOLYo0NaeudWCe3dv2LTP7HHUiEKzALjLSuZO66
Xw5rin3/LwlUcjcn8z6hVA==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 5744 )
`pragma protect data_block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`pragma protect end_protected

`ifndef AVERY_MUX_DWIDTH
    `define AVERY_MUX_DWIDTH 3
`endif

`endif

// $Revision: 1.51 $

