/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2011.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
`ifndef avery_pkg_inc_svh
`define avery_pkg_inc_svh

/* 
    Types:
        avery_u8
        avery_u16
        avery_u32
        avery_u64
        avery_data_base
        avery_hash_list
        avery_ring
        avery_pure_component
        avery_component
        avery_log

    Methods:
        function int       avery_max              ( int i, int j)
        function int       avery_min              ( int i, int j)
        function bit[63:0] avery_round_to_dw      ( bit[31:0] num_bytes)
        function bit[63:0] avery_round_up         (bit[63:0] a, bit[63:0] boundary);
        function void      avery_pack_bytes       
        function void      avery_pack_bytes_arr   
        function void      avery_q2a              ( input bit[31:0] from[$], output bit[31:0] to[])
        function void      avery_dwords_to_bytes  ( bit[31:0] dq[$], output bit[7:0] bq[$])
        function void      avery_align_addr       ( input bit[63:0] addr, bit[63:0] n_bytes, output bit[63:0] out_addr, bit[63:0] n_dwords)
        function void      avery_unpack_dwords    
        function void      avery_unpack_dwords_arr
        function int       avery_get_device_id    ( )
        function int       avery_power_of_two     ( bit[63:0] v)
        function bit[63:0] avery_multiple_of      ( bit[63:0] a, bit[63:0] b)
        function int       avery_two_to_power_of  ( bit[ 7:0] v)
        function bit       avery_is_power_of_two  ( bit[63:0] v)
        function bit       avery_is_multiple      ( bit[63:0] a, bit[63:0] b)
        function bit[63:0] avery_offset_mask      ( bit[63:0] page_size)
        function bit[63:0] avery_page_mask        ( bit[63:0] page_size)
        function string    avery_print_dw_array   ( bit[31:0] da[] , int len=16, string prefix="")
        function string    avery_print_dw_q       ( bit[31:0] da[$], int len=16, string prefix="")
        function string    avery_print_bytes      ( byte b[$], string prefix="")
        function string    avery_print_u8         ( bit[7:0] b[$], string prefix="")
        function void      avery_dq_2_ba          ( ref bit[31:0] from[$], ref bit[7:0] to[]);
        function bit[31:0] avery_swap_endian      ( bit[31:0] v)
*/
/*
`include "avery_defines.svh"
`include "avery_log.sv"
`include "avery_ring.sv"
`include "avery_timer.sv"
`include "avery_param_log.sv"
`include "avery_asso_mem.sv"
`include "avery_mem_mgr.sv"
`include "avery_reg_mask.sv"
`include "avery_scoreboard.sv"
`include "avery_fifo.sv"
`include "avery_rw_data.sv"
*/

`timescale 1ps/1ps

package avery_pkg;

`ifdef AVERY_UVM
    import uvm_pkg::*;
    `include "uvm_macros.svh"
`elsif AVERY_OVM
    import ovm_pkg::*;
    `include "ovm_macros.svh"
`elsif AVERY_VMM
    `include "vmm.sv"
`endif

`ifdef AVERY_CHECK_PLI
// Check if PLI is successfully included in User's run command
const bit avery_pli_chk = $avy_pli_check();
`endif

typedef class avery_data_base;
typedef class avery_pure_component;
typedef class avery_component;
typedef class avery_rw_data;
typedef class avery_sha256;
typedef class avery_sha1;
typedef class avery_rsassa_pkcs1_v1_5_verify;
typedef class avery_aes;
typedef class avery_rsa;
typedef class avery_oaep;
typedef class avery_reed_solomon;
typedef class avery_firecode;
typedef class avery_cprm;
typedef class avery_aesgcm;
typedef class avery_cmac;
typedef class avery_aes_wrap;
typedef class avery_log;
typedef class avery_scoreboard_base;

const bit[63:0] avery_1k   = 1024;
const bit[63:0] avery_2k   = 2048;
const bit[63:0] avery_4k   = 4096;
const bit[63:0] avery_8k   = 8192;
const bit[63:0] avery_16k  = 1<<14;
const bit[63:0] avery_32k  = 1<<15;
const bit[63:0] avery_40k  = (1<<15 + 8192);
const bit[63:0] avery_64k  = 1<<16;
const bit[63:0] avery_128k = 1<<17;
const bit[63:0] avery_256k = 1<<18;
const bit[63:0] avery_512k = 1<<19;
const bit[63:0] avery_1m   = 1<<20;
const bit[63:0] avery_2m   = 1<<21;
const bit[63:0] avery_64m  = 1<<26;
const bit[63:0] avery_4g   = 64'h1<<32;
const bit[63:0] avery_8g   = 64'h1<<33;
// for different timescale, avery_pkg is 1ps
const time      avery_ps   = 1ps;
const time      avery_ns   = 1ns;
const time      avery_us   = 1us;
const time      avery_ms   = 1ms;

avery_log avery_pkg_log = new("avery_pkg_log");

bit avery_base_clk;
bit avery_base_clk1k;

typedef struct packed {
    bit[31:0] high;
    bit[31:0] low;
} avery_u64;

typedef struct packed {
    avery_u64 h;
    avery_u64 l;
} avery_u128;

typedef bit[135:0] avery_u136;
typedef bit[64:0] avery_u65;

typedef bit[32:0] avery_u33;

typedef struct packed {
    bit[15:0] high;
    bit[15:0] low;
} avery_u32;

typedef bit[23:0] avery_u24;
typedef bit[15:0] avery_u16;
typedef bit[7:0]  avery_u8;
typedef bit[1:0][7:0] avery_u8_2;

typedef struct packed {
    bit[ 3:0] h;
    bit[ 3:0] l;
} avery_u4_2;

typedef struct packed {
    bit[7:0]  h;
    bit[15:0] m;
    bit[7:0]  l;
} avery_u32_3;

typedef struct packed {
    bit [3:0][7:0] bytes;
} avery_little_endian_t;

typedef struct packed {
    bit [0:3][7:0] bytes;
} avery_big_endian_t;

typedef bit[0:3][7:0] avery_big_endian_dw;

typedef enum
{
    // MIPI Manufacturer ID for Avery Design Systems, Inc
    AMIPI_MANU_ID= 'h0318
} avery_id_e;

typedef enum
{
    AVY_DBG_general,        // general message
    AVY_DBG_detail,         // detailed trace message
    AVY_DBG_avery_reg,
    AVY_DBG_aes,	    // AES encryption
    AVY_DBG_stacktrace,
    AVY_DBG_timer
} avy_debug_e; // for avery_log only

typedef enum
{
    AVY_REG_TYP_RO,         //Read-Only register
    AVY_REG_TYP_ROS,        //Read-Only-Sticky register
    AVY_REG_TYP_ROC,        //Read-Only and Read to clear
    AVY_REG_TYP_RW,         //Rewritable
    AVY_REG_TYP_RWS,        //Rewritable-Sticky
    AVY_REG_TYP_RW1S,       //Write-1 to Set (Write-0 is ignored)
    AVY_REG_TYP_RW1C,       //Write-1 to Clear
    AVY_REG_TYP_RW1CS,      //Write-1 to Clear - Sticky
    AVY_REG_TYP_WO,         //or RW_RET_0, Rewritable but always returns 0 when read 
    AVY_REG_TYP_WC,         //write clear
    AVY_REG_TYP_RSVD,        //Reserved
    AVY_REG_TYP_MIXED // not all bits have the same type
} avy_reg_typ_e;

typedef enum
{
    AVY_chklist_id_first

} avy_chklist_id_e;

typedef enum {
    AVY_IGNORE, 
    AVY_INFO,   
    AVY_EXPECT, 
    AVY_WARNING,
    AVY_USAGE, 
    AVY_ERROR,  
    AVY_FATAL
} avery_severity;

function automatic bit[63:0] avery_max(bit[63:0] i, bit[63:0] j);
    return ((i > j) ? i : j);
endfunction

function automatic bit[63:0] avery_min(bit[63:0] i, bit[63:0] j);
    return ((i > j) ? j : i);
endfunction

function bit [`AVERY_MUX_DWIDTH - 1:0] avery_mux8_1(
    input bit [2:0] sw2,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in0= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in1= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in2= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in3= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in4= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in5= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in6= 'z,
    input logic [`AVERY_MUX_DWIDTH - 1:0] in7= 'z);
    automatic logic [`AVERY_MUX_DWIDTH - 1:0] out2= 'z;

    case (sw2)
    0: out2= in0;
    1: out2= in1;
    2: out2= in2;
    3: out2= in3;
    4: out2= in4;
    5: out2= in4;
    6: out2= in4;
    7: out2= in4;
    endcase
    return out2;
endfunction

function int avery_gcd(
    input int num2,
    input int num3);
    automatic int max2= avery_max(num2, num3);
    automatic int min2= avery_min(num2, num3);
    if (min2 == 0) return max2;
    else if (max2 % min2 == 0) return min2;
    else begin
	    int tmp2;
	do begin
	    tmp2= max2 % min2;
	    max2= min2;
	    min2= tmp2;
	end while (max2 && min2);
	return max2;
    end
endfunction

function int avery_lcm(
    input int num2, 
    input int num3);
    return (num2 * num3 / avery_gcd(num2, num3));
endfunction

function automatic bit[31:0] avery_abs(int a);
    if (a < 0)
        return -a;
    else
        return a;
endfunction

// Return bit position to the next upper dword boundary.
function avery_u32 avery_dw_boundary(avery_u32 offset);
    return (offset/32 + 1) * 32;
endfunction

// Round up to dwords
function automatic bit[31:0]  avery_round_to_dw(bit[31:0] num_bytes);
    return (num_bytes >> 2) + (num_bytes[1:0] > 0); 
endfunction

// Pack bytes into dwords. Note: the "to[$]" is flushed at beginning!!
function automatic void avery_pack_bytes(
        ref    bit[ 7:0]  from[$],
        output bit[31:0]  to[$],
        input  bit[31:0]  num_bytes    = -1,   // -1 means to the end from start_offset
        input  bit[31:0]  start_offset = 0);
    bit[31:0]  dwlen;

    dwlen = 0;
    if (num_bytes == -1)
        num_bytes = from.size() - start_offset;
    assert((num_bytes + start_offset) <= from.size())
    else begin
        $display("avery_pack_bytes:: caller error");
        $finish;
    end

    dwlen = avery_round_to_dw(num_bytes);
    for (int i= 0; i < dwlen; i ++) begin
        bit[3:0][7:0] dw;
        // workaround: Memory index truncation(start_offset)
        dw[0] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        dw[1] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        dw[2] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        dw[3] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        to.push_back(dw);
    end
endfunction

// Pack bytes into dwords array.
function automatic void avery_pack_bytes_arr(
        ref    bit[ 7:0]  from[$],
        ref    bit[31:0]  to[],
        input  bit[31:0]  num_bytes    = -1,   // -1 means to the end from start_offset
        input  bit[31:0]  start_offset = 0
    );
    bit[31:0]   dwlen;

    dwlen = 0;
    if (num_bytes == -1)
        num_bytes = from.size() - start_offset;
    assert((num_bytes + start_offset) <= from.size())
    else begin
        $display("avery_pack_bytes:: caller error");
        $finish;
    end

    dwlen = avery_round_to_dw(num_bytes);
    to = new[dwlen];
    for (int i= 0; i < dwlen; i ++) begin
        bit[3:0][7:0] dw;
        // workaround: Memory index truncation(start_offset)
        dw[0] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        dw[1] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        dw[2] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        dw[3] = (start_offset >= from.size()) ? 8'hee : from[start_offset[31:0]];  start_offset++;
        to[i] = dw;
    end
endfunction

// Queue to array for 32-bit data
function automatic void avery_q2a(ref bit[31:0] from[$], ref bit[31:0] to[]);
    to = new[from.size()];
    foreach(from[i])
        to[i] = from[i];
endfunction

// Be aware: bq is flushed first!! dq[i] is little-endian.
function automatic void avery_dwords_to_bytes(ref bit[31:0] dq[$], ref bit[7:0] bq[$]);
    bit[3:0][7:0] a;
    bq.delete();
    foreach(dq[i]) begin
        a = dq[i];
        bq.push_back(a[0]);
        bq.push_back(a[1]);
        bq.push_back(a[2]);
        bq.push_back(a[3]);
    end
    if ((dq.size * 4) != bq.size) begin
        $display("Caught a simulator bug: %0d vs %0d", dq.size * 4, bq.size); 
        `avery_finish;
    end
endfunction

// dq will be emptied first. dq[i] is little-endian.
function automatic void avery_bytes_to_dwords(ref bit[7:0] bq[$], ref bit[31:0] dq[$]);
    bit[3:0][7:0] a;
    int n = bq.size / 4;
    dq.delete();
    for (int i = 0; i < n; i++) begin
        a[0] = bq[4*i+0];
        a[1] = bq[4*i+1];
        a[2] = bq[4*i+2];
        a[3] = bq[4*i+3];
        dq.push_back(a);
    end
    // pad 0 at the end
    if (bq.size % 4) begin
	a = 0;
	a[0] = bq[n*4];
	if (bq.size > (n*4+1)) a[1] = bq[n*4+1];
	if (bq.size > (n*4+2)) a[2] = bq[n*4+2];
	dq.push_back(a);
    end
endfunction

function automatic void avery_ba2va(ref bit[7:0] ba[], ref bit[31:0] da[]);
    bit[3:0][7:0] a;
    int n = ba.size / 4;
    if (ba.size % 4) 
	da = new[n+1];
    else
	da = new[n];
    for (int i = 0; i < n; i++) begin
        a[0] = ba[4*i+0];
        a[1] = ba[4*i+1];
        a[2] = ba[4*i+2];
        a[3] = ba[4*i+3];
        da[i] = a;
    end
    // pad 0 at the end
    if (ba.size % 4) begin
	a = 0;
	a[0] = ba[n*4];
	if (ba.size > (n*4+1)) a[1] = ba[n*4+1];
	if (ba.size > (n*4+2)) a[2] = ba[n*4+2];
	da[n] = a;
    end
endfunction

// "to[$]" is flushed at beginning.
function automatic void avery_unpack_dwords(
        ref  bit[31:0]  from[$], // Queue
        ref  bit[ 7:0]  to[$]);
    bit[3:0][7:0] dw;
    to.delete();
    foreach(from[i]) begin
        dw = from[i];
        to.push_back(dw[0]);
        to.push_back(dw[1]);
        to.push_back(dw[2]);
        to.push_back(dw[3]);
    end
endfunction

// "to[$]" is flushed at beginning.
function automatic void avery_unpack_dwords_arr(
        ref  bit[31:0]  from[],  // Array
        ref  bit[ 7:0]  to[$]);
    bit[3:0][7:0] dw;
    to.delete();
    foreach(from[i]) begin
        dw = from[i];
        to.push_back(dw[0]);
        to.push_back(dw[1]);
        to.push_back(dw[2]);
        to.push_back(dw[3]);
    end
endfunction

// dword array to byte array
function automatic void avery_va2ba (
        ref  bit[31:0]  from[],  // Array
        ref  bit[ 7:0]  to[]);
    bit[3:0][7:0] dw;
    to = new[from.size * 4];
    foreach(from[i]) begin
        dw = from[i];
        to[4*i+0] = dw[0];
        to[4*i+1] = dw[1];
        to[4*i+2] = dw[2];
        to[4*i+3] = dw[3];
    end
endfunction

// see also avery_va2ba(). This one with extra byte enables.
function automatic void avery_va2ba_be(
        ref  bit[31:0]  from[],
        ref  bit[ 7:0]  to[],
        input bit[3:0]  first_be,
        input bit[3:0]  last_be
    );
    bit[7:0] bq[$];
    avery_unpack_dwords_arr(from, bq);
    casex (first_be)
        4'b???1: begin end
        4'b??10: repeat(1) bq.delete(0);
        4'b?100: repeat(2) bq.delete(0);
        4'b1000: repeat(3) bq.delete(0);
        4'b0000: repeat(4) bq.delete(0);
    endcase

    if (from.size ==  1) begin
        // single dword
        casex (first_be)
            4'b1???: begin end
            4'b01??: repeat(1) void'(bq.pop_back());
            4'b001?: repeat(2) void'(bq.pop_back());
            4'b0001: repeat(3) void'(bq.pop_back());
            4'b0000: repeat(4) void'(bq.pop_back());
        endcase
    end else if (from.size > 1) begin
        casex (last_be)
            4'b1???: begin end
            4'b01??: repeat(1) void'(bq.pop_back());
            4'b001?: repeat(2) void'(bq.pop_back());
            4'b0001: repeat(3) void'(bq.pop_back());
            4'b0000: repeat(4) void'(bq.pop_back());
        endcase
    end

    to = new[bq.size];
    foreach (to[i])
        to[i] = bq[i];
endfunction


// Return dword-aligned address and size.
function void avery_align_addr(
        input  bit[63:0] addr,     
        input  bit[63:0] n_bytes,
        output bit[63:0] out_addr,
        output bit[63:0] n_dwords
    );
    automatic bit[64:0] end_addr  = addr + n_bytes;
    out_addr = addr;
    out_addr[1:0] = 0;
    n_dwords = avery_multiple_of(end_addr - out_addr, 4);
endfunction


function automatic avery_u32 avery_get_device_id();
    static avery_u32 id_g = 0;
    id_g ++;
    return (id_g);
endfunction

function automatic avery_u32 avery_get_data_id();
    static avery_u32 data_id_g = 0;
    data_id_g ++;
    return (data_id_g);
endfunction


function automatic avery_u32 apqi_get_nvm_id();
    static avery_u32 nvm_id_g = 0;
    nvm_id_g ++;
    return (nvm_id_g);
endfunction

// Return n if it is n's power of 2; otherwise return -1 
// Can be used to detect is_power_of_2
function automatic int avery_power_of_two(bit[63:0] v); // NC bug: v >> 1 is not same
    int power2;
    power2 = 0;
    while (v > 0) begin 
        if (v[0]) begin
            if (v[63:1] != 0)
                power2 = -1;
            break;
        end else begin
            power2 ++;
            v = v >> 1;
        end 
    end
    return power2;
endfunction

// Return 1 if value is power of two.
function bit avery_is_power_of_two(bit[63:0] v);
    return avery_power_of_two(v) != -1;
endfunction

// "a" is multiple of "b" and round up.
function automatic bit[63:0] avery_multiple_of(bit[63:0] a, bit[63:0] b);
    if (b == 0) begin
        $display("%m: avery_multiple_of: b is 0");
        `avery_finish;
    end
    return (a / b) + ((a % b) > 0);
endfunction

// round "a" up to the next boundary.
function automatic bit[63:0] avery_round_up(bit[63:0] a, bit[63:0] boundary);
    if ( boundary == 0) begin
        $display("%m: avery_multiple_of: boundary is 0");
        `avery_finish;
    end
    if ((a % boundary) > 0)
       return (a / boundary) * boundary + boundary; // That is: a + boundary
    else
       return  a;
endfunction

// return the value of 2 to the power of "v"
function automatic bit[63:0] avery_two_to_power_of(bit[7:0] v);
    return (64'h1 << v);
endfunction

// return 1 if "a" is multiple of "b", else return 0
function automatic bit avery_multiple_check(bit[63:0] a, bit[63:0] b);
    $display("avery_multiple_check: is obsoleted. Use avery_is_multiple() instead");
    return avery_is_multiple(a, b);
endfunction

// return 1 if "a" is multiple of "b", else return 0
function automatic bit avery_is_multiple(bit[63:0] a, bit[63:0] b);
    if (b == 0) return 1;
    if ((a % b) == 0)
        return 1;
    else
        return 0; 
endfunction

// Return # of bytes to next page boundary. page_size should be in power of 2.
function avery_u64 avery_distance_to_page (avery_u64 page_size, avery_u64 addr);
    return page_size - (addr & (page_size - 1));
endfunction


// Return offset mask within a page.
function bit[63:0] avery_offset_mask(bit[63:0] page_size);
    return (page_size - 1);
endfunction

function bit[63:0] avery_page_mask(bit[63:0] page_size);
    return ~(page_size - 1);
endfunction

// Return the offset within a page.
function bit[63:0] avery_page_offset(bit[63:0] addr, bit[63:0] page_size);
    return addr & (page_size - 1);
endfunction

function bit[63:0] avery_page_align(bit[63:0] addr, bit[63:0] page_size);
    return addr & ~(page_size - 1);
endfunction

function bit[63:0] avery_random64 (bit[63:0] a, bit[63:0] b);
    return {$urandom_range(a[63:32], b[63:32]), $urandom_range(a[31:0], b[31:0])};
endfunction

function automatic string avery_print_dw_array(ref bit[31:0] da[], input int len=16, string prefix="", bit line_break=1);
    string s = prefix;
    if (da.size == 0)
        return "";
    foreach(da[i]) if (i < len) begin
        if (i % 16 == 0 && i)
            s = {s, "\n", prefix};
        else if (i % 8 == 0 && i)
            s = {s, "   "};
        $sformat(s, "%s %h", s, da[i]);
    end
    if (line_break)
        return {s, "\n"};
    else
        return s;
endfunction

function automatic string avery_print_dw_q(ref bit[31:0] dq[$], input int len=16, string prefix="", bit line_break=1);
    string s = prefix;
    if (dq.size == 0)
        return "";
    foreach(dq[i]) if (i < len) begin
        if (i % 16 == 0 && i)
            s = {s, "\n", prefix};
        else if (i % 8 == 0 && i)
            s = {s, "   "};
        $sformat(s, "%s %h", s, dq[i]);
    end
    if (line_break)
        return {s, "\n"};
    else
        return s;
endfunction

function automatic string avery_print_u8(ref bit[7:0] b[$], input bit[31:0] max = -1, string prefix="", bit in_dword = 0);
    string s = prefix;
    foreach(b[i]) begin
        if (i >= max)
            break;
        if (in_dword) begin
            if (i && i%16 == 0)
                s = {s, $sformatf("\n%s%h", prefix, b[i])};
            else if (i && i%4 == 0)
                s = {s, $sformatf(" %h", b[i])};
            else
                s = {s, $sformatf("%h", b[i])};
        end else begin
            if (i % 16 == 0 && i)
                s = {s, "\n", prefix};
            else if (i % 8 == 0 && i)
                s = {s, "   "};
            $sformat(s, "%s %h", s, b[i]);
        end
    end
    if (b.size > max)
        s = {s, " ......"};
    return {s, "\n"};
endfunction

function automatic string avery_print_bytes(ref byte b[$], input bit[31:0] max = -1, string prefix="", bit in_dword = 0);
    string s = prefix;
    foreach(b[i]) begin
        if (i >= max)
            break;
        if (in_dword) begin
            if (i && i%16 == 0)
                s = {s, $sformatf("\n%s%h", prefix, b[i])};
            else if (i && i%4 == 0)
                s = {s, $sformatf(" %h", b[i])};
            else
                s = {s, $sformatf("%h", b[i])};
        end else begin
            if (i % 16 == 0 && i)
                s = {s, "\n", prefix};
            else if (i % 8 == 0 && i)
                s = {s, "   "};
            $sformat(s, "%s %h", s, b[i]);
        end
    end
    if (b.size > max)
        s = {s, " ......"};
    return {s, "\n"};
endfunction

function bit[31:0] avery_swap_endian (bit[31:0] v);
    return {v[7:0], v[15:8], v[23:16], v[31:24]};
endfunction

function bit[15:0][7:0] avery_swap_endian_128 (bit[15:0][7:0] v);
    foreach (v[i])
	avery_swap_endian_128[15-i] = v[i];
endfunction


// "to[]" is deleted at beginning. dword queue to byte array
function automatic void avery_dq_2_ba(
        ref bit[31:0]  from[$],
        ref bit[ 7:0]  to[]);
    bit[3:0][7:0] dw;
    to = new[from.size * 4];
    foreach(from[i]) begin
        dw = from[i];
        to[4*i+0] = dw[0];
        to[4*i+1] = dw[1];
        to[4*i+2] = dw[2];
        to[4*i+3] = dw[3];
    end
endfunction


// --------------------- Classes -------------------------------

class avery_hash_list #(type T = int, type TKEY = int);
    T  list[$];
    T  hash[TKEY];

    function new();
    endfunction

    function void push_back(TKEY key, T v);
        if (!hash.exists(key)) begin
            list.push_back(v);
            hash[key] = v;
        end
    endfunction

    function void push_front(TKEY key, T v);
        if (!hash.exists(key)) begin
            list.push_front(v);
            hash[key] = v;
        end
    endfunction

    function T lookup(TKEY key);
        if (hash.exists(key))
            return (hash[key]);
        else
            return null;
    endfunction

    function void insert(TKEY key, T v);
        push_front(key, v);
    endfunction

    function void delete_all();
        list.delete();
        hash.delete();
    endfunction

    // This operation is expensive O(n).
    function void delete(TKEY key);
        if (hash.exists(key)) begin
            T v = hash[key];
            foreach(list[i]) begin
                if (v == list[i])
                    list.delete(i);
            end
            hash.delete(key);
        end 
    endfunction
endclass

class avery_assertion_item;
    avery_severity severity;
    string         id;
    string         description;
    int            cvg_cnt;     // # of times this assertion is triggerred
    bit            mask;
    int            fire_cnt;    // # of times this assertion is violated

    function new(avery_severity severity, string id, string des, int cvg_cnt = 0);
        this.severity    = severity;
        this.id          = id;
        this.description = des;
        this.cvg_cnt     = cvg_cnt;
        this.mask        = 0;
        this.fire_cnt    = 0;
    endfunction

    function string sprint(int verbosity = 0);
        string s;
        $sformat(s, "ID  : %s\nDesc: %s\n", id, description);
        return s;
    endfunction
endclass

// Class: avery_log_callbacks
//   This callback class is used to control how the <avery_log> object
//   reports a message.
virtual class avery_log_callbacks;

    // Function: assertion_msg_cb
    // Right after an assertion violation is detected. Use this method to lower
    // or increase the severity of an assertion.
    //
    //   is_disable - 1 to disable printing the msg
    virtual function void assertion_msg_cb(
                        input string msg,
                        inout bit is_disable,
                        ref avery_assertion_item item
                    );
        return;
    endfunction

    // Function: error_msg_cb
    // Right after an error message is encountered.
    //
    //   is_disable - 1 to disable printing the msg
    virtual function void error_msg_cb(
                        input string msg,
                        inout bit is_disable 
                    );
        return;
    endfunction

    // Function: fatal_msg_cb
    // Right after a fatal message is encountered.
    //
    //   is_disable - 1 to disable printing the msg
    virtual function void fatal_msg_cb(
                        input string msg,
                        inout bit is_disable
                    );
        return;
    endfunction

endclass

// Class: avery_user_data
//    Do not use by Avery. Shall be used by user.
//  avery_data_base has a handler for this class. User can extend this class and
//  instance the extended class, then save it to avery_data_base::user_data.
class avery_user_data;
    bit       u1;
    bit[15:0] u16;
    bit[31:0] u32;
    string    str;
endclass

// Class: avery_data_base
//   This is the base data class for all Avery's data objects.
class avery_data_base
    `ifdef AVERY_OVM
        extends ovm_sequence_item
    `elsif AVERY_UVM
        extends uvm_sequence_item
    `elsif AVERY_VMM
        extends vmm_data
    `endif
    ;
    string           name;
    int              avy_id;    // VAR: universally unique
    avery_data_base  up;        // VAR: the generic parent handle if available
    avery_data_base  down;      // VAR: the generic kid handle if available
    avery_user_data  user_data; // VAR: place holder for user data
    int              avy_id_orig = -1;
        
    // Make it const to prevent accidental overwritten.
    // Create your own log member if you need to overwrite the log.
    const static avery_log log = new("avery_data_base::log");
    avery_log  unbaselog = log;

    `ifdef AVERY_VMM
        static vmm_log vmmlog = new("avery_data_base", "class");
    `endif
    
    `ifdef AVERY_OVM
        `ovm_object_utils( avery_data_base )
    `endif           
    `ifdef AVERY_UVM
        bit blocking_item_done = 0; // 1: only send item_done() after data item is completed
        `uvm_object_utils( avery_data_base )
    `endif           

    function new(string name = "avery_data_base");
        `ifdef AVERY_VMM
            super.new(this.vmmlog);
            log.vmmlog = vmmlog;
        `endif
	`ifdef AVERY_UVM
	    super.new(name);
	`endif
        this.name = name;
        this.avy_id = avery_get_data_id();
    endfunction
        
    virtual function string sprint(int verbosity = 0, string prefix = "");
        return "";
    endfunction

    `ifdef AVERY_VMM
    function vmm_data copy(vmm_data to = null);
    `else
    function avery_data_base copy(avery_data_base to = null);
    `endif
        avery_data_base to2;
        if (to == null)
            to2 = new();
        else if (!$cast(to2, to)) begin
            log.fatal($sformatf("%M: input is not avery_data_base type"));
            return null;
        end
        to2.up          = up;
        to2.down        = down;
        to2.avy_id_orig = avy_id;
        to2.user_data   = user_data; // copy handle only
        `ifdef AVERY_VMM
            void'(super.copy(to2));
        `endif
        return to2;
    endfunction

    virtual function string sprint_user_str();
        if (user_data != null && user_data.str != "")
            return user_data.str;
        else
            return "";
    endfunction

    virtual function void replace_user_str(string msg);
        if (user_data == null)
            user_data = new();
        user_data.str = {"(", msg, ")"};
    endfunction

    virtual function void append_user_str(string msg);
        if (user_data == null)
            user_data = new();
        user_data.str = {user_data.str, "(", msg, ")"};
    endfunction

    `ifndef AVERY_UVM
    virtual function string get_name();
        return name;
    endfunction
    `endif

endclass

class avery_pure_component
    `ifdef AVERY_UVM
        extends uvm_component
    `endif
    ;

    `ifdef AVERY_UVM
        `uvm_component_utils_begin(avery_pure_component)
        `uvm_component_utils_end
    `else
        string               name;
        avery_pure_component parent;
    `endif

    int        avy_id;
    static bit _flushed = 0;

    function new(
        string name,
    `ifdef AVERY_UVM
        uvm_component        parent = null
    `else
        avery_pure_component parent = null
    `endif
        );
        `ifdef AVERY_UVM
            super.new(name, parent);
            avy_id = avery_get_device_id();
        `else
            this.name = name;
            this.parent = parent;
        `endif
    endfunction

    `ifndef AVERY_UVM
    virtual function string get_name();
        return name;
    endfunction
    `endif

endclass


// A generic driver
class avery_component
    `ifdef AVERY_VMM
        extends vmm_xactor
    `elsif AVERY_OVM
        extends ovm_driver #(avery_data_base)
        // extends ovm_component
    `elsif AVERY_UVM
        extends uvm_driver #(avery_data_base)
        // extends uvm_component
    `else
        extends avery_pure_component
    `endif
    ;

    `ifdef AVERY_OVM
        `ovm_component_utils_begin(avery_component)
        `ovm_component_utils_end
    `elsif AVERY_UVM
        `uvm_component_utils_begin(avery_component)
        `uvm_component_utils_end
    `else
        string          inst;
        avery_component parent;
    `endif

    avery_log log = avery_pkg_log; // extended class may overwrite this object
    int       avy_id;
    static bit avery_dump_all = 0;
    static bit _flushed = 0;

    function new( string   name,
                  `avery_xvm_parent);
        `ifdef AVERY_OVM
            super.new(name, parent);
        `elsif AVERY_UVM
            super.new(name, parent);
        `elsif AVERY_VMM
            super.new(name, inst, stream_id);
        `else
            super.new(name, parent);
        `endif
        this.avy_id = avery_get_device_id();
        if (avery_dump_all == 0 && $test$plusargs("avery_dump_all"))
            avery_dump_all = 1;
        /* Modelsim limitation: vsim-8385. Commented out these code:
        if (_flushed == 0) begin
            _flushed = 1;
            fork
                if ($test$plusargs("avery_flush_buf")) begin
                    forever #10us $fflush();
                end
            join_none
        end
        */
    endfunction

    `ifndef AVERY_UVM
    virtual function string get_name();
        return name;
    endfunction
    `endif

    // return 0 if there is error, 1 ok
    virtual function bit check_result( int verbosity = 0 );
        return 1;
    endfunction

    virtual task end_sim_cb(string msg = "");
        return;
    endtask

    virtual function string sprint(int verbosity = 0, string prefix = "");
        `ifdef AVERY_UVM
            return get_name();
        `else
            return name;
        `endif
    endfunction

    static int _file;
    virtual function void aprint(int file, ref string msg, input int id = 0);
        if (avery_dump_all == 0) return;
        if (_file == 0)
            _file = $fopen("avery_adb.log", "w");
        $fdisplay(_file, "\\{0x%0h:%s\\}", file, msg);
    endfunction

    virtual function void aprint_set_file(int file, string filename);
        if (avery_dump_all == 0) return;
        if (_file == 0)
            _file = $fopen("avery_adb.log", "w");
        $fdisplay(_file, "\\{0x%0h=\"%s\"\\}", file, filename);
    endfunction

endclass

// Avery queuing layer
class avery_qlayer_base extends avery_component;
    function new(string name, `avery_xvm_parent);
        super.new(name, parent);
    endfunction
endclass

class avery_mem_model #(type T = byte, type T2 = bit[63:0]);
    local string     inst_name;
    local avery_log  log;
    local T          mem [T2];

    function new(string name, avery_log log = null);
        this.inst_name = name;
        this.log = log;
        if (log == null)
            log = new("mem_model");
    endfunction

    function bit exists(T2 addr);
        int exist2;
        exist2= mem.exists(addr);
        return exist2[0];
    endfunction

    function T read(T2 addr);                                                                                                                                                                 
        if (!mem.exists(addr))
            return 'hee;
        else
            return mem[addr];
    endfunction

    function void write(T2 addr, T data2);
        mem[addr] = data2;
    endfunction

    function bit[63:0] size();
        return mem.size();
    endfunction

    function void delete(T2 addr);
        mem.delete(addr);
    endfunction

    function void delete_all();
        mem.delete();
    endfunction
endclass

class avery_seq_base extends
    `ifdef AVERY_UVM
        uvm_sequence #(avery_data_base);
    `else
        avery_data_base;
    `endif
 
    virtual task run();
    `ifdef AVERY_UVM
        `uvm_fatal("AVY_FATAL", $sformatf("%M: virtual task run() must be implemented"))
    `else
        log.fatal($sformatf("%M: virtual task run() must be implemented"));
    `endif
    endtask 
endclass

//`include "avery_log.sv"
`ifndef avery_log_sv
`define avery_log_sv

/* Extends from component so we can use hierarchical access in UVM.
 
  NOTE that a better class for this usage is avery_param_log. Please use that
  unless you have a good reason for discussion with Chilai */
class avery_log extends
    `ifdef AVERY_LOG_NOT_COMPONENT
	// To avoid limitation that uvm_component must be created during build_phase().
        // However, the string based accessed will no longer work when log is not a uvm_component: 
	//     uvm_config_db#(bit)::set(this, "env0.bfm.log*" , "enable_tl_tracker"  , 1);
        // To solution is to use API or direct access like this:
        //       env0.bfm.log.enable_tl_tracker = 1;
        //       or API if available: env0.bfm.port_set_tracker(-1, "tl", 1);
	avery_data_base; 
    `else
	avery_pure_component;
    `endif
    string name;
    string instance_name;
    string version_str;

    bit info_en  = 1;       // enable AVY_INFO  message
    bit warn_en  = 1;       // enable AVY_WARN  message
    bit exp_en   = 1;       // enable AVY_EXPECT message
    bit error_en = 1;       // enable AVY_ERROR  message
    bit fatal_en = 1;       // enable AVY_FATAL message

    static int runlog = 32'h8000_0001; // STDOUT
    `ifdef AVERY_VMM
        vmm_log vmmlog;
    `endif

    // test result         
           int      num_violations        = 0;
    static int      global_num_violations = 0; // shared by all instances
           bit      fail_flag             = 0;
    static bit      global_fail_flag      = 0;
    static bit [31:0] emu_abnormal_trigger_g= 0; // reverse a bit for an abnormal condition to trigger EMU debugger

    /* bit0 if 1, due to EDB's monitor list have some value change
       bit1 if 1, due to EDB's monitor equation is true
       bit2 if 1, IRQ at SV level */
    static bit [2:0] emu_monitor_trig_g = 0;
   
    extern function new(string name, `avery_xvm_parent);

    extern virtual function void error       (string msg = "", avery_data_base f=null);
    extern virtual function void fatal       (string msg, string msg2 = "");
    extern virtual function void info        (string msg="", int line_breaks_prefix=0)             ;
    extern virtual function void warn        (string msg="");
    extern virtual function void asst        (string idname, string msg="", avery_data_base f=null);
    extern virtual function void usage       (string msg, int is_finish=1);

    virtual function void trigger            (string idname); 
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void set_global_severity(string idname, avery_severity v) ;
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void set_severity       (string idname, avery_severity v) ;
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function bit  is_fired           (string idname );
        error($sformatf("%m: virtual method is not implemented"));
        return 0;
    endfunction // check if the assertion has been fired

    virtual function void coverage_rpt       (string filename="");
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    // Obsolete, use intern() instead. 
    virtual function void internal           (string msg, bit is_abort = 1, avery_data_base f=null);
        if (f != null)
            $fdisplay(runlog, "AVY_INTERN: %s@%0t  %s. Caused by: %s", instance_name, $time, msg, f.sprint(2));
        else
            $fdisplay(runlog, "AVY_INTERN: %s@%0t  %s", instance_name, $time, msg);
        if (is_abort) `avery_finish;
    endfunction

    // Same as internal.
    virtual function void intern (string msg, bit is_abort = 1, avery_data_base f=null);
        if (f)
            msg = $sformatf("AVY_INTERN: %s@%0t  %s. Caused by: %s", instance_name, $time, msg, f.sprint(2));
        else
            msg = $sformatf("AVY_INTERN: %s@%0t  %s", instance_name, $time, msg);
        `ifdef AVERY_UVM
            `uvm_fatal("AVY_INTERN", msg);
        `else
            $fdisplay(runlog, "%s", msg);
        `endif
        if (is_abort) `avery_finish;
    endfunction

    virtual function void debug              (string msg);
        $fdisplay(runlog, "AVY_DBG: %s@%0t  %s", instance_name, $time, msg);
    endfunction

    virtual function void spec_error(string msg);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    // scope message related
    virtual function void sdebug(string scope, string msg);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void sinfo(string scope, string msg);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void swarning(string scope, string msg);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void serror(string scope, string msg);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void susage(string scope, string msg, bit is_abort = 0);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    virtual function void sstep(string scope, string msg);
        error($sformatf("%m: virtual method is not implemented"));
    endfunction

    function void todo( string msg, int is_finish = 0);
        $fdisplay(runlog, "AVY_TODO: %s@%0t  %s", instance_name, $time, msg);
        if (is_finish)
            `avery_finish;
    endfunction

    function bit runlog_is_stdout();
        return runlog == 32'h8000_0001;
    endfunction

`ifdef AVERY_VMM
    `define AVERY_LOG_CALLBACK(T, method) `vmm_callback(T, method)
`else
    `define AVERY_LOG_CALLBACK(T, method) \
    do foreach (Q_registered_cb[i]) begin \
        T obj; \
        if ($cast(obj, Q_registered_cb[i])) obj.method; \
    end while (0); \
    do foreach (Q_registered_cb_global[i]) begin \
        T obj; \
        if ($cast(obj, Q_registered_cb_global[i])) obj.method; \
    end while (0)

    protected avery_log_callbacks Q_registered_cb[$];
    protected static avery_log_callbacks Q_registered_cb_global[$];

    function void append_callback(input avery_log_callbacks cb);
        Q_registered_cb.push_back(cb);
    endfunction
`endif



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
hIKTRIvpvwp/096ZTuhB1WB9kvGSbj5bbRmy52u5rBJOZZlksvnS37a7bkpOP4xt
LGp7OYkvPTvoGuthfFXytcctf3WF7JfI8scX6vdynOeW+aSS3WsBocS1FFCXyxLh
upvCUQujmF6370DEBdT7FYRnh7fwjY7UIc2FHnNdWgw=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
ZhKBQKmAoi/OLX0eItyp/bnhCujj9PlO9msFjALtysATwT4NTirCSTB6PaDYpHAS
uMXLdhNV7rvf7a+LE5O8XrvDAWI4YJLRqTo7EN8GseKiAKVRBf2NUuUkUVcw0YMt
9uKetMGv1vK+iuSVDbQo0y+Ya9dAvBpLwAcEr03U2Rs=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
G/59iXEItUNq1o9JIhOHkVcnw3LVBb5Z9M95yqiH7Bunyq5HkjiIQbVQmJWa8Q4Z
I6AU5P7iHJPUxOnCBblfRg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
E32sos81OAQxApVpvJtlu0bWo2wjLbnnlHG6uhymWP03RqAOIptVO5Y9W8GYh9Pp
yz1yCMT2iJLRTP5Dnbhuh2w6huzaAdoVEI5SW9cLYUMbF8UaLARmblrudBn82btS
EQ2k2F6qHCDFqcHRjFDDWIwfZjjjsTt1dUEB7vOzbeXD8iANCd2QqV/es3t6UNs7
F/u6vOoGFrghuGtmX25B8PmX/cBtgf8GUrQ/YyvdUGX7mLjH9oq4uM35SLGh4+kI
4KW1BZuhaBiJiyqPN/dCEJ1XQsuwHWjmhMnwKhcRWT7NWQqqnNP+UlM3WdVlKZtk
1pFpGa8Yvyl3NQNLpwmCIQ==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
w+I+wrN2E9AMRQOCeHnjDdEUi+KkN4yNMxoApwkqcdicTYwgCcJZu29RFfFqeboh
lkjFps5WtVuuDD8AiGEOSZddWo3PTnFJGSIchYJ4+Rr5igwx2W3ftYpDo9qezaxA
rcCuqMxSYg8dLRmjPG/fbiVZDmt9UTitBF80qnyMQDk=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
gaqXZqkPZZWb9dm40p28uwYkM6pq5PdZ9Otg140AEsoG9NmwPnA9T0LDQHc13nHX
GG7NDn8C5L1f2HEYeBYfNEqB87VOXYKrbdOvEBTWoFvDTzkXqN0OJguuEfG/LjgT
wZJhB/XYMBF/FGkFTX/0rRVAL2s5Y5DnOCyqerhwM7cB2BKvL3TUGxzHKIwIfxJh
smDdEiU6rmRwLvSmbvg6ouLw+//uHm3ydHb+11QE5cYwGvWilZ/Nn1ipFHWORd1U
F4/dAlNixBxiPxVDg2zBPh/8pUUu7iklPDEvd0u9i3SxeO0AqHfzD7zFyMZvsV3v
BAm3i6lBSPVDDWre2dbyZA==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
m4ybY2GbbxoAj2HsJz32ZI76LHCzJtdS8NXuUAzlOqphPRrCyk9CLkA9a0HhynmL
IAmAIzyPczlYwgTIo/oD8Uub+8bp/EQGDlmKq/YLfp6FPutMpi6934rP8W3i7Mlt
pPiz0MWdd8aSTeG7Oi2fAaXZnvPiUMbi+XXH7j/xbfM1CgiKcehKzSc4xu0Q+VYA
ZGZQSHaTGHoSwyFSwcWsUlifPmMb0ChLqbo8eFNUfTxcty8Lbubx8NBmT6BmgGnH
Wwg/5D9X74p0ojKb0RjNswJkXzfmz0ZR/Jy1PIzm6qKvEMVIUMRjJqUiIXvAYi1W
9fXi3WTRAy7pggpg00LgIw==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 6096 )
`pragma protect data_block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`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
X7dysCAkFOU3CGo/KtvbwQ2KQKsvv/Y/QSj1GEFQbEZdyMVzKg04OhMAdBWRiNf6
ehM2d+CwVcdJFzg3MwvU2dYb+ftQ2dF8nXe2LaWvgj+2hx0po/CBmSEedAV7aci3
LRCvwLCWPOx/BTi9wqfjMKfZKozLtPqoxqOyUeivrj4=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
DPly7OvaM6VThazJ9KKeDQHjY12Kpd8ud5rHapZN6ZQatCpCFeRd3qyIqzrlJ7vt
VDobfNKl6G9WrbWevq1H/CufhkSTmsU1vwNxkDOJQvU5v3FQn0om4nMqT3SoaeG3
aWtAPao4fbsJhoRhOZ3/hlS6Jtr/QfvEYzuLhkNoBsU=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
W+OiqHnV7H7+19jENrzoAy3uGGOdGL04NnwBkVIX0wYV345A5Rel5Ok/PPUKTsX2
awkYnx86ayHBDmUv4HtNvw==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
RIDAMRGlY7a3q55XuosrRu7augJegBTEgAbGxGAGRwGD3M8o7JjRbd2n7qjJ4R49
/1s4aeYUWjmqKDZPG0+bgsg6sP8c752sy5VQWVHI5EkTyQLrQ8fZtbYJ4nenq2MU
hHmNyqYsOH0OowMbExOycukNKTjNBE6fWEUjQqZlIWzaR2hJTJN8Z7oLw/7EMFGC
cxofZxcvod/IssNITAEbhSasW0UitLUH550qyIm317ZSczaEpsJRikrrsPSu0UZH
q8zMXXjt7h9eSxuJ8LPSUWTBzuRqPZwHOHaL1fOFsmNFxoi6G45Tx8mIiX/rlstH
Z+grQ05UDZT/alrhRLzC7g==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
z0+8BIcyw/eRdvM4ng97+AX39kHPZcNnoymk5bTX2qaIJ1Oe+rRTe7DCFLoEqDhZ
xXatcNsstStd7UDAPGpx7IaP1KzVrpIGWPZTzWDqXqXA8swKxZlkFLv2UztkjQZF
Q4Cu3+Jz+FHbJ4PnRyXj3UkDcSgv/8KRXLC9il9GUvc=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
QD/2+zmlIiCHIHq7KmtIq9mIbDMKhoU/IcoRq9w4OLWETzXjnEggKrOnLn8oM3hY
z9YMi6gZdWSLK6SBiQgwFr5tk8KYD3g5jOmOcFSGN0Z/I97O/VFv/beXG8YsKnpZ
WKM4qoPZD7qpxeY64Fb9qCvFoggBm9nfO8c4lG4/Oj1xeQoZPm7vcvj8iR90kgZU
lLpvkO3dtHNLKKfr9qoRVeTzz4JEpZDDgHvP2B9NulM03AOzgVGBjEYbFEl4IUx7
3xQP2H2rH58e9HKRo1pYb3F4a8edXgeIlVRtWpAMOzynbPSQTk765ziZViuV6e/J
/bxfAIH6N5PYUGZr9rErAw==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
lYYPJOM6m1mLmq6GwnKwOa61PFJFfl1fJkHiGGneOKdWPDu62LrMwkaCnef8kAhZ
+TbJ2ca8moxSkbRQ5LQLOMDFN9/RHbOozRPlIR0zlJROHw+BSx7XBY+c5C/pncgb
xK8jpRO8N+A+Kic6cYnu0ZXFvkaltoLPr62Vr3hKBKlQpV51h/p6AiDQEXEKjIvQ
KfkOYFPIJw+a2V6eNEtQhliFMlVNIsf84oGlfROQDiWXXdMIXf8QrE1ejAmvUBQK
zeKDqestEsizfm7jsbpi5O3Z1jnLmjFTi4fCPXPoLtRK+3Ga2zR8PDdSqpEPhOQI
ml9fVUY5lKM0/CJOH1t0uQ==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 3632 )
`pragma protect data_block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`pragma protect end_protected

`endif



// `include "avery_ring.sv"
`ifndef avery_ring_sv
`define avery_ring_sv
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
/* A ring is a circular queue using head and tail pointer.
   A ring is full when tail is 1 less then head.
   A ring is empty when head and tail is the same.
   Head point is consumer pointer.
   Tail point is producer pointer.
   APIs:
        delete
        delete_all
        get_base_addr
        get_entry_size            : in bytes
        get_qsize
        get_tail/get_pi           : return the head pointer (or index)
        get_head/get_ci           : return the tail pointer (or index)
        get_tail_addr/get_ci_addr : return the memory address of the head pointing to
        get_head_addr/get_pi_addr : return the memory address of the head pointing to
        head_diff
        tail_diff
        is_empty
        is_full
        peek                      : read next valid entry, not dequeued
        pop
        push
        size                        same as num_entries
        num_entries:                number of valid entries
        num_unused_entries
        wait_free_space
        wait_size
        sprint
        is_wrap

        
*/
class avery_ring #(type T = bit[63:0]) extends avery_data_base;
    int       id;
    bit[63:0] base;  // base address that this ring sits in the system memory
    int       qsize; // number of the total entries
    T         Q[$];

    extern function new(int id, int qsize, int entry_size, bit[63:0] base = 0);

    // Try to get the next entry pointed by head.
    // Return null if empty.
    extern virtual function T peek();

    // Pop out the next entry pointed by head
    // NC limitation: extern virtual function T pop();

    extern virtual function void push (T v);

    // same as num_entries
    extern virtual function int size();

    extern virtual function int num_entries();

    // number of unused entries
    extern virtual function int num_unused_entries();

    // Delete the i'th entry.
    extern virtual function void delete(int i);

    extern virtual function void delete_all();

    // NVM spec 1.c 4.1.2 p42: The queue is Full when the Head equals one
    // more than the Tail. The number of entries in a queue when
    // full is one less than the queue size.
    extern virtual function bit is_full();

    // 4.1.1 The queue is Empty when the Head entry pointer
    // equals the Tail entry pointer.
    extern virtual function bit is_empty();

    // return 1 if need to wrap around, and output the number of entries
    // need to be wrapped around.
    extern virtual function bit is_wrap(input int total, output int num_wrapped);

    extern virtual function int get_qsize();

    // in bytes
    extern virtual function int get_entry_size();

    extern virtual function int get_entry_size_dw();

    // the tail pointer (index of which entry)
    extern virtual function bit[63:0] get_tail();
    extern virtual function bit[63:0] get_pi();

    // the head pointer (index of which entry)
    extern virtual function bit[63:0] get_head();
    extern virtual function bit[63:0] get_ci();

    // the memory address of the tail pointing to
    extern virtual function bit[63:0] get_tail_addr();
    extern virtual function bit[63:0] get_pi_addr();

    // the memory address of the head pointing to
    extern virtual function bit[63:0] get_head_addr();
    extern virtual function bit[63:0] get_ci_addr();

    extern virtual function bit[63:0] get_base_addr();

    extern virtual task wait_free_space(int num_free_entries = 1);

    extern virtual task wait_size(int num_entries = 0);

    // Pass in an newer header pointer and calculate what's difference.
    // This is used to check if the new_head is indeed valid.
    extern virtual function int head_diff(int new_head);

    extern virtual function int tail_diff(int new_tail);

    extern virtual function int pointer_diff();

    extern virtual function string sprint(int verbosity = 0, string prefix="");

    // Pop out the next entry pointed by head
    function T pop();


`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
JgMkDsTWjeSS5j8ch783ZfpJSr1j6w73uNdboG2tl2PzeaRm/KcvYy+uinl+mfw/
Hvd5gUlddBHnQNYGrEO7iq8zwfVn/0OpkgjdvT1BEqdU4cW/4ZannU6tlMEBF533
1gLZlhDiMfrAqpztFSw7PJR1jU9s9G/ZIkWVrDjvtPs=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
K9Ce6zy+0QI5Z3czOHMpGMQ9qm974tu4fg6jLMpfM49ZrCJ08SlbuDkoaepfi2ck
03AJH2hmSQiFRVMED68sUBFr7ZILJ0eStU4b+kRmV7oeccR5PP9MUgCj3QbCHjV3
HPGcJVUOqrEUtmDt4UlOUu1McAb+GfYvUeLEwxNgpKs=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
oWFU6TUzFP/MbskmmpmNNdyTuI17at/EhIgEzVI1catgA7/2/PEmrxbyVerb/SPl
wRwbKyrBYJrwOFK6AEjG/A==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
y4kFRfte+aNsEtVoD0M6JHyGwBI2+Qj/mRIGgirYgsIi4YWCOg6WyBka78qKr7Vc
WO9LSpK35T3U7TJaBfx2yDs35lXU640PEHNNGPmvR6ofW+M77uIe3USgmT0kcsHK
SznMOCvI/UVbX8t9M9aNuS5U51Pof5UPX/XdSAvay7C3dW8ClbhdLXUOwR6ZFKzu
i0IGx5osTSd7uNldcXPVCdYvVxrqfWJC0rSehmHjS74Ugr10Gp7K6lBoyWTAjFbL
q3/rfgVUjTA2BFl+f2di6KB9etF/gLBduTX0YlmmDrGw9SKWMkHCNWvo4sIlTfPe
v6MQ1V7UGG0gA/9GQxIjuA==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
yRu+BdDbtk2UcxQnhVrEC7I9P9QnGbTMFh7D7k5uQCe0G1/idr9knVPnEMAnnI4u
N4ivZ5l2IQYNbhJdB8mJUskN5DSD72CJWxqN4FKicHHrqxnK6G0zF+KE6n8hZuKw
aCI0nVLMUI8RER3NpV1y8EjLdGG5oLaYO+Ce2PFDOhc=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
LcaXOEgcWwOreq0+CUW1u1i+EleJIw3oE8i/JhxNglWgO2XhOdsPolUHxNbLKFcP
eGRNe9hcmbkR4oWCa7tRbfXkuASO8deRAYjNuW0aBSole/O1g8RKmAWqXOtUZPAx
T1iPRattyizYpSFYmxon+CFxZ0l9IfY/MTK5TvzFt47NEiWAJOZDOLDiiQxZEjSV
ulEDR2hfK6NMF9hHezW3srX4kxpmEIQYWBUFPCQiUiCBkU7lijHLhSXSE/nF/pf9
OoEdug+yps8gFOh8Yk0rP3sH0ys4P1FcvG47jUdcISVEyB13XH3oStI1NInTQvlq
53JINHgIBMSi/foNMHFCLQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
KquD4WKgzfUUk2c83g+/wGVMDcYWS8PbwTh8ISEgyNpG6Ng1E1jvorK/ich8y5lb
YxBzmDnunkXINdFM+adPMryaNh+cR997d18+QexkmBolM9GDt1NrP5xRi3QYBwJ/
dEqdQOjtw5anNaUY+VWVBvcUsM3Ezvs7ln8NG3MSAUm+kHVDyjKV+51JEP2yKfj3
9LWM9BKfRYOtk0p0y3po4ElQ8H+WUBsY3HIHGLjiU81wU3cZ2BCpH99swx/4qlnt
nVH+4PFtH7uZ1LAC2fD8MgE5XvL6BiPe/hhBJm3sr+j0red0NlERpuHwJq87ZglM
79AY4D8HRFyljYl+s5MHMQ==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 384 )
`pragma protect data_block
/ou2Ru6CCw7FRn0kweqH/pEPPcDPkhbb+Oqj33kaevGxr1txeb9CSMBvw1nm/DIM
/P4fODSygenNbz2Z5cxBZa5tiZXyGSE9cGaAxG4AnNa1Xl/dozLT/ZQKItIiRc6u
fMNTQO+NnIXV37idez3zWMYUt8IQP98PcWCjT8kNaVoQUuhvi3WZcKtWxf24zRdc
rE8v2gxpMCW8eQkLRbgc/YM0ABtScjjlpSntIsBWYV1EJYFkzv9JqVfDw82p/le2
Z2YzoyJpWPimUsJcV/4EiwFhdI8+7YDjeWcrIpY172jy9oeY+BanIv4WHWj8Gi/r
SpZYulkGIuRfeHJbvlA1sSS5WJCGngGA7kIyk2qLaFg/mtgIKHdU7csJl1OLm3vB
zKOb5Ljn+n7CqIlSud0EcKNC1x2kOtmnUDTitEebF/CVFwkOi+KAlgiJEDtIhHtS
XxNPNQA3YwqNMUJScCRWRqtIwqnQwZ6WWS/IZd3fJmjafR0xNz1eEN5bXR+B8+mW

`pragma protect end_protected
    endfunction



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
R5hpOBRwkWvHH5SeNh4ztTp8itlZ5OniHErjEdNLwzHRsJWbtsAz/rgITJ7j11+M
A9OxeOyJT0glbB1eMC1I/cv9jIrsC0FGKEsjcG8kxSOMlli5/9C8ZKpBKc9oOGOH
bqg0gm2myekjDEim3AjJBOlekzA7zolrkQfj+aAVPBM=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
TbVgY50N1ZtXMoDbUSf100llkbZPH20zr5xvfjtF25PXqNggCfiZQPqptLVCmJBA
USBA8x/8Ao3KjZfrIItSV5EFvlnht48dEdYI1f/JCOmqCqihZ+zE6yYECf2S53Qh
Z9R/gxf8zS0uuZgncLdD4dAXKqjZnR7R15zQpZNG9eg=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
WIzWZsuy0yiecd3ibfxBchQ5c8rewoLg+jCq69yDxvgvV7m5dLvJ2AN/Rp++P8al
FaQTp0IrJWvRrv/+pa52rA==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
LkiV1CkdVltBsvLvrn4V2vCtTKJE/w2OBhfj4BfA2cdeaa+TIFx7163co/zVmius
JDZnVG+UcXXS4chAs9rKirG2Ay0L6yPpE8KQxq8jXfzFYPq4E+gip5f9fb+MFNsA
jBSmchyIP6Upg9J6tseFCAoNSgxdwVYr14oWsdLr/xMm02n8HpbuhUEZ6RRlRajZ
XoD24ezpNBbCVidz93Gl3Ic0fFJ/MA3jGo8mV6gdmqpMTJQk6u1p+nUzww7bAVNj
m1mxc7FLEpGXFp/6xk/FTwCgkDpZXRL7eYuq6F2fXu0MxTwMK/cR2Xa1oCImOcIH
qLP/CEYAjPQ6LKMzB5kTFA==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
rA7Z+Y2U3cevEAJl89gbcj0wtErMIxQ8mtqqHcmvi/dSNbE0oojetAXCns5wb/4Q
7Tu97yx/qyi0Zw+LL5+JTTCtkVBSYDmpUNFxs03aOhP4Znl8TY5R4nL462MGJ9M1
LUqIOCJivlRf7CNGaHWsf8vwaNX9o8E4A+jBiQZrwDU=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
tZs6Wd/iBdIsaoux6nklWDicu3aYzBp38AYHzrovcRQMqG4JRZEzAuZ1cGOVNnlE
HjW4Gt9HUIYe73kmJ3TEP3AJnFuOivrynTyD2X7XcT2S7vuK+3sfKSWK8+tm5ht8
aQ5zSQb8c4ocGrqg+URc0rNx8EoP3/3cXQ8L2HVl67Ssjqsghy1bTZSDIC4O5tRn
4xu/thw07nJSR03jC5Qk9sD4DFwLnRCNR5WN5XPxHfKFFwiMFm9DQ93L9lVj6JUN
ypulGvHp0oiCmpvQKn77Pk/1KHZd6/d4WOI3LDYA79TXQi/+1AC2pdvopediV1fl
ejo12lkxh4NqpAzavY/jsg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
WLqUcy/cVkZ/nlUUMwjnpKnA1d5f6Q8oJGow02rNT/wsH+dXJqmvqygA5fL2qcmX
5TiaPKCqqrpEaJX+zoUGtJbCbEe9hd8R+f9H8EZT4NCAOqz5MDRzqGAgSB16ioFy
kbMzjkfpX4w2qjMU778jBgksl22BneN7iE2YEWl6J6ox3uwTOQAOzaZtcWOBUph+
VLToswOB9kLXQtuoB3Ne80lj6NklOBxYsg/plPJP/MO/v9VXLvgDmtGI012MvMex
twIRRtmIFGG5bnBHj9HyEGhq7neTCN4poRSZRwXouhqPqyXWrjxa5USGMpTW/K4y
/8PfaRY+d3mRjrvP5lWt1g==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 1360 )
`pragma protect data_block
/ou2Ru6CCw7FRn0kweqH/pEPPcDPkhbb+Oqj33kaevGxr1txeb9CSMBvw1nm/DIM
JcxrkE1QlUlegzRzF5+ISwmK1aNYshBwfwK+f76O+3/oMMLCgFpRDfnEeuLvfka5
mrZeevspuslBvv+gXIjHyNct677A4PXhPW0DbsJGpZED4qQBqJcvfY6lEK2QOc5W
nK0QgQxBxiFRca2RQBr9wdja0lst3UNvxSK5wShxNf4gs9GR3l/LZLhh7lNi0NX1
wzB8WQ1Mj2ocaUX/AYpdKB1/8EEQ8O+/elmKAcFFqQvEZcpU4+G0zQ6IEZPlTv9O
47Rfeltg2Jk+wdHRF4FF/QMF6lh02qNFCZkWXomhtA8iEc9anw7l4orqraPDDY72
jh//fi0Iuz+oOziodDwMZg9gwppPttvfpznx1QeB/f1rWKWh6nY1+3iFBloN2+cb
Gg6SJwBRDSeojP+BxkSEw6Oejr1TuV4tepzJYi01jCFgpbO7Ikf/FYa4h6wsLXWX
3LdAAmT7ghkEShmTe2B3aK08tlvOC38MLChZ+RwhhJB/eEEHSC1+D8KdOxZol0NO
PBMrxXAc36UhpkEapeksj4hCPL2QA+/5rkJsjE2SqEdwqwOrRZ/L6QxpmOfjPK3+
P2RQyrUwabXAvpNyqRZidvk3VAuBa3hGnhbwATWHVZbKUEdQaGvMRR/p7MDQtNmm
HGH1w7lSooM1fi2y88lrllBogJgVKLLaPnSZGbESvjl5HvMC2KUlKqFx0pEP4fBp
79k/nfr4rkLlh2xqKL7zcAcArBUomPC6iAW0ZQx02R0PlsG6cyogjt1UCAj5YP6P
po0B/sXLdAgKjwH4z/iEss2QnmO3exUeiGgNAYI6yoosgvQLz106+WEWpPi2lIBB
rlviSpIVRjqIrIe3AWviszF3nYyQBmpssjDIfIC3b8XQnDoqwoKBFYu3Kr/i5Ibt
POv/h8t00Ev6+IHdiw3B7aQkkY966M9xjBkc8ZdfZmtbG8EvzvpM4luiapDB/Q3z
3rLIJYtW07fJPt2kA99tB1f+IJiXXk4Ek/WW+jlN7kBtSwUQHJ9FAhVFqSF+QS9e
ry8BJp1gBQx+0UhMfBCljEEu23r7SzXVbIR8FXmHc3Dway78FQzSHfHB9NIjCIOJ
iJdtNLNeDdGAY9HhFGTl11G5Ivk1aCbteaQqNg6asecda+wI1egUGdqk9XJCfFZP
GUmLuShlQSz+oCqX4aWEKWJt64QaP0iYehgzZejlnyUZlQLi0R39gzgvA9vyaVuD
gMfqctogHzu4xR2Ysa3AoAj2SNmN7FdruTUU8lOAPVtOX4Uaoqa8VM3NR6Zz6O8X
ld78AT1nRM6hVQY2alEtoumqTzBT5LaYm7fnBOH417lkGpjs2+OaZFyV+SpnFekb
jM5PBSxmJ13dvqnvSz4X6VCzcOMafAeDBeybozO/wo1gMgq2IT4tiA2iBdmDNvkg
G1Q5JRkXtUYOv6nSm71hl+p0ZUh09VYjFy3ntus7XWSGUjBXGrsLXTgmyHJlO6f+
1+efXAykSHweuA+gMVIYwbQBINuVsKLk2+JmS02sMSzNQVLriQZp2/AOJUzqdMCu
URbD8M2krRgyngSi3YIR9dYXPTD8M2yiMkITMPBGCckswR0qEEOrYNa46DjamSVN
2oNgruW/1R283aLhDCmRnGDEClaAMyYfNUtJlZO2vbKdU41kHZ78i+JCQGhliIbu
VNL+B4ueQpC9tvHtNePQykD2n9uJetFpPTbsIiaITkEv1cB+MjuQJWvmwFmTllcN
q8EVjeVlNZipWAc2MabbbQ==

`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
cc49Mwj0kplvyoGhw4atIJo2oD5SMjztX55PR41awHvHayeTvjSPYWBFVIXL3+Wr
rXw8bU+u/zr8obsoKBWa+V0ROEALDoI0kCLo/TNzVfWSYhUTyKFPmMwC1hPg2uSl
Xtwda6esngcTuwq8iXarRsevtAZXidfCVoeuZhHiM4o=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
Az9DFJI2mq6LyuC1NBoTH3Laj//KjRSWAWO+uBI8PHat9ORfeOu+M9STrHGblri+
RR/UZxd09wo4Yk+2+Hzq1fNVGPMCb3pYLiHvfZvTQZk57NVU2amzWotxv24tugFZ
qlAivIml//k6+bDZ8tG58tzV+6G2X2reuI/K12KheWc=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
FrzcTYkVKsRkuOf4M/HStrpxjc0m8bnvlxW8OXpMtQJ0g3ItKn+trggWo5tCnqPh
IYFXM0nviXaXnSnub1VM0g==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
l9oZfoAbgXe+rmCRoMmhvjFVV8bkiDhj+++gV0FPQRDgV74z/yZ/BKlYhEmX86CN
IvOeRWpQSx0nPB1nu66EH+VeeASyjNgKuBCufxdlynDa4ZGgBHm2rRno0glYWvZz
xEpECORAl6qfeixUZymxpLAEtTYjNPLewDzhIZXvB+KXh+RLU4N8hyByd/EAvKUv
jJUSJR7sIK/MrYSDaTcyHH0NZKhLMpR2B5rCp9ZVm9meeV+kosi6xaMQD6H4tu/l
UXCN4LlWyRmIh3q7cDZHkwxEqhDG9osnOi88TcghY5Lq9ZmQ4FKXWQLXRLm0YomY
aU0fwCLfUeqIk3OEYcMwxA==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
tQQRyWNH+SpdRoXOo8gxXwUSPURQUoPBdB/PkKqkOgedAXjOOmCVckG+oiJg6P5s
szwSi1f5VWDLMC2EF1qjGiqQ1IFvoCtSYZm0yvhbrbWvw7HdOHwGl8f96/Y6MGDj
QocXE2ievPReocHx9obSH8dn3/pOW5UccqRGkHmz+Ig=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
RzEiqXwoZAdBhZUebE+NCYa4DahqpVzlO4IgJjBcL/7o3LE9OJu7T68b72FB1zM9
VlrVvHGbhyz7HgHitmQWKQNGRezAxwnbwNouAt3eZkLY7+AxNibLfpHpeOm9msoh
PxbilHoP6dyUeB074nhmvWSEX0u6aDvLDelKCp+ZvzIeEEukHxD7V6iXWMbOhtrm
7735Yni4TQA4PjRpTuvDzzPCqL4ui6RmtZNCf/e+mPGZCOGhBilRFDYC/kMeo6Qp
2owm7vgaKnq0Ikki7EsFOR3KQTZKFpFUh+0087k7YHxAMp/MUxYfEmcA9ZEEkpmK
JQm+gJl70Qh2+2fvksA1Vw==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
cjfSJbTZeIXna7CsENDrhTt4Y+C/9aPoVBIFacJiiriTgon51ulPXPrfFzUMDnwj
0wzhCuPW+lsxMCgKwKdDk+TMdFhB8F6Cbv6YqRYjguu4NZWaVHW1DcVYh0lRSaCc
WUjBRnUpp5wABqlcZuWrfgj+dx+muJ61/OQjIhL30Ax3T8Gjca1JIBeT7gCFl/bq
TJmlVbx/+2DOuBwoRigzX9k28bo7eJzfiivVMe4KJQYn5YK2Wu5NtWJ/GYb+FoNh
7Mguafk3dMM9jRyvs/a7XrvODUhPz5FQdSYqRsGhHCLUS+ZzBjc6AAle25hXwOHH
AEY7dt9Ck84f/OQ4romG5Q==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 4736 )
`pragma protect data_block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`pragma protect end_protected


`endif
// `include "avery_timer.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2009.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */

`ifndef avery_timer_sv
`define avery_timer_sv

class avery_timer;

    bit  is_timed_out     = 0; // timer timed out flag
    bit  is_min_timed_out = 0; // mininum timer timed out flag

    extern function new(
            avery_log  log = null, 
            time       timeout,         // time unit is determined by timescale. If min/max is used, it's the maximum timeout value
            time       min_timeout = 0, // minimum timeout value, use 0 to disable it
            string     msg = "",
            bit        is_fatal = 0
        );

    extern virtual task          start();
    extern virtual task          restart();
    extern virtual task          stop();
    extern virtual function void set_timeout(time t); // change to a new timeout value
    extern virtual function void set_min_timeout(time t); // change to a new timeout value



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
flZL1pu4Aj8ddE3EFWO2w5E24TnIQfm3A3M44XsDXq+OFu6Cfs1rCzhSUTSNTARp
T1OhmfVCUCMCuf4nRIp6R/+N6jCwUAl41nJSpFvmbqimgfW/X/1G193XmpQ8h824
Z9BtVVBPxSM+qM35Lod5fIv22qN4rwUxbT0j+HBvBjs=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
cKgvdm7gSmFLras/lftLX8vt85GVkTaKFIJMHVL1ht3GvyPXoun6fvr4iV/f59Qh
Q+mkGn/gRSpMYuOThsrrgBsWyyqi9vuz92+W0nniAEVgU7I3c4tH//oqUuqOH5gi
5v3CyZcham39xGrh4NZaFmzhhYP3ZFaiP2TyzTILDK8=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
OhJLi3zwHdfclIgJ7Eo7LXDxbMKFhWN0WrdKJ6nKcEshaPgfZAxB0JOGLwNt/WVI
mMIo+QKbnuxNQOqfw7tKcA==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
EJmvjzG5oPqvLRTacmCXJe5MN4dB2XWV3tFYD1B12zzOn1ds5EGl+1yNhUqXuh/o
mK2zZ+ml+h+e7Ao5Q8GXtWDIM4cm6CITcFMx0nP4wAFw/hH0H6DIOS03XHcySk4m
+rUUxiBRPeAoQpeIXWpV0fMQLvBw0a2fl3b2AAaBHzGy4OTRdZZ809/uIfVikUy0
TS/X4TbPuA4fP5YN8qfaXvC8nBOcX0aF4ezBgfHB/JsYBV/I4flgYn0cC1HBF+mJ
cIAteFfG9ou8tnJbFYzAV/AXY2WUXSzekgrT0H2/s90WEndXvrp+z1qHh9j8Mqe2
Q76zx15mdrN5TL2YnhiyTQ==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
NxQa3P2Y5WM/9QHD0oQEnmO90/m0J8mftECtWTWkVeoBuTXFxzzmOHCGqq0MQP6z
cNbwN2opYDcVK8Gim1M59wNl3KlnPYxfeZiZWihSlv5Xo1cjhokZfEdpqAkWE4WO
/1S+S949El/A6OfmFgtkHEkNtskcHQ776fpuE18YTbI=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
C/7XmPJ2aKZCHUSdMBtropF6aR9Dq63xCSByezxLYjfh2rPNoqlhdPDhBFgmcTtp
tfn+GWEq3JOTXOWu05Qur9BmtnUD/1boqyaub4qBL1/2OB75MDQ/Bp4IdYzkpb9L
K9P8QprFT8sXLNlFileH4VQzqsF1d1fDpy6JbATDrmGapcVNNzFc5eU/sA3vGW4d
3yTPcfW2adpyGdPQsTCZtXympipaOKMqrFTROZDKj9k+xE41/QbNkwclsZvLlqBU
Upj0KKGWtAvOGrVqUPfPgdepTKqa3zwELJxRVz5L8H0HjwNQA84Ey2KL7wGNRntT
j/ZwVxm8XlMc2MBRTyaOqA==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
TYFAFiyMglQqB2GrauIuZC2/He55jSs5dfcck+LRlGarlTqu4rUiSHL2K/qDu4Qr
QTIqhMHjhHJiaNRSTZQl81hW7CVKjMBbR7AiL9+SvQju5yyzb/8aPSatb1a2Z4TP
JrV3TQVWP0Jzb8dZUpoMrpme96ThPYeZnVYoDqDUoGGt4Zlv4z4ynHtu8TKeo47H
fwd0EOXAh37tkCuzyk6mV/OC/GU46N4ttyiLnKJJbQQWOeP159QumKwFtdn8vx6M
dR6a7QgAEtUdFTFPxSwSWcWnYi2KS8ELFynZFdXMnQG2w9T98fgoXQr42PlIlsZ9
KlGgcT2tX9pLcBKjHDSA5w==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 1392 )
`pragma protect data_block
/ou2Ru6CCw7FRn0kweqH/pEPPcDPkhbb+Oqj33kaevGxr1txeb9CSMBvw1nm/DIM
/P4fODSygenNbz2Z5cxBZYcDjokjPwmzJ96B20/gAqEQJ79CfInsTDv0lQ//v3Av
ajCWy7CVVkU/YUxkE/+k7PdS0T/Q9aTYqo9t0GvFljNXZ0XIldXrapt0HH0u8mbj
O4Xd2Xr9/AZIB1loWulc7agEVMOO2cz3xhKukc2/aYza618dEXByCUd4+KQmpsgb
4YajHWJfokUIrmo9gEixAq7Ywop/3JUj4qF1dVWrt3JQj+U04t5TWU+LaxbmUE/I
KyxJawaViwb/VpKSKbafTod6Ae7RBQxsYkHYrg9ZrA10nUqLOgN+B2XV2Lhz1WVl
G/rVmYMCbI56cIBEd2FdJ/DrqYcO0INWLfIXxg3/fO5Hm02PR7nCA6yILws4fjsV
OJiwOhZBTIXo8bZVlXMdAcE8K5dGxwvBx2HUh9CoywJp+IU4cSnSpaQ8te8+Q+qv
1jhX+C9sw4MuB82vutfSetgtmy/gQFW3uf+wmQ5EJct8c4SectYuueu4XCw6eCBg
hUcJPTemWIctrSyUEEiTtrcl7HNbYj0hHLE3ofoIOdYGRVFXqGw3MDgNnHNO1str
rpWziy3sWF+u6ZZCfsKUt0b4EamdKSzJ+chM6COL2CZKZaqNhAQ1p+niTgl7jWb3
cTlO7q7kuwE6RfJYsl6SWrCYN3/NBZLD2F+8KQ4Q4biUg/GYnJl/+jGcIKBtyXY5
ehT1sQG+oydhrhF/rl9spQQlbfA1/lrIp8haIf0YnKAfi8fbHMlwVAEP2tuA61Nj
SB87CzZobfDiAbVs/EILz60bNKJDvNpmlnMjOZZtmZBRAhpPkHCciAmbuJsXkujb
BAGnmXANIT+j/LQPehXogYlUmUJ8f6UX2azaPHhw2mHO271KttVfGNjxIXfwCmt5
GyH+Jtfrt96qtBSs98V9RKAfKfUWb+MzmPe45D/4DNMqy/e7Bg00i1spD/HDoDHa
2pcCJS8IsjxBh8DvbSCB+T2G0rRgn9+y2CoTzzqczHIbzjWXLagfiEp8kBDthRkR
98vxd5KFtq9CWMUF2S6fSBF6yobNEKY6EH7pL3r7TJ4Tpsm6wnU+7Fd15unk+cH1
zPaycjZTXltN+x3aLM5tFdzl0EaaEm4E+Ytb3G5uRgTAlMcjqfLsuCDJfg486/kj
wyrPvd0Cjk3I79QHEDAd1Bl8xOmPr3smwz5I7jECrnu8KyfXJNkhqgJCcFYukNI5
ektMsJx59rTzFb9ChxDSRDIcysOea69j+WghM8ncuRH2MPmqyrxRMVKsS1sJ5CQh
U/XkTmAfsROWDM8feSubnFl8z6qimh4Gww/81qn/LZmIUAM48e5lfwIJozd6ISRJ
CXc/jvLz+kGwcUKc4GyTxnCTcNkS7XLKVkMX8zKkTFOk9oyUkDuMLahPRMkU9wsB
eRCkg/A85O4ARd1DtGuOk919e3Vg1v5umcEKvkaDKKqAACsKzcp07myBST7rFFdm
PoDl1FFYghvm/Bru/9b1Cd833EXa+nR9jH261dtn21Kzytqi7cs1TydJBhNbVC2T
0wNfM23iav4ARTyeh0pYyLLbvGJPNOpPu09JyxfGIEwZOHrcREhwM9U7GT7RZwoP
RfCuwzjhufyqlw7PPIsaqH4DXLSQoAR3G6sAuxNN0Oc4stFqlIP107Hpwav1HyUH
Bf7whFJKIESRGxI/m6qOpnQYddOuZFCJFJ2lXUFl/pjQPbEwlr9q1G8kq7YuR0kE
sAmnVr2/vWR29sqCnqEwRgtV+YLCX7n3kmdVTJJEeDubJ/90lmvkgbA9VJoqOgSU

`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
gzpXMfSg4glnm5XqHTMUXgJ3E7miJhcqE5zZJd0/oqk/qgn0cQBLc8h/xRRHK6Xb
V0sUxz9hI4tJOiInp++0tjfvXS/ZyN6O3/uxXD8sASxLbk9R+1E6OjMrw6NYapWJ
1k+BThti1sXN4uCzMcRrFRV3304gFiTBdFI4evoRZ/o=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
l50dMOqxDJ2glyQa7BDJyEPiAJyq/gWxTLk7r8y0aC96rJ9GCixscYNhLu4xaPWP
371dp1nsKyiVLScIzaOZ4POMOX1nqkP+98WHDEmqqSUACJjVNbrfUodMpISnLZyG
pXylnpabCWR2dIGF+a86CNrwTbfOzBozJHgx+4UvrmI=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
Zh+qnrChgvuSLwImrcMXP6kkVZeROP41yqga2PGe0J1jmp0tfTVzyklF7rocBGwm
V763fk+uMufsdMswI+Apcg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
bZ/Ev1GEtkg74nvC9PjeU75CPL+KG3Ac7ML54xumfg/xdvgfVEgh1lEZyMvYK/Rv
a+G12k5sAGQSjlCLsAlSLaAoo2Q8PodrFO66MLWY7WHAO5Bk2CJzoYuRizCBNWNu
VcoWFIfj4RDlUdx5nAVX40lwuUcmwq+pkYOOprRLjId2K1SnomOYbL1b1FmYRnsU
b4MKvwohk8a7aNSHxItcQ5bxaROgtIAr5dM7hwZSzuUZ2j63hsuwLnXkl5rBzqJQ
fguNiT2IcNAaNBsKRnnb450zKUsW56zLNA/fa9eJK4Gtrrhr0MaLWcs0FU0/uN/4
R+nYmUDnRsBy+3zy29qzng==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
N7iGEu7ZYUJGUxOdu0mDMAEjl4OkYvLpv9R2Wltqmwup6+6WNuz5gMNVozZtQiVG
toTzKQeJpdxGGeTgctsd6WJ3huLJM2yqAClDMt19AXDqT73iZ4SLSCgki5Me6Z0J
er9ROPeqxORcdzeApbHtcdTQ/Y74Y+YhIBtytvLIjZA=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
OMlCHQBj4Ky33Cm6toz0nfRfJ9S5lIrqX7CiOkAHmW3DSD/QIxDM5oOtlHnIRXOs
/Amw6uwc4BljPWRdXcUALTENs6HTAfm7DWF3XWqJooNjg5FuNGiw5o99tvFtZvi3
JNv2TpTK/kWcp8NzbrUe+BlO0fLO4zNEzkyMFCH1JaFfDBdn7CdKFtla+a1R+2Ul
PamEZ7Ml7F1wisPcQsehbzK0W60qg8Jdb5UVn2l0C9+WAKwoq6YGzF0QefftVJmR
HTieo04D5LnA0esbTZw9IYUut7l3YRoCdqWlwqrRflTu2fUSSYLtF1X5NafGkGfA
w9hC/fF5KOSwXYsZKvkP0g==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
VwIn26Qm78U/T8iXwTdlg+jjal9VesHNiinfub0Ft+yOg8fPChsZiDdFMNz1WXFM
nhV77FK3mRtgJ8JDRjZ02ejfxgCxztKjQsPWvcJ6I8CgoQWL+ClfdbQFcVKP5o4Y
BnLzx2ZeFzWHF07pPQXf+8MDMwRJX/UW7zV1wYDMxcyVnaWKwb+VocCKDZN8qDj7
8frP8LsM2zhX+3Z4iArMPSDcJDzPvdvfg3HfJicItY5gkAGpIVBPa8Jqw1G4laA3
EdNVvSAXZZu0Jq2pxwOC74miHkz+9/aJF1omfbW1f+Zuoua0ciUdRyYL4x/Agx64
4zL+JxcGxlHlvjAswayeGw==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 1968 )
`pragma protect data_block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`pragma protect end_protected

`endif

`ifndef avery_print_util_sv
`define avery_print_util_sv



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
HrUpXh/YogW6UkDsEeK7gTYh/d6LkEgHQYczAfjE9OgsfhElfJjy072zVxxVO5AM
COUzD52lTp+t9sHBYqS0sDsQfbhzsiZUdD+RdVx4plr70/sLJDfRN+WhSHo2kmMn
JYCh19WrtTOzGAqYxpONE7KO8OrFbq8uwDqg7930do8=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
TYbc0SxrfIerejXiuLBJgflpbuk/ot1DJl3B86vKQ0p23nDECiuzJX3hT4crmpFG
98/PciQm1nJpwy4lWxKTELw/1lxVg225JXTIMJt/XnXhsBTLyD6ITneaQSvs2uLR
7/UHut4gUX0yje5DZ4loH1/rinCelovEjrQDQ9zj/fk=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
Ot0nqci7+Se3KwyGmnK2YO4Ic/ysZAJFrx338F42AttBIDZHM3+aSClQK5JbvMUZ
C4UgnPtDm8BHX/B1z6wVUg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
0G03fClOHQe4OUe/CD8CDZ4sMe+Gz9UP4vM7n1JjrKoigvvOGz3u9A9IH9qyLZUF
mbEsNJQgHFWn3lAFb1gsvhPP7DzL8GZ1aZKaeTsAcxNS2EiU0fG1UhF9WTtWaijC
Dgdn5HNPbFrkcHuRKdjuLL8K0ButkRY7S3Bi/3EbpXTG0F0vYxxOctAVLQVi4WO9
ZgnjnqAyFhagi/19CAHgSIW1VKTt3hLcIryA8SInwd/r4IV2ombQYvfc11IP+ZIa
U622J4gk6ddcLaw47GJwEt9iE/i4d6ux0FJBv4XZ9cSzBp5NA+oOyBxl78Cg0btL
zkCKmluQgk8Jokb2w5vBFw==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
NlW4P4rupMbfQdOpgk10nsdu8ntBJTNjWufxL/6Ops/kZt/bTXYtqxeoJfbkYJvp
wh01f+fD0OlW79+yUGHFwNAGqCcxSDgCwCYGyXPu8t8/EFrNtH0kAPdQGTRUU8t+
xOz0LpaSvA0/0RWqwln/ynQVnAixBH0wPHxn74DhN4s=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
qDWeY/icV4GMiXZMaJSNpwO+KqI7fhZ6DCg8pFeyKtamvmt+q/k/C7ET5J61uuay
tzloVmi7l8FdCuHjI5xfFMQ6WXdLxZK2aY/Ht310AClQ0UUYINpzAN1y1fqKU05c
Adq7vd89L/ndDYlEF+n2qiYShEARllWrE3Ipv3cEpw8XFBM8BH8Rc87Zp+eoEYkb
NNvC1Jb4MWBkETUAwpb7/HzDl0ffcM/Tirvvb8GOtqvrz9lJPJ7Y68X4+AXhg4UU
zt2Q6AtCXkBygIhzFY4TjPHgiqDZ2I2mnRZp2pFLmA/+bxmLjeoRUFsw8f1XhuIq
nhxty0ZSS21osGtTyNlzuQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
pH7X41wo0qixjsDb5xd9eCpNKH+r6gk6YYIQNSMcHGPAe5FlbPElCHka9eEY/ZzF
I9FCkej4tE+/sgLgVzZTX8Ys8c5R4mos50pT4CRYx2nZzPh6lzGdDvbZi/6uKceN
9BwJCVabe8kRu5wEzN18Shb2GEhPIqzBpUyWKPxEYO//vYac2Vl5hjdJufBKRGwe
UwPGkBT3n9Okv4n3h7/mWj6h/PZ/uDZQ2yKb5tHp93ErEfwLGGblr92PQW6J82Yj
6g2cnEIFbvcbrsDVcuqdQ/sCUw1rSc4MKfGx+axylPtCAlByhIvmGbvVzYmTloyU
VD564XXBtQ1qTBjYXEDo4w==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 1952 )
`pragma protect data_block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`pragma protect end_protected

`endif

// `include "avery_param_log.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
/***************************************************************************
 *    File Name:  avery_param_log.sv
 *  Description:  avery_param_log class for basic
 ***************************************************************************/

`ifndef avery_param_log_sv
`define avery_param_log_sv

// for merge coverage 
class avery_param_log_base extends avery_log;
    // basic variable of log
           string   product_name;    // BFM product name        
           string   product_name_s;  // BFM product name small letter

    function new(string name = "avery_param_log", `avery_xvm_parent);
        super.new(name, parent);
        this.name = name;
    endfunction

    // for merge coverage item if up-layer can't directly get down-layer
    virtual function void merge_coverage (avery_param_log_base log_base_a); 
        error($sformatf("%m: virtual method is not implemented"));
    endfunction
endclass

class avery_param_log #(
    parameter type debug_e     = avy_debug_e, 
                   chklist_e   = avy_chklist_id_e, 
                   assert_item = avery_assertion_item
    ) extends avery_param_log_base;
    // file handle
           int cvg_report_file = 0;

    // debug message related
           bit dbg_flag[];
    static int dbg_flag_visited[string];

    // NEW:
               assert_item      chklist_map[];                // chklist_e to assertion
    protected  chklist_e        sampled_item;
    covergroup cg_checklist;                                  // Var: checklist coverage group
        coverpoint sampled_item
        {
            bins AVY_chklist_id_first = {0};
        }
    endgroup

    // assertion item related
           assert_item          assert_map[string];           // name to assertion
    static avery_severity       user_global_severity[string]; // name to assertion
    local  string               unknown_assert_q[$];

    extern function new(string name, `avery_xvm_parent, string product_name = "AVY");
    


`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
Xr5+jrwQQ1TKRxtklddkwgh87SU4YO5NrW49TW1KO+MRSuuJXy0KXw23LFQ0gPwc
QMGPnvx4J0goPOw866U6Z6/+b65zKtbVFDi8Qy0xpfadg3ZK02zEi0c3azmjlKem
7dMzkakOY97d/pI6b/J79HUW7wqy7hvi25PsrrrA4/8=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
H+bAVOaT/Ns99bF+xqIQdg1Glp/LIkmiEIG5RH5sEsAFmnwrAx0+GFucQJNiV70g
3HuNCOkSNU8Ndaa9qIQTUjONRU2Mk09aD68Fz8MPK1PpNaFStxvIPbAUrW8IiwNd
/bmv/q5qHVj385dHBVel+6yV0Ou8hpHHqj+jjXMD8wA=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
AJtydSN3oXfinn8qEMsH6vazok4qhZxovc6xnVjQrGvPvG+79uC42M9GpXm0FbnO
pJ2SadBJeRCx2FOL80iYSA==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
Yg1z3+SiSYc1Yzwj8P7A2nDeDMlCtQas6M31Q+s0G90R5dTQAvzA0V6QpDIDRZrb
OlV3W0UB3GqDlbtMw+nIT9kUpfpE/p79C8TSsbwaKgkOINiKxQz3xivpp3xCZ/KR
8lpB4wPMrT/1C3+TVElyaFNdyb+AcBfwxRV+O8d/mRiG1PCLrTpq+n6EatfPM4MJ
SlWqFutkgWEHTEankW82GCiNdXLLdcO2jiRDuwB1DhH1ZYC9ZgM4EqH5+CE+HjmH
6mEhQuV7G94WQQVrFhTCnvhoYkUMBFn5hn7uewd6/iKm6fEtpQ9cUixMhkZZH8eM
mEzQGlROHjPcUrZqVklP1Q==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
Sp/QsJAwXLnXHUzjEBGefi73nZWjOO/kgSxHBBH8zlT4FL7BzHEJzGw3cy7zZWVW
jD5ae4wB+FpGuicFa+krkvdL7zIsWSpKNWCn2q9HGvrVBi7JXIHIUmr5Nz5VGV15
X7nQwl/0XZQySTc7jHm0XN5dbBLJ94TmziduJBBKMIA=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
jtJvuEhM8zwJTgnqfHuPhkFUbZGgiIRioiUP5VqI9NVTbaKZcAge6GQprhx7TlUI
jK+0WLN6gNCDY6Q9Pr7bp1AOrhaiYl38jwyrAvBqgBfU30ywQpLPGgx66r5uxniP
uWEM/5bYjyUBjjqqANdVS0YT00svmw3uII+Os6qcN0kXBBwDx5KcyRuV26sFyBDl
ektlOi7AcJ6huElXTW90fwb6KuatSg1PEeKutT+p7tjF14xQKOC13NKAxXAypOfG
vXmKn8wJkSPolEK05G5c7fSXRMtYNY+thcegU/wEKVsxqNMQNzGFrumcMmnV8kJc
yM3eJFR/IT4sy9RdilZOdg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
QvWw0tTa5L5DZU2FdsArb3QAba31h/SuQ1q4RkEgbyRbBoDd5OlIYXuc2DWKZ3Mg
cbl9k8/qjF+ONGAgj0/u084C5O274zo6xqevuUfP2BEMVKtf+2wjlP+Ro295FVT7
l2gEz7burVxKHJ3cisgW33cUNQDR6BR4WQqrNV33LHdhj4QbBebxv4vAmQEgfDZu
gchdP3er8uzPLisdaJx6N9+khNZziGlBd5WWog+nDfyhSWQevi9ekocIH4GWUgBK
dvvh/ooHmeaQ+GficAZtOwjidFexU2kbmE18xjDk/YoHc+0Ze2obBCtIqe53Jm+T
wZmEP0OrZMj72pi28Dy/8w==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 28176 )
`pragma protect data_block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`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
BJd+XdfmgFhJd5e7+FGa4aH79ymIZ2p0W357UaKhL1ktLz/rKbxl21RXK4p0Bm21
8T9KaEqzA/HtrCpA5F4Xp5ClmbYv3KVyjsykTJvzR0VznwvGDDcunMOvaBgq3AHI
aEdKYLkwOpxbzSDP71Jq0IJxXj4nv41b+BY0r/cu/1g=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
g4qY1Ts7nzormHEwkS2vLiqUdUSN4p9DgyyZngeH4SGvgPZqll83d6GFVDWUJXCg
DzlsmDuv+gNVpxudpbVkPd/y5dZkqH7G+1/X4wLuTLrxzlDmYiR+ekFNimmpQxer
SneUCyNHKSsKalsMBsmCDSi1OpASlUj27OI1B0g1QxM=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
INo8P1mcwsC7d0516NGMG+jfIpPdqgKRnHXyCG6yWefYi2LMuLAFyEc27Z7yvEi8
hi5aNjTRHq+NN5Xb31A7Dw==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
OLBLHP+tCtHg8LkvHmeGANj5plBEqeC76RPckAXFgF+ixqsCxujkpP437Vt3c7Bt
wfbqmxQDr5CST3CN8eMD5sH3grMunKK0XaE9AtRU31ulGypKwd+dRGzNExex1s65
WXaPb2QynUI8SCzODXXLF42tXrSqRj0tuoG25T08C2QfdD8xj7rw5C/1d9pEMTml
2MPLOOldyrFgmxs5K8G701Rj04nySFJtrPnbW/wxlunpdnxHIYCYCIVEfjIcLhv7
tzeX5EingMdzwLTcCvfng7CmVR/e//UX3dC9m7jMxqdoGIlSWTydkTXb9M/mrvyz
caX8+UOwePKL79Rx3vo7bQ==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
Gyi56K6r9RxGZv9QNJYIyeKAS8RZJcIn7iRFoBuvh7+JLRN/n5ww7C7l0orOR04P
WxKTK9vr5SlqURwoBPUc/VrKdTr3Pd/8ML/VN6H1qpK0AuoyC/TvEllj/PPRjamb
QTzBHLKnSNLQk1DX2vzX3+J7BC4w7D2OkBKJdz3gPEM=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
QT1F34NwxkOHfuy8xYfge10u3a16ikaziat7ioiSSHwYocltLkeeYzRe0ZIlJHV+
pCzg26Angy92YqWHq8aGSOIjYW+z4XB2qV9HTpejrupGGDzg9M2zvybXxsgXZ92X
4e5rtfJYfHCHlvkq2XAOZA3kHnxGjU/TXGFYsh4LrdXZ2WCqnV8ATdvv+kqkQwjL
OaE6LH8k27b2qNytF6paCKgG1KeCLyBF/PSlkQuQvbgMwWqIrevZ97/YLzpIqSdc
N/xEdYKt3Lh+8C/A/ZR4IilsiWdQuRPgLq32ceQnszi5m4noFXNbOFfxVdXgMIsf
pBZ1GQ6uhwdTTTBoP5wqcA==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
bf3+req7fo8KdWy3pyH3IzmHVaC2Zy4/ZGZt/SJ9k/qOoWYLMVds9dj+HuwSEOTQ
MQ+irkJKXrpZloAcyI6/iItOl2R4CpuEinGnfQ4Dd8/ytXjSZwN4F47eDMoe18Uf
J+fQL3NUcygMNqAfPeY9fHgTLuHhdEO4umH2nSspQnlI19dwe4dUy26FMDulL76J
aB8eSHQpLZSVA2caEfXovKmei7Nu1ueok8jztexqdPMgDpal9mzNjIpGa11AvaL/
E/kuwRUutwESgNH5ryT9D/hDT+8ziWGAU0zJ91eLR9DC16dvOQyXbCr4ZXGaWQi0
7Rhm2hW1rH73p+JELsYv2w==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 3600 )
`pragma protect data_block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`pragma protect end_protected

`endif

// `include "avery_asso_mem.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
`ifndef avery_asso_mem_sv
`define avery_asso_mem_sv



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
KqM726xH50mCVD1i/j0RgYULRXru3/jEsRJJxEme9PPwVPy23QzFD68ojWA5vMaV
ATPmFE6IvyxrMEAZ85MDFcMBwvVcnxBhjcIzhtnZLjZhe8uScnQjjmuRB881nfo0
0G7nU6iDXyos9LB/HhTb3stUmLK5AFe3IEOPB5IhH28=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
wzoGGFkIpK5cS/Vvzbgi9p9FkkjJ60nqz7DbBx62bKLLxnT2nlmDtG635ZDzKs/F
WDmvg0ZPGeNzG0hI9qrEc8o+XOpzWqMCg70obMinlHk77ESY3k/xvteLbYkS0H6j
yyxP6cIzkKIyBPqJMoEW9ucV9HHYSS7++TTvn2DUoTI=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
lYadbMPOUeyAx+EwTGlOkNwigyqKeoAkBCV8uwOUEypvVys8omCbi+X75r/gpXrB
Z9ReKv2HJ3xIsrq6O4bW+A==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
ETPBFjyllrIPrXc9zFGOMqDtpPkWm2vJ0+vI2ns6GvdXC5/8rzcKwF+g5IP0q6Z2
J87ZRpbJivAqe33gPJLPZxazwHj1lI8KUe0TFFLr3uOfUdbgvaW9uRn3iWInq52r
9E0ZdCZGlI767Pio21UOR9P1P/0qspgMW/mhwqyWg8vVARoepnw0jtnpmhlb8tBY
W233+uV6JgbOxo5YPKiqAKF+gqTh02pLdFPH1Jtp8v2ajsnfjigqboATe8b8YtZM
q4x+9wcTZLgC/EUvl9GEewGkElHMJzKrzEgHDXMjC7JWbY2Sr8Dk/w0KqlmOYKeW
HnwDdLyHUqCujVs9dKUUOw==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
Maim/CAtVh3yaO7fd10olGJTKCdRB1o6wdvk2oo+owCI0M1pP3yuvSdrongdx1Md
oryGE317txNTHE5hIx6DeNoZ9hY6jKZ+6ubA7XMQmsKnEmG92MRm29iWMH6Y7Nw9
eKKKUXB5HF9hWySsahoY4YQxIbL8uEKZFe5/fqzrIc0=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
M0ZM0OKuzjdjGHzTJE/2ozZA7+89xFkfNnSHrlOoZLpJts4XDdxJ3rdXHoAQo2aI
k1/TLjvoXiLlS/Ao++uS8KUPNGFrssV3LHyaobkIlVoHieyNALBDiKxvNllUTnHR
DgTq4pTeOupb4qIn87cn6oFztSQoCmEQLRu2MEnwbooBpMlVyCjYNK2ZavdXEu8a
DteQM2kcTtQjAru431Etcw2nFLkKwgqrnqg8+VvWqS6gWDNCynGhQ5J9GjDQmb1i
hNdff5riZMhXYFM0iJqeYzMxsAyZAh0x4NdJQeB3i2GIja2Dfke+/Hutdit/ZkKr
nvQAKvcVRpalaWuQiAyaTQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
Qfn/ZNVVCOmMRE0niziQdL5imdHG1kns/JuDrj4KboMUVsfWPZq/ZDcA6BCckA7T
gecpF8lI4lC46uatw1vVMoQmzmo9lFDfEvDuBVqRS/3CQQ3QLahmY16mg4mgpwh6
TGGNf44Mnx3g/keb2GInXsyrrBPj/aU04hOuEKHR8xdkMTXDL+SVAyYjqTj0zCbq
JefaUZ73nZeiygv0wMhrLgV39too6miNko5rCCKqrqZBw9bWQYjwDAPE1b4s5uDs
+vbjNjNdAdeekcP7xMrDJZ8MpxRFHq8w8m0AGjRU5JZf1CDk4TeWrXBqYyMEUeIs
sWOH+adaCI8Hp2vJgPZ00g==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 2880 )
`pragma protect data_block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`pragma protect end_protected

`endif
// `include "avery_mem_mgr.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
bprNOH7OVTvrepYLGjIplPwYdEzHAea+IdrOjBOysGpCzG2gnWYFmuZXGxmm9mGY
CQSkyGYKnyrVtJbbqVSVcvte+rhfserD5W+Piuznofj9xesCNFX7OHKFKJG2lfCC
XMjrPyoXhjITDI30bZf+Ijk/klUJFxU6LKeUzE0FvpY=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
Zg3rAH1N1f+uZvUV1uL7GQlQG+NIRNHz9LFXzPV5Um2FTrq2kfHnjUUUrIHsvN99
t1GOq6o6Mrz1USf9gG+2r6HB34En/yjwrIrxp0zNDZxwCPHWOBbejwSY+6PCb5+y
vbMTJWGcG9A3izun9qtqV0Yj8HNPm60aDHxm4RHByeY=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
X+c18u3W5biUel5khtdOTa6Z6P/L/XRIK3gne4/z0j1j4gs+yG5Ny8nZnZSwJpCg
pzy2nJLgdvm8Q7E0iPLyoQ==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
KmbKr02CkFteWc1KoTDjCVpSZyKdJmkznhPTsRp3JVgCYI3ftFMvh4KVAZk8LjtX
o5CiQWTbWWRoTw56hTyWUfXRd0agPLoWx9mD7go49v2kP/mHiRxq5svTC9QIRLOL
rRuONPyAGPMsNZMQxTs/yi4QRAWEoQYjEWQeqnXRI+T3g4SGNNfCujN1gp0YJaZd
GihfHI5DiqmwJO7rtRgLW0Sr9aW8jN85ghIK+9qMGElDlTPGwBKEbiRKbDMvyTNJ
TIcf26gciemVEflXqp+hWserpPPhqaUuytoV0MRdpnaaO22VptJAIt+YQW7cTzcq
cMJnz2khdYc1QqhNvf2yxQ==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
NJhor9pUwcerD7erqSaVPywn4D0c/UMBglfJM1aSgvBvKiCl4U68zaAnSwjCHv7V
LD2U/Q27hPPTfNCq/frEBtkJX3XmiYjsPk1bJF62w9SuE7pN/bNM36CrD7T1HFZA
7jcbbUrJtwdepeXYUH19CJoOHw/wvFbz479eRnY7aKg=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
sbu8OXR8amwcBlYa4MXn3+1Kj27LD8nuqcZaofN8Fe7XEF2quKyHCdplZE88ohRQ
NEfzN5DHrmjnbYYgq6jRzN5Mrhpop7H9Sk2WslcYiFKl0gj+wUEwdYVQ4AJYV87v
+7KeiFebPRPM4gMOZR44SXh0pMa7NPLkwJu2HBFQe62jEWfuubaqV1MOqjpqGCB5
zX8HBoOR9dkSNnrBB5G08Gu9lAQwtctsF3Qkn10QnS28XVsGTPr++KrenWYan/YH
6QK2FpJ0oFwnTG8q6m82KtpdKlteXJFfsAM7vbf81CXZo1+Y/ZVeH10DAi4apR7C
cfYaUfygaZsZLx3ZvOUNhw==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
jAN1sL9bspYTaR0bC6f87K2XKl++6X1F21M9lgRseZy9riKLwJBkxrgUbk8JsiLg
AgPRlCwFCxpqGL9SnoJbeyIkHGidaYi6xcODEwP4fJMMAE7VhXWjJ4TSR7xFOQro
/GNLin2hooM5BHOY/qxOHivyBoDG1so6S/UyMzSkLs83klpoGHcvA97rxO/Ms7DR
HZUIeC39m1iIvSKQTZxBb50jIbvalK6JP8+/D30inDFgxxs7AEukqD3aRd6C6juM
V9eRniklwXQNf0AaCXD6Q9wRcixBwFp0sjFtTijC1RcDv1vfhvapYPRrIQPz65jb
tmi/mTHc8cdXAYopZwo1Gg==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 16432 )
`pragma protect data_block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`pragma protect end_protected

// `include "avery_reg_mask.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2013.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */

`ifndef avery_reg_mask_sv
`define avery_reg_mask_sv



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
DrMMUiQ55ko0+dPr8a3qpwv0iOsvpiHiTuO0edWnkQQhctHAdCtRoTarcXlIKGed
dCyTOPOnSQqBTZdyty+Cq8kwxLpclibsDb9vGgpTaEa+OcQsCu6MOHW6jejqIU61
zXH87DpCF9+P3XJ83ZqPZBO2nvUD3S+f5Lx2cqgwhqs=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
kjqU8CX3MPkf8PoWFdLei8zkY9eHJCbxOSEX0qksJJAiJl5U0itHoGCYXJj8X4W1
BRZhE+bz2xMXIfP/0PhoGZ3DXkn10hO0NiQC6cGkr3YpIJesAA5nY/D0BiQXQf95
ilXiLohavJGMIBfSYivrF+6kObU9qL1+u+ywjKxod20=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
WCFOOLGEFw7UJvGJW8q5DQBFfxoMhyNTbg9yNQIKWTlCKy1gzL+mJ49LJyQgcsPd
OT3M0uRCKR4do126P0NFtQ==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
ORA6yaU9gZ3mf/wvcGoVL8BOjB44LgWnQ4qHHKBwLcnnh0xQNldmcjPsxJKGqcV8
/Efk+E4WKR2sKc/cvUw/nz8FDoQzyOyQZx6i0SE8xC7qp2hCEtgZibjVpBHAYXZJ
SCaUhUKBD4P5hbeTlfcLzl2sZjU/qsxLejKmok/JHKLBpqA/c6jVkWB7Lt5nRcz3
RFUVxrFjj5H3uUya8vqIqmuFrud+gi+6RkGXOYv2Y8ZflSOIItqrvgABYWdSg8gn
4myOnUleA51zF0EzQCg1+EGFDStOAoBJ1emImw0v4HO++DDl8Vc4HYVLUGMHKrQO
bFuLAqbJ3wR2LRj3aL7r8g==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
hwSvXHAhVHNBefD98TgdfbpWJo0EaoLxEhQ6WE7MoIjFb40Bxvdf85pQqkAGCucr
zcLGUsj+aOg9wUELTiRI9QKpd9iW5rO5QnsRXjuods+PErcOW61e4/Tllu53JLog
POp7y4qB3Lv/Cxqzq7NmD18jLwH0P0y6hzuUjOz/5yU=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
BhcI9+CDJ1GZyQRr7flHs/wexqcFsK/+px5d8Mgchyica44KhYyZKNBRxDdJpp/C
ZFXoCL/3j3Nu3xOHnoHdjWA5MKu//kSv2ktDE2ZxuQUPMtHy33GABIAV+0/AVKdU
UC29vBI92pLtsZxj65xjef5J4nGYdrPgGv8fpsqJmQZT3Q5NqnRPoIBuq+LNytdv
AqL/rVwjXxS0X8RiWsN2aOj9Fc5pDT5YSWxVqdLmpLQrdZLKcyqQ0gDBRoIKVUok
WcsAtw7PFtwtWE4F/cxcwD7IObIsQID11jFE2TysujzQdBj7lGVXKziTD1b9b6cY
7V/GciSewJjNQTtZcXHZzQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
Xl5eob9KBmCRn4TJ7VlI9sgIss3eWJklpiM7S/QxXHggTMI5b8Myf1vvKVDlWVzO
wRQXLLvK3ASl74zGWnpH3uEE+fxhGR0QMhJZXQy5k39dOu3EkWpAU4dcHkjN/NWZ
L0bgsyFigGUG8z1eaM//nL9b0BQsgTd5EopidLEJbtCaAoYKx5pMwBQQhT8Z0Lxp
g1TIwGqWJNzAQs1sBfnuQuswMt8uzOpHVZECZXmqU2uYgja4GyiW/agEU5eTtnzj
vbHEk2eVxP41JzmPkgP99SI/4YBGb6Np8GT03AUbkkFkUnSYoNuv4ZZN4IKaZZS1
ZxWk5j96IfhgZRrn6laRWQ==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 5936 )
`pragma protect data_block
/ou2Ru6CCw7FRn0kweqH/pEPPcDPkhbb+Oqj33kaevGxr1txeb9CSMBvw1nm/DIM
lbiCB77tuKLsrYJ4PK4uIQVg8HbvaXLLhlgkfBXBsOanyNGy+R7BNr1fed4oImZF
2VMTlhyZDs9spNRlFVyW8EP66NdTHY8tVn0WZsdaJe+/a1xLrWb5Cv5Om6OaMT22
ahKrUKfE/K0AY05YawceP3jvUr0wNDJ2ZUDJLsDjtPADCKqvHPntlkkRUr+qaFjP
imx/CT9auiX0AlKozrvlNMxi3cw0lw+es9K6All6SbPCVqbvpLywoh1WUK8a16UH
+pMTB45CklK1g8WN1aXkjd4IOrSTTR+rIn/+suunWZoHUVi1ZVsG4yJVJfdOrgQT
Jh56nW11TisPK42qa5MuAtW4vFyUKxyMupgG4MS6o5UDXh/I+uwXurbXiL/xZwRN
GRCapXWt+l73u5FBj+zonAErqYCi+L+MJFJKiEgkJ0Yv2X8HQcIj7kf2wjPDRG4r
j7pK4Z1hPHuoqvO5i0p87lXOXMaoUc0JGu8zt/BAMd6IHzESG28mR8SG9mOq/Rwb
sy4mQs2EX6kusfrP8qNqlq0S6QDx/SkCcObpgdMEFGbtvnN9QM5AHOjaFbfWaUj1
do9tnHf5W0RiFWaSnlrO/tbPDz11cwyuLYWFg5TicRTXmWLYzo5fJ4WxkqQ0g3KO
A/z/Cruyi4CS0MSwwee4LT4rnv8dJLx35U88GGIX5mY6PHxvkAN7/Coe27AwEXlL
P9Vmokm9IgpV9W67CYKNCLAi2JtiE2nCwY6ycBtVLQN+1wDnzlF4QrJACrR5j4t6
U6kT/Rpw6Mn9sH8KPOWtX3mEbJtELlLlbWrAKHlTvTFj5PgLrL829wySBIGrwVQ9
f4Tk1Zw/FqheV1jmqm5fsO1shHJFHFveOoP5JGa0bvuRM7PpZLK1BZeUTRtuNzRi
Kv3gP3hVdgpzPhftXvE4Wmxx533yGA0/J43CiAajuncamW2aDYYUUJJin1rk9HTZ
L5J5Mkn4Xe4mZaA3BVLBsVpOVXvbBfRSmye94cm8evIMAO/gByN+/ieePSgFccA2
nBCrLRlmJdFilSqWi6fMvBQPXjYA7P/9yA9I1gunJ3FI111JGp4A16/V4+PaFtqV
b0q6Ik3mQi6318PL4ch1B1OxQd3lW63AXuKhDwKiopyZmEBDauosp1okMxArVwfZ
1KNk8Fo6UeHdM9KVZpu6F7zbvuXepNFdyMVwcXxveuli5ELDissbSJcFjVGNc4vv
UqkGIUUW6XHqU76JWH1nqlZ3Ko53if+l42avCqzQlwOq7Vdsdf/3VrNXNRNJXnf3
edI9FLIBsRRb/+O9aNRLg+GUYlpu6wJ5nfJdmOOGPI2ZlUK7pxkQfVUbYzPD4Qzv
dt4TduUaADuMA77Wc8rZ8j/s6uafSgBNYfOhMWNBbWt/1ScdW6uKdikoWOpN+fCM
Qy4u8V0yQf+VJw5Ej1Fyu86dUMCiVouQe1KP458oZFRnZKLNba4BfF2G69pI7fQH
/KWuaqxxPfdNzhoYSzI9eDL6kgEJRYujGH9NgjamivsO8aJJC4yeGr0h6Klj+4qy
77hHcjhXtQlWmOoBNQxOagvemvEmkyy89BahZGHvRBCGV0O+qQp1PhNppqqiUkRY
fPoFPgsK9XT5vyr5uuHjHAiB2i3RiYwRcuy1+021jzaNKoUs4tTC4MbTq3Qz2yj6
P15TNHSlTvv/3zbKlAsQb6M4mH+VGtO/lQZi3ZYdPr8tonbyWuSe6+0Xc1Kx5756
QSdTpTBktyF5IJc/KxNX36LFF0G14TPv7g4RDMKOlbaqXg/m7ztnKNAGjFyIp2tQ
JAjhV8edP2X1atWoOo87pkbdOrZpcHaTEiZSkoVUNZRNqc4TIVYbtAm3nkQf6uns
ZZx1502wNcVKlOXf23s7SZgXkhoT87EDvudwpulyix/Oeufcb1HP2B9kPkGWsU9N
Y5ArA+ISDxJF8B5jtW+b7V5XVmTjX3rr561AnfhFNknEGSx4IaJ/b0uuMNabVYTg
2pRtRu6jp/2g4B2owXBIvAgsim/6CNrG6woafENUMT9GO1Qc/19SMQQmtTkv5rxC
sWxFWidomNV9oTgrMYk+W+VA+iCc9UT0DIIjy3GNvF4Xm4rUQPIYyPpjKeb5xRje
k8TE0eLZQI59mhaM6/CfwkgjVQvp7+kgyYXhlL24AqXLzTfZ4wGSqCN3oWwLPAaQ
zs3KPRZBt27w2p34TzcBexleaJ+HC/u6LeVt1jSAbEUJcKfuwerSllar0UIHv/fT
Y3PvmEWP2AcfoiFdJieAe4uqAw6K1V9k3QhN0npl551uPahRq2r+8mCFOylqFyWS
8Yyl/A12IUDghWgPQ4EszKBiTPnzX01Il/AjH+96zBXrd3gmW33tmatiRW6uoG5S
H7RWB34XDB3XU6tFa5cdmI18Ds51JvkIiH49sOEigI5jYKPR1xXiZgq7KRWI+Y/A
6MwQBqKIx+tC+8v4F3X3eGQE4MYE46JwuLTUtrK7Qt5I5zQA/STPdsw+WKZvG3UT
AzqF5IjoYa1yo1GW+CEpf1Z7/0Lp4V08ikVF3Jfkl07XGmx1PxuCZO8rfZPOGMfJ
pFspaDSw/SbrO/TQUqk+X3VIKImP5K0unHmI1FnPveIDkOA1WQQjWVU9Xpb+mMJY
iYeBUSJ+XZJI6C/yB8OcOQpRgL6Bwv9kaJBvv02CFXl02gV575BjQPX8txraCLD/
in1CaPDGv4kAXNJYhxIqaV5++5CmZcXZrRSMHuuWToIntK/8blQwBuVVOnOiphj0
TcCK06g2GClEErI2oBYyOHatlfvXx0dE0+1pKe5oUh+4mWfJeKXkdnXZ2erPxFo3
RJtF9gSPDo38tyyeUXPPNGzqkpcpROgSKfk1h5LwClrfBO6DPsnUqq/yB9TaocJB
iPrvYpbrHmh2axAC4hCmiRaqwKZmzI4buzL9HunsohRe690iObQxY76orQwpDB9s
9hDSrNV/sxjLIV/XuqkzMPU2KXpjUxuM4IU2HlB3h8p//I7RntVy70jCcyjQmUze
quKzcyMl6WP6kOj1rH7yx32CFv3eVnm+A94EQRgR9ZhyxS/CVMmjJK80reHf0jB1
5OI9+NO/1Nu7vIVpPm78RewfwTy3FdCGgadf559hyyTaza8BSc6Xi+/+yYKna0Zj
UjhATr9WbWGAL3N+41KxuZ8S3KVyLuoUIFqsu9pk46ZFATqgafez7Jw0Wfa7hyhQ
60pC21Ro88cVCtPp4NDDRgdSEc1377K4Ow0zFk97JJbXoOKwzm3OSOYwjh8kjqjT
xLd7mqkMWzfBEjxS92kggQFwZSjmdljc0Uznbe5L5N7VRCb1QEGGdnSEpFFjFXb8
EDWaFyQWKZvDLJE0gystR08oE/hpM1skl+DHBDGaZ8WIH2q6ED8JBinbaRpIwhVV
otYlxoWQdUSwyoaIheVd/DieJCQuoK5K7i1GK+y9ldJzl5amg9GBuFeK9UvrV44F
z/yIywsm1Cctz3mvoQmK5Z4vQoY1B65nKFY28EHKLtyDeuHl7vytPMAtHw57q/uu
e7988qFZRwBADztPhg2E7iL646BOtXa6qFerwk+9Gxgu2Vv9128R7SoLLWlGQW+v
QXOuqENtaUBTF/6cfp/0ddSHkww5nNKI9dqwrZqHZcsgnTlfCjbSukQUDyUpxS09
gDHoJ9853VkgXCvmJMqIHe1nLtuZO1lZ/NR6NFfGjTymvBupr1ZzO4Urc6DdMw1F
UEcu4SIBaGXUeW1YL6uKUjrWZCr8TtKX9Jx/+73sa0CjU5gjhtQUHXpMimM3/c7b
tYppyB7odqbT6EoAXooGYFn/RoxAaDZuE66w3vpaBZFTD7j9s7Y+rC2thCNq6wrU
eceV4TKXbiJ4Punn2HkJnexWz6OPxkpG4tdjaE8H5DlSp7+ocZRONfCf+KUbgai8
1ryFbsaHqkIkfvpN/58N/1yOhrF1qxdDwADD/FFTeYffMjOU/UBdcjW+hKKuOiJN
5WH0o7/2g0Un7M4+qXwINhFJssEPapL7699BK0JVoZUptrXqnzGOc0ZGBcv4ByyH
ADFkds3xLxR19ET+dDgZP02cYWsxvyj1EztwrrOK5hjJzvOquHLcadNQSggQjMM+
bjNxBbr2SHy0Jf9wbLb0+ka1Dvnt6463Sgfl3CKpuR/Hqh/RyJkQeFGIqTo9wX2Z
eL4KZ0KXuFIx3lddo0eLz34rkK/1ul1zY3+u08/SylROrD06x+UlWtrF97/pC7vX
EtQiNdlrtiAdtN0KzY9a1f1od8TA6T0QuWgZBOuL7tsWEu+dfMT/9XAalnvJsa8/
Uyq+HcWqRqWxBBTfgyAgpq2yUW8aZoOzewqkGyD20DjSgD0fyxIAsHWoQMpwB2d7
oNcGhJJzGhkKKU0QP7RsjYvQsp3O5vWkbP7Iz1QFCbi2y9sV7veRv5Mr8VCQx2/2
ndScALKtbvSniDu+rUqRhvjzE9WbWkgAz4OR2qF3BJOq0G376hXyvzxVmo9wkFDg
WuLsqT3PvI7xJx1MtLWNztobM5XXAxtZycKjqfu4DLOsy7bx7Nrv+tSFtqazR3WR
+XXDJ6QO+gn8sCK9QeB/h3sZJi55+pIxbTBaHwW2LCt+5d182FBb5ETZ/Tb+TTXV
v0F7xc+JTsqmDvYyXQtRGdN2lPaJu2QUWT70tUaIOuL5U1BGepIl5tjlkoknOrOQ
LXHbEtCrz6ovXPSj2bE2daYxEy+YzUaDiiPuKLi0MektgMKauk6kuLh/Ljyo7yey
c3LBdZ/wUlzRRKQM1MvFoPN1li900rglKlbtCVnNw1rCzHHnyBRB8TQuENO/H18p
zrtfG9eSFP2pP+ESkIAzhRF4/+ZuEKt2FG6vVrxB07m3tzzluR7cm3QudsUeGdLG
3RfJA1ucLlPBxNmdSe5tMBRUNYfXWdesv4ijxNhjJnd6kjk9nlwY9GIDeDRTigoq
127uaPBDHPZ/1RQsSR/6i9ZUgcFLs4sPZPiKYl3vERL/m9LgdQZA5fnsQXw0ZX7h
J2tiStL3slmqLqM0+JAQpMrjLmn+G3uAo5kK0Lh7aZVdnw2OHaNGKXLx1Msu3o+x
5cZtw77Doale6t4MVekUNl6vj56foO9F9W7vddN2sSC83ZZ/UWHP3llNkFYEdpd9
Nzcln/WaGxYbT1joe2f8HoIecY78PIL2vBZexCvVDwdgSNKx/aqsZaK1G2uwf7Xp
S3XXSZ8oNehRiPbp2a27hfPXIGXB5+G8FiHS0TBjHgS0FGg4T9mvfkhpFkCVSVsL
odLA1z+Ahz+fnf6HU7hU52Yer5Wz5jsBLAHB4CU4GgH8HcVCiYth5mHDOYCk0o63
vGFnJEaeYMNK/m5/zg0NOcL50zrBXVndyeWo3YJ5eHukvzcgD8lh2CRJUieM+QLX
D13fnn+bD/FC+ChGOgyxp8CAm5seQ2TLu3n4QSm/VvhT5a8ahHRiFsahUJ8abZuI
6D1jNBobRZA4mqZtTUmh+xSwdm5Y4PGoTf7gBuYirV56FVKW9sQin2GCnV37M5dc
qV/Qwtfqt1JU8530l2mH3t0FlddHQ46vHtejdqPOCS7JqfzM1CBr9U6R+OVUF3Mr
XJrM412b2coSrWvkApk4AdrgXK/3DLLS2yIxxt4YpDXmhuQDXLBp74k9qES0KF+r
OLJw+s3gQX23MmHznkBO+b3V61kre7tWqTxrhOy9O+JQqTmJ6pa390AuRi7IxK8/
7aozzQtFzlZwVFulyHhsd0T8PLFf+UH7Gz7aecjqtatkm1h4QFLs0jvRSAN6cLcP
5EQ8C6rEkw2ENqtsC7UjqasNdpuFnyt+fBQ0tjrc0fK3T75jP7i1uldVKQGu5zsB
Cj7i7bsNmPCpFpqU5TugdSQdSzFJTDobp3gM0C0oTy0rU346vXollvOO38hB5eeQ
DLDocCeY9dbPe59QkFvJ/Mp8UohYXreObwj3klTuSM0Fy1T9Ybxk3GQSiZiAHqpq
x5dKlOHSDOtzdRHu2ryg6g8l1RwOzls1s0OIC4xGxzC1muKywSVJE5KeseaB9Mvc
3NtKO5EsAzsXG67tdD5iZb97HsrCi4X9kIMVLa1MFwyVeW5SR0g4vM/eGOwAQZx4
ZIxRhaFPF/UIMPTrNL4XhTrY9lfIoEDPLVA8hL95ZHGqqimmVJneK45m6KLxk/+T
uVTzszOuF/1wLdCwOjIf2vqC0TAcsIcMamA4aQ1swv095U4P9vjCmjlOdRxZwVnF
gZ0lqiV+BmvtK4hVB6/unOxUPG1VGhN7nmx52lyhT689dJ5Wo0zVAqX/mpAi4cT2
rzshZcVHP3mRXuFTv+P0QzzlZX7DdVW/iN2J3p9mm4M6b3o42Z8fHwylZokCVAz+
5hXR3L51ds7iF9qOY3N3JY8LRXbeW2QvA/Q1xCZ7AFwK+vd+w2LcRf64PrZKAlko
2HQXVSrz1Kb/sMW8wZCsTdwZ2d5PFFU7kC14T+MuEybENpLXqu8QbxnDToqseXkV
PbsHVeSZjm5EWFZWM7xEC5u73M5dF9d1XI2MU4lxfyuahYd/en21BU/naYJoW7Zk
f5mrfhd4eBj8JKLrwi7aIaaqIFZ5CkJPmlOvhGQM733XVyB6XwHlMJ+ka2Zh1Y5G
VUemuE8JAyy+RhSxddkTImYnBtY8vvHpTgYX94ECmmImbHKADVdnQhfqER+1QFO+
ST39Ozhc/8LEqj+TcIDFWH4zFxSYvcMYSikx+WYayxOpj/WtUfD5hPdjD6YjsUMR
10Tfgrv/CgVFWWSCBE7JIt3FLRzrqBuh3DfBOOebn2a5QhADQvLZW7HPYCNEtVd3
t1USmMsQ2TgqU04m0lSnm3/9a2vTwZ0CeIiX6gh2sk9eL0TJMA0vKuRl7iDMkN2H
FPcVD7sT4MJbR9gJm2kOcOvkcrDR5irCJHE19QDV+RmQ2YGJq/J/CU/KCQjj/A2M
2Opo5MqS0h9RjyBm3aw1ZFThVOspwfvtGXvdSL+8N+EtSOkPoDr6jVVktvg/4ZSk
tikQeoBDdNGGCvXcuqsZdAm2FOEcD1UBGgUsZcEebWv301WEeyPsGTtKrlEVquha
ESd9oyREJKKUY5oHfCe6zbA221GSw0Wbd5iG7HhUZtDvF752z3ObrTq65RaANwwm
CxgTMluS+dFnp/pio4XWvtK+JIuGtRUn6365L5sXidA8ZNRKPThOiXm+trFOBNG8
+uW2Qj66gzzSd265qFYnApU+JIfIQ9MNExLmm/I/tr7zearcsl738ouDlCl49izu
ePyXpSemSMA/Xj1suWw9AzWhmiS5co5DdySNUTDZjV+gQhb24glcdOtciO/V0+Ax
8iBn+1SCC98Lv8x4RJGaDETb3UElaF+21hosfYlMeZUydV6IfhGXmAsdxAABQcwk
ApPSHGCHm1PjBsRD/PS+Js0owVyi7oqg7AEbEY5GeE7O/syTKEiF6c0gblMM1kB1
/DxMerjQyd0dtwGpB0KoBGtfy2sQGwsybBBRqMsOcCDaxgBRtMrK8kzLo9hfIUWD
C4W5sC+TPW5mDMNsCt7hCj106i5ReqT+LF33MVuqaJU/XjJz9clCdM8TuaJ6acAe
Q9Cedge6wH01HTu6jq0QkjbJEsldI9VkfYCf9reV8m7PsnQVzSuBzN+MTUIag1yc
U8sz7hvCl3ChR3iKWhKDowJD6+kt9hLSAzECCFTaKtHS3znPuPscJMVzcqsOZ5xA
7W5VNs3Z8XByYrV0I2qf/NFjUcgNUyZs/xiVzHF0xBKSWXiwGGdvtm+OmnqzJzo2
0McYLOalhp/Nd1dFfTSXk9MLw3DVo+Eo1fXBY7PyUXR4t1i1khN8DalN3JPdXPgL
rpfJeDNYFAc1WX0g5mAnSFhmu+UYqpdQbpt+EO7FxY8=

`pragma protect end_protected

`endif
// `include "avery_scoreboard.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
`ifndef avery_scoreboard_sv
`define avery_scoreboard_sv



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
df1lOD3Czv2I/D0EF/U8avvtvdUpC3P+lOz2JyLnIK2fNRq7EayeodsUGnqB4U8R
9fbCqFSpvD3pC23ZF/WPjE+8VNOau9WWQYpy3l7uhbt/gYJW7i9IlX64NDU39epK
iypeDJ+usK45OlDM+ha2SK7Z8EzE1r411208dSeF9x4=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
2ik0jfe8svZ8V45ByllKI38UZVaHXd0wnPlx0iHnWoO5GCbAZHK6NJeJFdr87L66
/10SYpuZzcT8TOw6YHYBsJT76foOTKmqg41NFErbONkevW7KzUETdtD0v7mPfliV
Qs/FQIJsRT9AK8s6WWBL+VtSYLq6eeBvAN25zO9nxo8=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
ZRDhTXp6t8Fv/B0+sdjJLjicHLWC/QCz6JaecVlOw44tcB8MIEmASQbyUeY8fw4m
GcBjwSR7Bh9XgzZFXR3KYg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
FAv7RchcppCNv+Oq1FS00tJsL+lyrBXfxxzoaFK3UiIhfF0tJECnnMJcMeXdhfOk
4YhFG+cNgnsX0dtmclHWvxqeAJuTwqlOxbtvLbVdTcpw2Z2Ivd94z3E76rOYiD2a
IN2Vh3KssBwniLcuiGFC/vR1EagDUc1Xq3SeHzOEhj1A5LQhI+/K32taeH+Sm/fx
S1QMWOyMAlPYtjrPNier1EkYuGuxMrtbxMEYLou1e08iTXuWq+vg2m7C+aZlmS9+
wnZcxbOBVWW/rCRimHOAWDSjzOrVNcRaNVNOKnB3+x6hHiJjxYzQE3pLHtANDor/
38RVAYNwtDglGPh0UHmvgA==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
k2MdIXcs6lnYV0eQzHTZScZaC4DYP29qTHt53PX00nGr+2PMSLp3nSKSMo6ibzQJ
KYFMPTAjQ3oky7ZlkBjQkFbGFZUDVQEX++WMURzUidVEFAQhM3zyAknDQSHBn+TD
nwRKrd7E3H85Zq9VyoCoFGOa8wvroqWSZSEyy3gMuRg=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
vnB4JWgg7o0bv10M4jbLKC5trjifUk7+ih5lmTHrfaRO3A24SDxdxusYImvqAJ9+
k4uFhV7WfwIFoQLSsA6avbidC89YtlNebUXSDA1ti7wIn5pkqZ5aaaJR982nupNc
NBY6k1IjLVrQ1+fs8NYneSa5sT7ISKF4c4nzOlel7q4Q3QpWo341YDhH+WWTU2+Q
XsOzQRYL0ej+wCxEYF8qM/COWKE5qRO+mrD2lYVg3FkO3QPCwlXoQK2h5jTy6Wqe
uiLbIT4F+ThZpYEFLeY/GWSy6hwDDN6qdffCMtYRO/hmLDvBEF5HHJNRTtXHFDmC
nBQEI+jtftWviGsZ9bGi5Q==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
MrBN+0uPO1oYFIQUOZWgPBz+nNRVwU4nhudI7sRuex6WXRaR8mP12ozUvEIzZK0G
12u52Ertk1B5HG8gvaYoo5onm/qaFWcru9sFlSQNpM6haZvezJGv3uXUcp+ESb3Z
Dtw/KjcxeLYujw706bwDbxG/v2kXUQjxVa5h2i/S97V8j2ALL7WeUP0TeTxlMK6i
BFgoptyE7bWfH2dAZsfB5gA642TdCYQ5M37KL2AKtZoJTePwJmSbqMCZf86fUU5T
tkT/ofIqxNqVoHgdD0Cy7eSJHmGWtf3X+a2gb+SxAcAOzNV0+UHyDW8m6lNFFbE9
Qg46TrozS+cBqRNK9u/skA==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 5712 )
`pragma protect data_block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`pragma protect end_protected

`endif
// `include "avery_fifo.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2012.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
`ifndef avery_fifo_sv
`define avery_fifo_sv



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
baElWvXxNNcpyw/+LDkhSDIHJ0uTgNIxuS5r9KfBUf9bjkxTUuf2CE95v0LrTUAx
jL631SYcgPKzGPG1isuxWvZ9CzFuay3vLucxR+a0rqUuEs1C4D8FY7xB9l9r2xGJ
PcuKHMMKvG4uvV0ANSBICeps0aH09aGhLbMwsuGiPdE=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
P/FaMGxILvNkuhu0Ln26rZ0kx7DxnZfv1GB7JOr9R1DkdCN2+8g3mqeK87tX1/1/
IjNFupQ5ICnz9+4qXDucRS8gNf6d43DUP206EqRUMfpcCzdA+ZldOwK9ZV8nkGR0
v1+kGeoKPRLg33MX06EgnP06cFNxhd05CHelL0UpZFI=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
eg/DpDDEukYIe2Rr3QFdMvNkTZ/YaC7NCki8MtzwdJjuN328nHZI9FRIdRIulw5k
Gp0p/8jDLRxnxsGHtQN4YA==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
xNbho6Jdru9TXpaQwLdKQ+lAR8Yu3kUF9vAnP/IImsJ+nq64y0DR9mZeiSeWc2gq
lpKRUTffN8sBONBdI4zz8dbEKORAkI7Gl55wAXgT471VjUPsQqpW/lRrSy9IxjFC
0k2jrU1aQHePM6vbhg5eFerzWgw/6mRlDsexmh2jJI0X24PujQLmeg3ft/H06CeU
A/A59UX0kIQXoRDvy2n61NnRJ3Gxl9Y8CigDnisoZenlNQ3Wd578IOJxQ+uIQIBP
TsamBZvDGDEqj/TUxqCIi21Hsui0+E6+by64V5VWXnRULQyv9J8pNQEYLf+6Vn73
UeJJP0JqMd2mbJCg0XVl4Q==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
ihglOlrg7DeKQBm92xkr4ApQ1i1jJBjuRzwyN2NpVTa1lDutq5XyVUb1JOllbSrV
6Hcdvvh8H9s7AP2w9JbcOB8KGeNIHASg8Qk5jCOB4loM+AE/tWiHioipIljyopxB
N/NKN2GenSQrxtym3WSUuUnPv6CD7oKfdjiPZB8YIdo=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
i2h/8pwOWKTJNLTuJ7ZBOQ+vvLEYqiEUwq0jUydlGrNKMcGLKQMmxIvnFy9AcxFY
nuzD2GTxE9ug/o52KV0aPAheYnewaHRf/wYgav+1PCeqbrMzKzcq68dthLDOYJ31
AqBHSehWXOMhthNKAJtgJ9ZhHGmt+jVnSDxL5srheRiqlpo+Wvmt2+h91YNVCPR4
N6GYrs1fHdVkE5l5QFKoLQVLwDburDMnbLsbjO7PzDAv9HehCIustyAbNrs0z/8q
i7y31XL6Ah5tw6/ORp1Qr1laFpq9gMl1I2XAhuEgzrpzHZOCMNeavxuXMdDQ85/0
x1qwhCcBK3DSMX3hEkhtGw==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
Qtcu8wS8CmvypcrW2dt8WFM2/+oxjUo4kEe07qmNzOIcpJ7zBvfmGuhfEvsf+QsD
qP/f+H+0Kd0AFrqqBhnnmg5W5mhrF4/Y/GVhEgr/V9qqzViHJ27f53qNQNtT8ss8
3K4SjWd+57g4Nucd0ENz3DtotTK1dYvvGEiwTKZlIG4tGOe0y0iVx6A+aYmQUUsj
Cp9SFSWsqpTMY/ALY171LDJn7WmZ+6k0xZRmlsdGe5SwKGbXIVQzD9yUIAOwurJ4
Z0hu6fyCDmJAWV9l7AZhQsSOOJOFlvJILWAuAwM452rdbHofq6ZIrrUIHTECVvbe
I8vVk5pyHYKyxW+ADLvgcQ==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 1200 )
`pragma protect data_block
/ou2Ru6CCw7FRn0kweqH/pEPPcDPkhbb+Oqj33kaevGxr1txeb9CSMBvw1nm/DIM
Oq3IQvAKlkMcSWKnbOf48Hp8qqn5b7lQOKdrUXCTw8RtKZp8FdQGTZCZ/k48Cjzp
66OvXUYoeaC7RUoCYECtXMRkWyAT0Kvo58Ama3uUTFojYL4pY1+NENIZ+mPwLdnt
Vy1I4N4skbmOYAAROADswU4J91HThl6v6/Mj+8xl9tyGk48rlvrhan07FMec5pKk
iUU22IQ69aUtuBBdqVH2QIqeUqfi5BF/GXTyZJ7HYtk/xFKNV4H3kkXL110J946i
UHV2ZeIxQPBUH/b+yStNa+kOOwhPL3iB1/d08XxcaaZ8MTfMpgY23JedLBv0qXPO
+P52kgS+3Vn1x8JizjEv1zb1/4LeLcsuoS7hc7y5vHPJomIoQAnbsuh3HPOVoXrx
UUNiZ8Ykvaaw1l3/x8YvQDODj7W3iHpuq4tV9DIotFTVZ+KeacrZgFr/rwai+MjH
nsXXAKD6PBeKmp3JM1yVT+5af6tCEW3jMoWUVdpUhd5uf/uQyy2S3RByxlwFpQEU
whfCuQwD+ZFGrhF/bHOtMHmlc/rIa4dEfdelWVCqr7OnHVWRvRnCkcGz7twdrKHv
WxhadhjCf8X+A5gQmy55h3Z8BSL4w3xVCAseK+BGbP9KAsHGN8l/Y/b/zWuhddNK
52yHShtLNDy+VFzIh0foVfDiCjy6cEktCctuGGARPkhZTnven8JCkbpFKLJZYkDT
yYqavRnWErVS0OiRLOi8crKICzDsTc9LmwWik15zbEDVQKdF2QyWrEQemXyPeXCu
+NdCAiQXIN69VBBox3k24QUcVuK/Jf0NNSd7TRMEjfeEkQZ9fOHaw/Ng3Wc4nQg6
sQW4K1jdOJKR0MjbKSiGDNcqal5j0btpuzdxsN0vjvnKbBaWQ7UvZNoPqVsvTGs9
4TNhRmOGGjm2ac7il22YocNhDBukjOwuG4z16Hapxe36OcWRqf/TsuJjjDD+3ouh
q8EawqEHv9H7wNqDf4o7MoKz9NpjMpSNs62JKNAaLgsbFGwqBWGhF0XdiwCZLeP+
QHCaFOkmPV1EyU9pBo1qp9kirHfdZMMnb7vSe519C3cOdCGDA8GpA6s4er30Ei31
Y09JxC9HrT3bgXANOHL8rOuytZflcsDSbKB2D1L8uv+4kc2hWfN6CQjGpOQPBKG+
tS9RReyQ4OA23RfN1pfZZE6dAvoL/KUCIP7K+lNu3F4hR9PlXeKMtYTNMn23eVmh
hR8DFgiAZScdV3sbTjsPi2HSSeYje7OEI80FUk3JrXkTy/dWhJLihjFbhkGPH7m7
mAX7HiqYhPvdWvH4kB4C9iMaN9hAP/ouykJaEdkGE6kLk17n1bTpWtINXOYLS+zI
QWc1czwl3c0IR8lSY7rsp3Dw+pm7VrDQW5nGYgqG7tgLLsV9ZyaVWMCYXQgyrgqH
fm4uGrisdWs7gZlc2tcxKbRWCnrmKnzXe5+s91G7N8Upud3Ux2wCZj/cd3JXBh2R
EYdlsq8eFPkB9QMfLRdXIZmpWXhp5ywB7jB3oXgEx1hxPRdO2/GT+p1VYy/czRcd

`pragma protect end_protected

`endif
// `include "avery_rw_data.sv"
/*
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2013.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */
// avery_rw_data is copied from ddr_sim/src/amem_rw_data.sv

`ifndef avery_rw_data_sv
`define avery_rw_data_sv

class avery_rw_data32;
    reg [31:0] payload_dw[$]; // double word

    /* function: new
       new
       - isw, if -1, no data in payload, else, fill payload with constant or random data
               0, 1: fill the queue with constant 0 (1)
               2: sequentially up
               3: random
               4: inverse of sequential up
               5: sequentially down using start2
               6: sequentially up using start2
               7: start2 without change
               255: all 1           
       - total2, total number of bytes
       - start2, initial value for DAT */
    extern function new (
        input int isw= -1, 
        input int total2= 1,
        input bit [31:0] start2 = 0);



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
F1seAcCta+rF6HyFbabB30SNOKtOMnicr+KthaQHMjaHWmIrR7VeVcYVFMQ36Py7
4eIXNzj/nzQrm6qdX67W2EVLuuYY6L0jb32WlmL3rLABRvLeMsauRMiOLqP3RjcC
Mcihv62pVQthKJMBdoUK3+zQszXo+DpImoXuMHo6jZA=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
B37WzVlcHqSdRgNXM12/GbAbk8guiqhU4D2ny1T9Bb8eXn+/Hxdl+T4SiJ+w0Dl5
11YW1hhYf/HvD1dCY7OmNhfZ7D4qDsd+eAmre3yADp8hW5ELynxmb3ZgAs15rFwL
84sxhjHbWOJauE4dO03VAk11u8L4TXoMXZ5LAFlOpnY=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
SH1nxHjeQgM4jIuMyUxNZtvjdl2IEQMX50igGuzQt6fzCcSejkoMuDQkJTOUHOd5
gnKyK+vZ5nuthRuveawK3w==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
QiGggAKeNdEkOT3xFNm3yhvBsuhpAyEaQeHkfX333IUIAB9Dt6ute1/cqZ4+8cNw
/qQklvnkT6cGgZ7znDkP7vzDoHIB8ozLGG51Cy31/mOT+L7fvRjU1ycVs30zBBW1
8yndDLihFGeOhjaGxg1Gem+AIt2l0gS0v8EplDFEGyxJ4Gh0yuZMsG8q5gMKls+J
kYDa937Uee+9Jm/tJQ4+R3AOtVNw+IXig0DS3aIQ6Zf1z9SAw5zE5mYFw5mjizFu
bhsRI+CqcSf2fj1PbPERtG64dEr9E14ZgjMXb2TWAtJyyr9dEnmhchjC7BW4fsdw
KA8iecUENlD8mE3D0GxATQ==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
cDUbphwaoj/LMQxlLqQLuuQh8F7AqyaMqxVUGQOCyFRH2UYrEHSblgMKHZiAXPIj
qIrAXBS3f4IQN8s+p57ijpEm23CP9hUdba6DpGshrgH3HDxCXtVYuxJuSPfxnbF5
DZvRZBJ6+YZ+KdpuMY/41m7bwoh3lVSlAkpSSla/qG0=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
JnamSiMX7PHCcpLWQTAp2ryYi1vAlqFboKYNbFCdgpULVwf7cGAO9eaSrQNBS9Ye
HZ3GPyqIlHxgovxL/NwO4Dbf8s4Oa8Suoq/vSWWF8j/GE5Z2DAOJQSD2eozXbk//
jAnTUbK0YKOzQOXG/ltbYM1jJCJ8o9jYrwIrauDDP769BVJWTGUCEK5OcT4LTAQS
CS9ZZ5vW2Ltw9dNg5tL5lJ1+wJQyfYrT/rnus9cYKakVtoitZp/uod6qFqQMcCY7
6q8oB8AlJzEiFEl0Jy5Odp9H3d+C1sTLquOpWFINiO8KheIhrd3XQG7HE0hACDPM
Vb3/lL+n0y8uYrNXLzMrqg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
lctkeAWkibo27aOnCokycnunuRseWsrDHGbRShaOnNYl6Zxh+mYkYGQDz8k2tJHh
yZSnaOzljzRE4earJIN/tUXZtDl8Nq8io7Cyt2YrFGtVqg2ExVE4uZ/ovGrdZSwr
OE3td1Ad6QK+KUdQXzlCYLujNY3HcqExobp4H6s8jgNuS0BU6jRa4joapUM+RcK6
xOAuQUz165JuBDosJSELCJYiVKrcc99x+riY0z4JjhCWkVCbrlxKw8V+0/bRPZFu
wQ95r0Bjy+QwqIkd/qRhzPdddhcV6EBO6OM/fQb/Cyg8TB01MS9Z8TthuPi0JeuD
3LudXu5De3g0nVUNqMxecw==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 6672 )
`pragma protect data_block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`pragma protect end_protected

endclass // avery_rw_data32
   


`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
l7W2c/D9h6/03upKmchVsYtpZniMReCzHm99t+t2rBx5/PACgt711bTKyjAdkh5O
1l6myCrIAB4WbiRa/SdAEXQ1aN/1+VbLBUynSizhGGBXcctnluW/JV5wwpUwXLEo
R/K+MjDfq/KjtGBmxdeEVOyeWHaaRuZxtN1fPMKGfQU=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
SN7mhvPerbL/i52fA6mXBBsJyBczOc77vUaEsgLZ3hjeEn+WXrorVkLpvT3vm+kP
5rXWCMKcTfMAiouk9HI5YNMHQfeZ3x3MYRhymzQh9CBbvTMj88B69KlTQbykOCqz
AuAhWoRcvD+jqlvNvUvlhnUa/xgoyxRJOsxXIkqgtj4=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
SQORNln8g/TLEtPJ15hBYjuFyiPXLryryU3GD8ggM9XDlu9bgEYF6ffHhEk6MNkL
rF08HZKYh+4VSe+uFRkg2w==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
W4sTWSRW9Ck+sDB3X32fPrSRjHBkApCMQ1JWfK5uGGNp5aQWF6yefnSAG9BtHmmO
YN21R/BzdMkeLt5v419sGfkYsKK6OImvgSkLgRq0Vin0jCCMsVyFvtMEH5p1AXTF
iq8ZlqvPWoko1EuhtfYDLkhcFFj4oX1nBen7zwX+MT/+1fkQKzAxgJ9M+tVBF3yc
DqFqM6e3DdBdtJiC0kdmmZaXSCaSy3v1wX+Aw1JsirRvxyrjkKBokSaiWo5Gi0bY
KAMRpLkPMXrAGRtwpGN3SzYksgWnOMwODBtfmhJL2/5D8jIIisTNdYtcxrgnImai
hiR8AWMq2oWdOSjLor31sw==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
PIOAitbcPWwxtp5xWf2Shr22Q3aMRJM16XoZhZf2FgV1CIPnsh4uHImS2/wuaG5M
W47fD2iZLittQmYgT9CfVHbSNe9ZVtXaMXFP5DTILWrAUAKxHaHQBTpiYCO5+3pQ
6Pg3YV0LqtIRjYj+H3viegmAUG4wcr9foWz5/qYef/k=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
N2OFFu5kQ+SQC6NTbmjXRW8NEdyVdFAlWfyQ4Slh0S2I7cD+DhDbhzy4iSFOv8MH
l3gN61REzTvc4W1tzBEYmIN6mNTa35xNC+pFVgTE2VwlTu+qsdWffEP2vxgTwNoE
Iby3ZtAglNQGriK8j/sbmHSZMWEqmDhy+4FkyR2pB1657YuOppmM4Px+S1Vge7fh
U2RFaHdypm3jziqsJhZiNhq8U8SK9Pv7FpLOqOWLWBaCuJ8NlvbdB+PmoOEuNWWZ
xQrdg/P04lIXXweEi5d5E0N03ZeS55XclIPBFPpW1RCTG1fvCeVX7jVS6nXZ3/uL
m1w0LG5iWw5mX8CZ2BLHhQ==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
H7a9uySQmUth2wW5v6lRG2/PhMT9qs1bstD+7SguxXxIv/PKtr2PDLlxuvDLZKxG
RX4IPjfbgzIEJEUUt5NNITaXkeTBOytcPILz6Br+/gz4WB3oQqcEp6dEHI5yUgVZ
SfpyD4dM848pcnPg02L/o8MK5fk1DFXrsdYpBp0KUBtwCUgXHE3i9rw/4E6dSInP
ZWD3w6CqyohizDjdCrdQO3kWEmMIPm8BLENgJ5ZK+u6641TX7hOqMM9wngQWEokp
q94vmkhccLUno9QMqm9D327U1lHhhXr96SV8eGSkdDi5rqMDDoRLaKZzcsmTGcsd
O9kEdDA3oeRxUVIzRTnPjw==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 288 )
`pragma protect data_block
/ou2Ru6CCw7FRn0kweqH/pEPPcDPkhbb+Oqj33kaevGxr1txeb9CSMBvw1nm/DIM
G/pRJEVT/MNQibzhlWXgUs2TL6uUdb/lR/r6aUnM9S+Fi+FNVGvnvGkroFMGchve
129LqYNqAEJmoI2j/Qo0+EwGaS4ApqYiGu9gpz2anHOiNec+Y/9dZLZaM2gw5sEM
IjMpXht08xsfM+sE0Uhk+MHDv4Z3Q6aB3MykQMYikklxiKYHqZVyiiw2IfebzWhm
1tDAqvHGu8a7D8u/nANPKcUukKiPpioGe+zq6KPO8BWRt59mA/1AVELNVRSIkLET
pFeOjsOCxjMcgaJ+rW9E1MyXOSioLVPN+VRBniE6YPZ4k7GtjiTKUwfsMxUu7KSJ

`pragma protect end_protected

/* Class: avery_rw_data
   This is basic class for read/write 
   - payload [$], reg [7:0] data payload,
   - payload_dw[$], reg [31:0] double word data payload
 CLH 2019_1129 I really want to phase out payload_dw
  and use avery_rw_data32 for that purpose
*/
class avery_rw_data;
    reg [7:0] payload [$];
    reg [31:0] payload_dw[$]; // double word
    // Simon 180911, it is used by eMMC/SD VIP
    // CLH 191129, the proper way is to extend this class and add those extra fields there. Otherwise, this class will contain so many fields not used often.
   
    bit [63: 0] rw_address; // ??? CLH 171121, don't know the usage. If no more used, it should be removed
    int extra_argument; // ??? CLH 171121, don't know the usage. If no more used, it should be removed
   
    /* function: new
       new
       - isw, if -1, no data in payload, else, fill payload with constant or random data
               0, 1: fill the queue with constant 0 (1)
               2: sequentially up
               3: random
               4: inverse of sequential up
               5: sequentially down using start2
               6: sequentially up using start2
               7: start2 without change
               255: all 1           
       - total2, total number of bytes
       - start2, initial value for DAT
       - is_dw2, if 1, double word
    */
    extern function new (
        input int isw= -1, 
        input int total2= 1,
        input bit [7:0] start2 = 0,
        input bit is_dw2= 0);



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
N5U4S7eTp7JI9JEI1rOUcb/IDQ+Ersg3K9vTmuQLmPhqpX+aIgKaiUGW0S8Xz2RK
kdCjIn8QGo5lOcwysinaRjjtj7i8l0D5RrWnvLIwIIP2TZOR0IUeMhhAJwU0gGIo
63DG90rq32dlolaLGoWGj5u/I1tUQJt97g5SWDG9XvM=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
bGnxJRaOsYaZOKdPik0Dwf+0qsxWRXc6tY8ZPW0WnorAw0NplLRwnCxgNWHuCIev
fRbJRRlA1grPiwDvqDQ/pbbTZ6pXlEKnazSptOHRgO6zVQO1B0uIkTG0Ubd3SuE8
1M9+N3egPZgrBUp7a0dZZlaoISymABOzRNdzTsnpikE=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
PUHYi0nRkBJOx520K200CaDhOiuDTB3zPHjL1TQyY10pWsW/FP0rKxcsCLMihhdX
xdzTAnxf6KjpwPrUsh8Vfg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
hB8RH7EGugU3VqIHaBNLd8Zz+61AzRCmhb3lf+vK/6nJr4AA+lvBuEYMALbStKop
TqrqwODuA29kQnImj5Uh9ZDDNfjjqYakPJt+ViGwYKlmHheCUE+s0Btai+d1AJPs
axC8/92hT/UCr6dVGfI0mTn8y+wtaqL0ufi8gBWPqGAZp7MjeR1AjN9+Ghe2q8mA
iyu9FJUC6cqOoBmUQUoQT3Po5T+FPlG9D4V2jYRQTZkxorU4VL6Q9VejOP5BwxrB
N35X1lC1CMYdwn4r++/9kF/FO9zNnF+QZg+I7q2IfDSsMvJJPFeXaz8wgII7gJyV
tartwfDemmQYF8aptdmI4w==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
D7u23LW4uo4NfxA1kj7ZvZBbWO3SFZh9aothKC7ygVQAgN1sRxH9aQMS148vDCpZ
bKhO2Fbj+35ZU697zWdvCk3DPIXDExIG65wl3AMAwnzo440tDUYOBVC0s9Bb8Ov2
pDdtlgkVuweyTiD/qyDiIl7yJ5EVGE0wngYJM0n1YDE=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
ivk9e09a4n5b2Lsza89HISnA2zlXPjFC/9CqRb3Zr0hK2o5CQ1WQsn/21TvUpFJ9
qwq15468Un6ivBEJzu3N6sxrMA8BgAoG0+kKYbWxeVPjIX/dnTuWu7vxUK5ES+Os
JwzQpVl7nEnbTeFmwafF8abC0j9nmAsoVCrZoB26ohKweggcO+Qr8SKd5lP9tN28
SUkw0ouODDqAX4lszEyZX+KTWoDF1LDmonlq+InALwYt1Jop+AAlAL6fhPz1iRAM
6zct+j5kYES4er6bTOgWmoHN2LGdBurOg+0ija9cN4cOimVzOtFFnuHLI8J+YLi2
YmDQBq+AVnCbjhKty0kY2Q==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
F5nyQ7o7GIvsUFnHUHsJMY/q4rCor66YwhFd5fTPHlt0acA1WPzjWPn76O4UFL24
0o3rqpClTFLYV+bOF6WPtdkINtVzQ8if6QySbZc7jPap7xHdoxS3A52yyt13bVfA
Gu/Jq7Ct0CpvHHamodtwkmse1nT5jkBNXBz1qWSQrHPyT95kyjklWzK08cEpxTG1
WYYP+UcJjJfT4UL2Sz1qr2MRaNm4FIOnis/Q+Bsd0meB1MLKlN/xqslLDOY6fXYT
Y3tQsGFqyEqUCsk1lpHnOgjxZ917IOei0QuSdskyH3B+lcyWK7PZv+hepMz9vjye
9wGsyNLTdxWo0VPChKv8+w==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 10304 )
`pragma protect data_block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`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
UBnOczpsk5Xco28RgbI5B6tWXoJWLL6h4ec0rFcbxkBiPvNzmZkU3sT+0sQwHeba
gwU2PQQomSYsFSagLQxXy4W2XdgArHTTzidpihLCHM48W1+Hj8CqIgeIrnBmEm+o
QYcssxYPhX7xnaAr58RAbakCxUX/gVixEgsXkEo+KnQ=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
ot8gQW1scVj4c57P5XDfrBetITom2Fqba2vZRtQQ7MoB3lqkleGGwcrMrr4yNVaW
Wxh2Hy8o4RBJfQCZCCL1uaDZyq7H1sC8tMBsa4ULTNzyIDJoYRUUtvUrG58YgenS
XHupupyv0OwZDIe5fjzadL2Naq9/GN7QuLmIqfkdWTk=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
gYo4hZt1RZVeSxW/gGH0fLqMO30olFJmmTc5ja+wI4mHGQpTittq88pUKcTb6yfz
KcfVulcfDalX4rUKAPzF8Q==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
y2v3bTXjDvZ2IEngUmcuG+ZU9+gIzF71vDRmw8sBdZdezVDj3T1x3X9W0OfpTXxu
OahPuf77GNISg7q7GgrmAlwBubRUCckSzsVyN4p703hr9t/KNy9g6bVqdXDC62lJ
rYIQtLf5d7jK3kHYd9vu9RCAqAm4PvCIsaUsf1CUIT9DHLV5jqR2eN4hCmFX1vVn
j3Lp+rPFgTBFWmxT8WB40Z4QKRp3+2hQQyNeH0KR11dmqNAmxLD1GLsqO/PYjuIw
fn7m6JtvOHhjPgAJnWWZCxr92H/hneNBuS1tNvdxto3DvmApVwJeFrP1svAAr8qM
rkHWdnqDXr1rIV4Al3xr2Q==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
1C891xyTwsvUbgiIkl2Y2pD1WwEoy/+Tz9mdWTFUHBbx0fND3psktCMB43WwBKqb
pSlX6h8NCiUToyhljuZ+atnl8AghDotWPMbf4qmvfZq7oN36lzPQLPbr20Ijshsn
z4mR9SnWZr0I1ff4usVq2+SZ+rGVr8Dv2+P61lrA3Ok=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
mAOnajKiJsZonaqxd/cBq+flRQnpQ+PK08/Q6eYbgKheVOaYzTxWroqLzXO2OD8O
9fVBohGyX0feZvS3+R9Ppp0bemY89wPBfwhBc0ANgKySN5vJ4nWZSpYw60PSfcSM
995ehHNPrmNGaPQwP+q6UHOX7R6UCFj/HRnHjNO6XYLZuiCz/Z33RgxiZkNkvZf6
dbVLPBQ8GBmS/Ti8ZT01eFYNt4fvHUsYh1bZuGYZyPM2Jm7VBg1XduU0nBJlZ7gP
7cSo/bAKDI2LtfVZL+nTbVxmxL/Ulx5tlEjpt/g2G1lZ3vbJi6WYCmpJ+BDMhSvT
CFGpnUVFNir+2LGFF7+Qqw==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
UM4X6p4TiKksI9Vg74uUEvcTdeRuL8OQ0/Vjzozlh2g1+8I5L6079Wy/xUxxlcTU
H0TlOCvn38+waGNVl/b54TuDHu79AyMsvG+U2udxAyVw8CGqHDfBMkjB2UfsBQf/
E1+jn0ABooYu7tDv0nFxwcsu5pUYKckb2TjjA5nMvfE2xhJiCf+2YOdV/cOTQkXl
KycOg2jSAI63SEu4is65kjza/U6tGt1hsN0zcBcbpBQN5ZZtsChAAzxaO9pZqs3H
XXSmm4jtBJZwFhT6CLSOOSyLM11ffQBAxXyKOa43S/ROdkuxkc6BSHKh1ugQhDuY
nay3rgkiGwlORYwh77meOg==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 320 )
`pragma protect data_block
/ou2Ru6CCw7FRn0kweqH/pEPPcDPkhbb+Oqj33kaevGxr1txeb9CSMBvw1nm/DIM
G/pRJEVT/MNQibzhlWXgUs2TL6uUdb/lR/r6aUnM9S8foL4jmWAQx2T9VGr1LaBc
8Of2t1lhorY+uPRoklL8Fyt1kJ7AMM9AL1zqDa/jfi14oTQXRsH9CL66JU8VJI0b
04Oiszb74AkZEibaHJA9Omcq6ejuv+Zm70uQiBOOHtGu8hCBcx4vWsknlGAL33lw
svzaNqJfnMnX2b4TM4nEjtsXfSLn64Ld2GlfF1CGb8QHaR+3qDZ/J1CNKngUqGF9
UPYoQCY5VBxRjIf5lDXiXrO8Ch75GPS3Aie24m16To65sa/gjCYD4ligoT2fviQF
tOQ2kh5CXgbrJ7TrEem4OERStKFF4Gpo4ZLp0Ds4TkQ=

`pragma protect end_protected

`endif

`ifdef AVERY_PKG_HAS_AVERY_REG

//`include "avery_reg_field.sv"
//`include "avery_reg.sv"

typedef class avery_reg;

typedef bit[63:0] avery_reg_val_t;

typedef enum {
    AVERY_REG_RST_cold, // Hard
    AVERY_REG_RST_warm,
    AVERY_REG_RST_hot,
    AVERY_REG_RST_flr   // function-level reset
} avery_reg_rst_e;

// Register field access policy
typedef enum {
    AVERY_REG_ACC_RC   ,  // W: no effect                            , R: clears all bits
    AVERY_REG_ACC_RO   ,  // W: no effect                            , R: no effect
    AVERY_REG_ACC_RS   ,  // W: no effect                            , R: sets all bits
    AVERY_REG_ACC_RW   ,  // W: as-is                                , R: no effect
    AVERY_REG_ACC_W0C  ,  // W: 1/0 no effect on/clears matching bit , R: no effect
    AVERY_REG_ACC_W0CRS,  // W: 1/0 no effect on/clears matching bit , R: sets all bits
    AVERY_REG_ACC_W0S  ,  // W: 1/0 no effect on/sets matching bit   , R: no effect
    AVERY_REG_ACC_W0SRC,  // W: 1/0 no effect on/sets matching bit   , R: clears all bits
    AVERY_REG_ACC_W0T  ,  // W: 1/0 no effect on/toggles matching bit, R: no effect
    AVERY_REG_ACC_W1   ,  // W: first one after ~HARD~ reset is as-is, other W have no effects , R: no effect  (Write Once)
    AVERY_REG_ACC_W1C  ,  // W: 1/0 clears/no effect on matching bit , R: no effect
    AVERY_REG_ACC_W1CRS,  // W: 1/0 clears/no effect on matching bit , R: sets all bits
    AVERY_REG_ACC_W1S  ,  // W: 1/0 sets/no effect on matching bit   , R: no effect
    AVERY_REG_ACC_W1SRC,  // W: 1/0 sets/no effect on matching bit   , R: clears all bits
    AVERY_REG_ACC_W1T  ,  // W: 1/0 toggles/no effect on matching bit, R: no effect
    AVERY_REG_ACC_WC   ,  // W: clears all bits                      , R: no effect
    AVERY_REG_ACC_WCRS ,  // W: clears all bits                      , R: sets all bits
    AVERY_REG_ACC_WO   ,  // W: as-is                                , R: error
    AVERY_REG_ACC_WO1  ,  // W: first one after ~HARD~ reset is as-is, other W have no effects, R: error
    AVERY_REG_ACC_WOC  ,  // W: clears all bits                      , R: error
    AVERY_REG_ACC_WOS  ,  // W: sets all bits                        , R: error
    AVERY_REG_ACC_WRC  ,  // W: as-is                                , R: clears all bits
    AVERY_REG_ACC_WRS  ,  // W: as-is                                , R: sets all bits
    AVERY_REG_ACC_WS   ,  // W: sets all bits                        , R: no effect
    AVERY_REG_ACC_WSRC ,  // W: sets all bits                        , R: clears all bits
    AVERY_REG_ACC_R0W  ,  // W: as-is                                , R: return 0

    // PCIe base 3.0 p587 
    AVERY_REG_ACC_WMSK,   // W: use bit mask, 1 means a bit is ReadOnly   , R: no effect
    AVERY_REG_ACC_RsvdP,  // W: software uses read value for write to bits, R: return 0 (Rsvd for future RW)
    AVERY_REG_ACC_RsvdZ   // W: software uses 0 for writes to bits        , R: return 0 (Rsvd for future RW1C)
} avery_reg_acc_e;

/* CLASS: avery_reg_field

    There are five members visible to user: 
    - v: current value
    - dv: default value after reset
    - acctype:  access type, READONLY, RW, etc
    - sticky: if set, the current value does not change during AVERY_REG_RST_hot or AVERY_REG_RST_flr
    - sticky_flr: if set, the current value does not change during AVERY_REG_RST_flr

    User may backdoor read the five fields during any time. But user may only be
    allowed to modify the values at certain BFM phase. Please refer to the
    related BFM user guide. Use these methods to change member value:
        - set_v()
        - set_dv()
        - set_sticky()
        - set_sticky_flr()
        - set_acctype()
        - set_write_mask()
*/

class avery_reg_field extends avery_data_base;
         string          name;          // VAR: register field name
    rand avery_reg_val_t v;             // VAR: current value
    rand avery_reg_val_t dv;            // VAR: default value after reset
    rand avery_reg_acc_e acctype;       // VAR: access policy type
    rand bit             sticky;        // VAR: 1 means no change across hot reset and functional level reset
         bit             sticky_flr = 0;// VAR: 1 means no change across function level reset

    function new(
            string           name = "avery_reg_field",
            avery_reg        parent = null,    // if null, do not configure the field yet
            int              field_size,       // bit width
            int              lsb_loc,          // least significant bit location within the reg
            avery_reg_val_t  default_val  = 0,
            bit              sticky       = 0,
            avery_reg_acc_e  acctype      = AVERY_REG_ACC_RsvdP, // access type
            bit              rand_default = 1, // 1 to allow randomization of dv
            bit              rand_sticky  = 1, // 1 to allow randomization of sticky
            bit              rand_acc     = 1, // 1 to allow randomization of acctype
            bit              is_static    = 0  // 1 means this field is a static field and cannot be removed during reconfig()
        );
        this.name = name;
        if (parent) begin
            configure(parent, field_size, lsb_loc, default_val, sticky, acctype,
                      rand_default, rand_sticky, rand_acc, is_static);
            parent.add_field(this);
        end
    endfunction

    constraint constr_v_dv_same{
        v == dv;
    }

    // FUNC: set_v
    // Backdoor change current value "v".
    extern virtual function void set_v(avery_reg_val_t v);

    // FUNC: set_dv
    // Backdoor change default value "dv" and current value "v".
    extern virtual function void set_dv(avery_reg_val_t dv);

    // FUNC: set_acctype
    // Backdoor change the acctype field.
    virtual function void set_acctype(avery_reg_acc_e acctype);
        this.acctype = acctype;
    endfunction

    // FUNC: set_sticky
    // Backdoor change the sticky bit.
    virtual function void set_sticky(bit sticky);
        this.sticky = sticky;
    endfunction

    // FUNC: set_sticky_flr
    // Backdoor change the sticky_flr bit.
    virtual function void set_sticky_flr(bit sticky_flr);
        this.sticky_flr = sticky_flr;
    endfunction


    // FUNC: set_lsb_loc
    // Backdoor change the LSB bit location. Shall only be called before the
    // avery_reg is finalized. 
    extern virtual function void set_lsb_loc(int lsb_loc);

    // FUNC: set_write_mask
    // Backdoor change the Write Mask bits. Only applicable when acctype is AVERY_REG_ACC_WMSK.
    // Value 1 in "mask[i]" means the bit is READONLY.
    extern virtual function void set_write_mask(avery_reg_val_t mask);

    // FUNC: get_write_mask
    // Backdoor read the Write Mask bits. Only applicable when acctype is AVERY_REG_ACC_WMSK.
    extern virtual function avery_reg_val_t get_write_mask();

    // FUNC: get_field_size
    // Return the number of bits this reg field has.
    extern virtual function int get_field_size();


    // FUNC: get_lsb_loc
    // Return the LSB bit location of which this register field is located
    // within an avery_reg.
    extern virtual function int get_lsb_loc();

    // FUNC: read_dw
    // Frontdoor dword read (via bus interface). 
    // Read starting from bit_offset to the next dword-boundary.
    // Note that A reg field may be spreaded across dword-boundary.
    extern virtual function avery_reg_val_t read_dw(int bit_offset, avery_u32 bit_enable = 'hffff_ffff);

    // FUNC: write_dw
    // Frontdoor dword write (via bus interface).
    // Write starting from bit_offset to the next dword-boundary.
    extern virtual function void write_dw(
                                    int       bit_offset,
                                    avery_u32 value     ,
                                    avery_u32 bit_enable='hffff_ffff, // value 1 of a bit permits writting to this bit
                                    string    dbg=""     );

    // FUNC: sprint_parent
    // Return the path to this register field.
    extern virtual function string sprint_path(int verbosity = 0);

    // FUNC: get_offset_dw()
    // Return the dword offset within the avery_reg.
    extern virtual function bit[15:0] get_offset_dw();

    // FUNC: get_offset()
    // Return the byte offset within the avery_reg.
    extern virtual function bit[15:0] get_offset();

    // FUNC: set_shared()
    // Share the same reg field with others. This is typically used for W1C,
    // W1CS and W1S fields on cases where one reg field is used for set and the
    // other is used for clear.
    extern virtual function void set_shared(avery_reg_field shared);

    // FUNC: inverse
    // Backdoor inverse the current value (v) according to the field_size.
    extern virtual function void inverse();

    // FUNC: set_one
    // Backdoor set all bits to 1 for current value (v). This is for testing RW1C.
    extern virtual function void set_one();

    // FUNC: compare
    // Compare the current value (v) between avery_reg_field according to field_size.
    // Return 0 for not equal.
    extern virtual function bit compare(avery_reg_field tgt);

    // FUNC: set_print_verbosity
    // Control when a field will be printed out. A field will not be
    // printed out unless the verbosity reaches the value set here.
    // A new born field has default value 0.
    extern virtual function void set_print_verbosity(int v);



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
DBVxeXxezyVix151X1HlgL4g3jem00rXZWHZTF8nz+uGUz9NlmO8ph1GgiZoj27K
yPR5NvAWCFi/fhjpONVh3GgTl88m+35ZW+ntWXY9IX/gTd2NNruNrdbwk/HxAgYj
wnxbtOgq0Dl9QQxp+VALYYWUagU7enNhlBY9xEXfxv0=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
iH6aG5oXPNE23DPFda2SE2YTXVdEG/x0n2plREUn9TIjEygW9Xm8Klzm1a25tiXb
QkXD5cVjeERML/fT6dCTQo2qktkQeUxfWhucKGeRnIBDOA/8dQu9oEPuISiKlo0P
cOhva8k5ASbyLgM4eeCsFi0leziKiIdXmznyKdg8gyw=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
fGCDQ2Wp1kNZJit9BN8NePgBLy+w1GVLn55p97UBMZ45x16xniSo4pcPQbFUZ0fZ
MDR0I6XWC9mUfrEcWxPc0g==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
y435bYjrxNgnVPIGzOh9z9ZE3fhB5h+dxr9DkTtZfmFte0prxk2qGrOJL45h1fcE
0e3TxoF1UPJCrpqoMH3CPsgPisEtzEKFLZL6XFZxxBOh3XLN8fh3Znr6ITAfVMJd
qevlXhuhiONN6Hf8YIYfNovt+TkbgkyrqUfu/RS1GKytgeZ15F+zwwnuRAPbG/7a
pViHzq7PHNaZH1+92VvIaHU3H3buG2cHSDjtmgorr/YdD50mhwvZC42vhoWiWhdA
+O7G5ldz7auiOiW7bnzwW8t1fACwJ7Hrs6ya6U2kHWuw4cdNq8EWz6az9EsNzaik
jWq5RlDwlW6V0ud+KeiJSA==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
xnWLHixv4s15IfeVfR/zEW6isdIgKfBnlSk5GZZwLS/xHmEwqbwbeUzf9z43Wz+k
DEPazbB5aJoRXUba60fjz2hjRhAkYmUQyc/SO+mS8G/MSsX2aY7mNM3DCdz9Rgf0
uDXiQnTsFRf60R+OsKR4w3B+pzVbv6HDRO/R7svluH4=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
VJRrIg/UHrKpJ/MLDxeemfwWaz1OPn99yC87YAN4+WluTYSbGNu97ZB1aQmWPJLL
KcZ+ZGrEES/fLe6133SuKYyX95Vhod+wAQJvE8YqaqgmLHpeA0EKckKukvicdkvL
Ix/ZIx3in0DQqlKwk9dbdjHuJPFKyMwcWvLB8btERywk1zeiEfe8CZJ1AviyS5aQ
hQhtaz3Pj8zWzjtUIjfVb2Zri08P8/ljw+7Ybj9DNZ/7siL1pJxfZDnBV7KkBaPo
JOcLQQJiUFj5MAL6LJa4CpPWjrr8VCedYx6buZ9QFOiNa4c1D6emjbp9uKDU1Unx
TQXvf0SQGtYN3BcFDb5vWg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
k834cKBrwidejey+V0opmbridNUzVHeA8wOT5wuYci+ez7MZyNA+xqbpECRbzppD
IOfZAaIgqPzAIS7JuJgHa0kvgZv+MIGm9w5AbF9KEx3fJ8lwsgpTe9JZvEAkVQNt
c/DrXGtFylTLLoQf8XQZNYc9dsqcq3Kdb5yRC4/OZzRATrqmax6m9ph2BFHrywiY
+akWncFhvTmhBZzh+fhsx8RHiTePZDpJcuqiRB8PUOfXbv0/+jvQp+huEPr7hVJs
0Dyiv7CTgSI3G+CHS7xbGREQsAiMdhit3F+RsluvUqkFfxduL2BWw/6TgnF7W/OU
4by1RzIJUQ6ZJt6ujFpmwg==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 10624 )
`pragma protect data_block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`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
hor87FGplfJMFdvQ+YrhABc4TvB7h9MoS4pLfqrvDqSAzZHitnN1fQgZSKoEnEEk
7Ah65ddeYUFvo6c6QG3Ydx4if/nNbi6uihklg5aUfiMJyANwVajNG+CEAAvlVhut
eWxIOmL/VM+eO3tWjww75HsKc6pCn4N0CMgR3W7oK6A=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
jOq0cwNQzUW4g1qWb0bbrGEBMe6d9mUXMgk3OkN129b9S8ckM22NpeGPa9WDJDJK
NhFZklUvGOKXOmdId6GPNsquy0ZWS8xxSGCCdvqxDMsQ95S5CYMp8y1yE6W/JcZJ
sS92V51jIPA5ku1K3LvagpQb8DkXanw745h3FW3F6cY=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
deZrC8fQQJAYmzWrQcC0Rx/lHhYmqXcQ+xc4TPnO1d8uw22qpHCTUEgG9WkW2H3P
TA06/YEk6Z2Yhn3J6DmaOQ==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
b6zqV/Gmvu0Mk4z7BsICAF7y5orGQ0LiurKUiY112CA48esaR5XosXu+8BAdcHIo
0HbT5am36dkQe5dQkWOH70cEJLYadL1kycQY9GmSto1kP9gJibzwnNg5sfiR/04c
EgUFKZ+mU0BjrTKsDMvj2jhR5sRQr9e8Diji9jOKD69kxYDUThAGf/GpJKusN+2G
eBEZxFUzM0eYF/y3O3I95I/Axc4iaG1cNeys4G5Qj7b6gleEL2Q8H974GiRNaxst
TUJbNzPnBzj/PBmpF93rrfUOaT/F2TEaLwR5EJo+l4xosyVS3u065MkUu/FhoGs0
Z+kAn+8nuxshSpAJ2s9kww==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
Fvs5FQJlnQyOSbuoUjIvnhDIRsI9E5qZRHv2Vm0sMMzKt5HsEAw8asep8P4UX14w
gPHe2WOqsCfqg4pMcjc5uQUxY9lr/ecDHYpRf3mnNTwZH08QsxoHU+Tb51+lXVOb
TS6up6cqCBaO9dQ6zmvliPq9jnk+TliUx8oSCF8oro0=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
CTl/9IbvLZtgrBF/EXWTXoeaW8XFWdl7tu5FkGcpK2Bm9+niTWWzrM6WMhmfDTaG
rii0IkvWUkgMGyo7muJYGKPbud/ZlbXOaurgj0aekLhFGhB/tN58I8ygsRb+ggL8
CX/eeziBJKa9rEhKFvAKW7S/TBOqZxluT840zOQJWqtjANrPPuZK6s5fZkfPyxs1
fumq7F6T4dxfUE9HPYTua+srlbBCjLNBlA5Px9wxXqN6SLjcS1bXrU8kpsb9pl7c
CivkpbSWamPkRLQhX7CJovg6tvrdh1f17MtHZnSVJoDZaz1uILpgJr7rhotGTRem
i0su0RDiVsVKBAD/Qg3CVA==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
mEzAtAEruUfuE3p/bjoKRNUt63y8GzGJBoNKoNq7PLpEvxOISB0jVh7f0RWWcbsX
aPh4bT+4Z149ZAAJvFljrOhV2r390qGXvk1AA5Pxn5B8Yq2s8VgPgzNGKMre3e8L
hr0vPCi6sdSdRo8Z7MvwUZBMn7wM/+QWU8In2GND25nqnKIuQ/uRduwBWIIrLoJz
Ge9lUhweuviQUJdS7t8lYPIgz66FHsA8oQwrtR9YBKcwAK6kYPWK0ZL9/59Ks+jD
vDvd/FlHtq5xIKqI85tfK8q5/gSA02ht/LS4Xz/vzRZNUrjjp9I/Jc8K8zX641Ge
ZGDEdi8PMFwgBFhdDj5qxg==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 6864 )
`pragma protect data_block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`pragma protect end_protected

/* Class: avery_reg 
    This represents a generic register. For example, when used in PCIe protocol,
    it can hold a capability structure.
*/
class avery_reg extends avery_data_base; 
    avery_reg_field fields[]; // only available after configure() method was called.

    function new(string name = "avery_reg");
        super.new(name);
    endfunction

    // FUNC: get_size_dw
    // Return this register size in dwords.
    extern virtual function int get_size_dw();

    // FUNC: get_size
    // Return this register size in bytes.
    extern virtual function int get_size();

    // FUNC: fread_dw
    // Frontdoor (via bus interface) read the register.
    extern virtual function avery_reg_val_t fread_dw( int      dw_offset  ,
                                                      bit[3:0] byte_enable = 4'b1111 );

    // FUNC: fwrite_dw
    // Frontdoor (via bus interface) write the register.
    extern virtual function void fwrite_dw( int             dw_offset  ,
                                            avery_u32       value      ,
                                            bit[3:0]        byte_enable = 4'b1111,
                                            avery_data_base modifier    = null );

    // FUNC: sprint
    // verbosity:-
    // 0:- register name, 
    // 1:- all non-reserved fields
    // 2:- all non-reserved fields with all default value
    // 3:- all fields including reserved
    // 4:- all fields including auto-generated fields
    extern virtual function string sprint(int verbosity = 0, string prefix = "");

    /* FUNC: configure
       Steps

       1 Create dynamic fields if extended class implements it.

       2 Create auto reserved fields to fill gaps in between.

       3 Link all fields into fields[] for normal use.

       Note that fields[] is NOT available until this method is called.*/
    extern function void configure(int n_dwords = 0);

    // FUNC: get_dword
    // Backdoor get one dword.
    extern function avery_reg_val_t get_dword(int dw_offset);


    // FUNC: sprint_dword
    // Print fields' value within this dword offset.
    extern function string sprint_dword(int dw_offset, int verbosity= 0);

    // FUNC: set_dword
    // Backdoor set a dword data to the corresponding fields' "v" value.
    // a field is readyonly, the "dv" value is also changed.
    // Typically used to mirror a register (eg: apci_func_info.sv) 
    extern virtual function void set_dword(
            int             dw_offset  ,
            avery_u32       value      ,
            bit[3:0]        byte_enable = 4'b1111,
            avery_data_base modifier    = null );

    // Allow extended class to allocate fields of dynamic size.
    // This is called inside configure() or reconfig().
    virtual function void create_dynamic_fields();
    endfunction



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
hmiezzX/kzR0btCOtXEfRxhum5/VZJiCyyFc9GkhY+a78THouxUaJQWeqqA3X/0R
cIp6nyW93g5DOoU9Dkvxh70POSq9Y8GU/R7rA5n8M5daEwkHWBtV13wHvPu9HUrf
Gj/CXaVs/DxOpdRYlhKB1MVts1aQr1Fkps275u4U0uI=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
mtdAwPC7s3wlX+SqGWkCTo5Mf8gkeVbIE67kql4dug6JdEzzszeW4I4uMwt02s4p
HTJDzDu4CfjaFQcBowATXlxSqDs6ofl1W/dDJ/pO9jLP7Dop+x2VHgSETUGzU3Or
e/3Hh3xEsifuLW+a0ELh9tlxEzLfqFemiuQmnl4d/qQ=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
LcpOdGdoqCQ2rX5xNj5Q9ReAydsF80ifjBLXMacpa+DfH4D039zZHRtrS+Y/Z4SO
Y2yjj9Q1rGBUidmi2MogXA==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
AmebgFfPjIXlc9ChkwaE+7aEkFlgaqS7ceS9wIgRTAa0oYk6Jg4Yq4dNypXWQK1p
Hc+ocvP8DVoGsa3VTUGwzqVv23dOUQ6PldaGlbRvLiKSTHtgBlYHy6Q/XtuzclUm
RvomCuDtkb17vzF8D9huilbfms3LjeWN5e1sNGUlKFlmeikW6b6G0Q1v0xEOaA8e
6ROB/NiKWhQq1wHmhfUr/WMQco2HN032S3rejcqLQMcLzRD0VSvns0BsYjJXjaf9
YrN/vU0ZxPhaNGtK3Ig/g+XeaX2ONcHtSj//FOR7ro1dL2XcfoBbhgdLLMQtGtoG
l7Li24B0z+z2ZITyAU5RRw==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
g4bSSx43nqvGtRsmmQ2hJCsqNDamCy8aBaCxIpM2rF9bsl/LYnL0MH5qvmABmQ9f
Dbvg0B/WNyldvL8coepdvg+D4YlOrtoaEA4BtU4PDv8p1JxDuV3y+ndPWlyV48lk
lUJhwSnewE5q/3B4db2hJzxpnMXBnU1eqvwQkRwpqFI=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
hfSRHQDzEHceU50i1XxgRZjiCuXWFGCIy9soETEe0cH8H34GShOlwudJUBqzLzoO
YrVtAx7K1JW0/doazshFTYmv3DbNowklvASuIhsAesAtVuRvN1d8dGtlAynxhXd/
sqLNQQPQvVNRpbWhjdYp0LYZbhUW0faM6V8vDNB2IQdK4iHxVsGwbnU/wwYo2iBG
4td42nV3bwAhlqnnceEblQsWesQspTn6h8A+jbnoYJKQ7XBqeNg+cSYrJWgd6OAt
0aWiM5DLBfyZCdtkMcdHuAU5jmxIYDgw0yw1U+qhRZDTcG5CAKVKAYLfDSVoe29U
7wrbXe88xTllYc2oO88Yyg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
kMEmK/7xnGZS7EtrYuHGjOyPADkolGHmH+lth58DOxZq4Ulhs58IFEwOHCv2QQdD
Mr3117MzwoUZs30gY+OZ7lYujh3M8alCYOQ1pGbeIlWhJfoeFwCDUZlasGyxeVnw
rSPCYbsW8LMovn1cPU4C09FHjQ4xflV/hq3YRZVe+yi0/cEi7R0196WnauaNBrHV
SPOo2LHw8Frnq6pyni6x1jpxroUBZVAAer1HBsEYQfJRzZ0hWfHjqEfDfS13ce8n
QjPLJPX0jXeMFi2TNk9gRcLRw33pvNgSPT1mYmWLvVKRtcGGa85bEiPWpeB7u0Pd
Ra/15Gct0tTp1rRupfqYbg==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 7056 )
`pragma protect data_block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`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
k5ce9p5MwNLQO8iG3v1jqtmNU12nfrsgn3+eaGfiqJBqxXpFVszqTZIo4aVwYooi
da4Bgo+SRhv2QIuaIqhSRDXbYouU+Y+lxhGvprpYUwdohuklenNreKTERWYre4tF
Q1J4xaHaVMb8byDgCVI7tEGdrixiX/CsK/JFKsGlL2E=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
hDr1UfqZU80uCKY9jB1YfZwgxGh+WilF6ClKI2B3z4ph4/BzjGPi+wwdjNZOMxMn
ERwgOMtrpmw4/R7kbfsOZAXv9jLAPDISHegBpvsk3iFhb5ySsyPjY133Xt8u75QF
BU4K8jylmtgv5uQRYzZRyjoHWaMnWtInpY6gt5t5QS0=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
Sj3htcaUhvSVy0t0BSxym6gkYkpDzaSLteM/xJqaPs4Y9yvF+E38IdM0B7mFAYHq
X4Jwgxp8upE3y2/cT7wh9w==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
PpzF/IOu/cOkl1abvc6rI/r2KEancnjzxAwCw+CsPSgYchy67IwaK700A30pcqCt
rOFOQT2hW402EEzKI0Mv3QgUaNhYtUa93VOiRCS3IDExDk/ALMZmkXNEXA6m9FiE
3pmmN4YK0ufH5dwL1IGcB+v6SSs3zx8OTLRygzaNUh+F/BY0RK3NbLt5teeiB7V4
+TSYkOh9fdjSAQjSKsPjb5dOXGKh1h2xfm3sfqBkI+HcmzVhSQo0ebGi7tIpg3cR
OJVBopfjIP6SnMnOmi1pAMdz/7uIs9zhEDOC1yeVmsjNOf3GCsS2dVubRRf9dWM4
BIwKM3VyawjaxUJBptQDQA==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
aYNfe2fR1xbMlDVJVwaTTEbzPOWHwRZchnxuRH0QgqBwMNvEB6AzdxS9twnTtmmP
O5OESu7nQD30DXDLo8APTLnutX2ZA3ZPdg4N7lhfRH+pJbRfoSp1yd6s1ktk7UsF
chjS4o7Xk/Dws8DtkhLNj0WJ+xijzORs/Ja9e8eIutE=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
Wgvuo2+Al1eU/cRbjTkjofCmEvm3nGC2M2qi4oCcrd3WdioQFuoap4kNvUYV9JE2
oFaATLkpZVZGHLN1WleW1DTfcZ3uV6/ftxS1XV44FqnABxnC4APF9GS9/MLlsQF3
GJk4k1gQEHM7fMe88PSAhH0xGjuCWtWUDSNrBvZ0WQ/nifuttPjV2q9WcfhqrFYn
D3xrHNJu7KTQrNGgbENZMqoEYkqXClKqFHDCyWLuuy7r0XIFK2EUiLdc2ido/Sh7
C6PajHY0upuHTMi6u3pFlUAvytZhRiQ5XmGTjuzp7JRE9v9auOBWCAyD+Cm7IjnB
BXTHfpSgJ8GrNRvypwWocg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
l2Em4MjgcW8HYl9QnK2KATMPc+eGF9K8yDIiMCT6gHpjhedN9tLtAoFv3FMm/UPG
8WJrQigVT28YiJ7HWd3phm1sbI8x+dr/JJt19VbEENJBXzzZKeBqmQByAL3GxAuQ
bU7GWmtVKssS7+BE98bvXxwVvOInbGzdju3AhmPbohlYzCfGSJspCsnXHtVf/z0y
vPm3S15VlNiDnyrr4QqE1T1EdMsKY1LI4h5dc/oPOwVnbLa76Q3eEpZcHCHJ2gfB
X8wCF0s0U/qtBr/6N6rFDjbQ3A4E9rTbEt+NaN4Am3ZEixleBFIalNuT4RBDoGtT
Sax2RGPc1SuDQ7cEfy+Okg==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 9968 )
`pragma protect data_block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`pragma protect end_protected

`endif // AVERY_PKG_HAS_AVERY_REG

/*                                                                                                                                                                                            
 * |-----------------------------------------------------------------------|
 * |                                                                       |
 * |   Copyright Avery Design Systems, Inc. 2018.                          |
 * |     All Rights Reserved.       Licensed Software.                     |
 * |                                                                       |
 * |                                                                       |
 * | THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF AVERY DESIGN SYSTEMS   |
 * | The copyright notice above does not evidence any actual or intended   |
 * | publication of such source code.                                      |
 * |                                                                       |
 * |-----------------------------------------------------------------------|
 */

`ifndef avery_encryption_svh
`define avery_encryption_svh



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
Um427xWLDA1wVTkJjlBbCbtmH8bpwbPfd3gQJ62/dXqcl2EofY6ZSSOUB0fry77g
pgsEVqIfRLNV2NLaafWigY6plcAiPoJ1ZQhKIHP2hIC4m6u30tfath4WcAstYJK0
2dStH27tsEfzqjVDDUwo8CPEHqhxWUKkuPFoNdmk1lo=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
qAFPcLGl7/IKYxz09jaZ+Smq/Haho9M913DoCewMXOcbK+m4qMXsrdPQzCbMJplj
vaX83h5RVYgd5BfXcWbKrDvaaJcqjX3bG7Uc9oId31hGte17KwuynCGjM2ZoVIo7
BaWkwoQZzn0dfRJ4VwKvyTxvw0s4JKw3jxfFKatc2hg=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
qzkydyYSppgzbX18wxqrANUqb6rWdAXIoe219FTVviyNlae2h3vJXWWIw1Retxof
xImZby7vFckg3QlLJhnnYg==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
VgT1Qpeq9bH1VVK7rjDRRX6CT0R6zFvB5klV7FdxTg2Nrn9MS0Skay6OE3R2PPB5
PWvWSnc7cfOJ1Sp/7KJ90HQaNj90JQpDNUEdyL6Q27kFwMahpVgDWKqzNV1RlJ+A
m3sxSeADDma1A0KQDGvB/uspClp6wXYD6cafDgvsgbE7ZAqXfSpGnr7oMU5kLuJi
gXql+rbMVZaDhvigucI3Bf6RIgd7Ke3MpnpMR5QHIovtrD1Cny6VDLRJvIJRnCnu
S0xh2enHGiecIX4zITjWQ+NCudwTXRBnqGK12lorssU8AgijiSgL6aJU/bO2RL4X
2keK5fJIwp03s+05a7tBGg==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
IdysrSB2kLdasGmL7ffrglGwbFGc47CBlgRlODgDHqKTqAIGrlm4h+AHjbEUZemt
Nqtk6TkOp34k89bsslmHGuT1pLzWZmLo9mDsfFc2YkOS2cCMMnPZezDEmlG90IK4
iV0rih0FZL2FvuZrmPpc0E9pT7d9SQZEVpKyJelXu6A=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
KLEWJElHwHKKBRqtMDtFzi+bq/TLK5mLpS7txsgd0eIbGblWGVxt8X6rYDxMEUlZ
8yqMxTf9/672dKYhKGd2aauV5Q2s1TuZCMNmoKA+ZqzIGJPY+ETkAANh6dHIRRel
ws2RLhyTRK6TA6C0zdvQuP1+eZVXGFT+a2qpfkPZm1zkl1+vTl1BssrYoka64CMy
AjDWkPzDS9ocjzeENaMpbQ9+i9dNbrPcbb404+qaGS+Y52Yz9juk1/b22x227bbk
eU2EMtWOzNKFYnKr7pHKClMsszvgUwYreqzcqSTAp1W/eTCb7GyCY1oFwTPevVI4
CiP43wqWBGnWmIdCH75jRg==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
AfY+UUwDW6BCmwQEZgQz+ZQF5B0sNz+YY9eDPWpPANbvwmld6YYWb8GL9SBaLlJl
qjLhvPRndS0/MSGAUeVy5kcBLXmA93hyltCApe68cBmNOCC7zHL2xk8/oYMc4KTm
CHkh5zsGqn1fsf1LDSxagEUWG3o57DF/zZLb/wKyfy5is7qJoYlEYpS3hAsbyKbN
+DLLdq0MViJbUJh+367DmDro7CXwnHtocJhxam9zODaPuwsFcuTwNUhWovKi/ZJE
CrafDuUftwo2jOEbaQUBYTHbwrxMmqckiqekLN4wZBt+NERqVoR6KuhhEVl/GZZ8
4jX14pL4rZER/RkiKKZ+Fw==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 131984 )
`pragma protect data_block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`pragma protect end_protected
`endif  // avery_encryption_svh


// ---------- Avery PIPE interface ------------ //

// Table 6-10 Message Bus Commands
typedef enum bit[3:0] {
    APIPE_MBC_nop     = 4'b0000,    // NOP
    APIPE_MBC_wr_unci = 4'b0001,    // write_uncommited
    APIPE_MBC_wr_ci   = 4'b0010,    // write_commited
    APIPE_MBC_rd      = 4'b0011,    // read
    APIPE_MBC_rd_comp = 4'b0100,    // read completion
    APIPE_MBC_wr_ack  = 4'b0101     // write_ack
} apipe_msg_bus_cmd_e;

typedef bit[11:0] apipe_msg_bus_addr_t;

// PIPE spec 6.0, 6.1.4.1 Message Bus Interface Commands
class apipe_msg_bus_transaction extends avery_data_base;

    apipe_msg_bus_cmd_e  cmd;  // VAR: Message BUS Command Code
    apipe_msg_bus_addr_t addr; // VAR: Message BUS Address
    avery_u8             data; // VAR: Message BUS data



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
c7Kvo8EByb6tk5lFxv/Y4blDU6X8EbJRllr0pj5THbEnSPIVBL0p20221O5EGAbH
RfCxgKgY178bLmplAJm3uvai2RPZo/35nf8oAvqh2zgGysK0pLsxZQqPwGSeESRI
nmrYtITMrxymGs44n8aoMcQSOgKl0v8Y/iV2wX1wdAU=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
DkOfbqajVLpTWzaAmfnV9XtUd2ernUeTfYm1IdNrv+7auwLvkW+EXh/zsbnnYVT2
4oWHvnBM2bXizb4+RNUIB4pqjpkAIHUFFhJN+EUXeyglQP+jFydpHeGPOCx8WMjO
IbybVi86oi+QoX4H9qw1j8uSJglcbLmNZKBKBl/quoA=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
byJugaXLiHSNpHSXUvexKohG0+DBvlbYD9heLR1USI/DnoCwfPewWVu5qX+aa9r2
Wpbt+1gK1MvIN9j5YJtVvA==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
awdi4TF/r1Q23cF9LVndqke0wlx5tmUrl+6krTJgK8NpFWQ014LzYXL8yTVo8L3X
bfw8//kugp+iELfZyOEqKfTNWIz6wTG5R37z39wiq/E0qIgzpcG3IG68iKJ7O4eu
yqbbrcn9Lzq8Yn+iWI8V2Rzzh6aBu1NpkPT1qzZAkU9VxWLaPSK76mfgzav5UCtP
BY+IwgZSYN2fK9RiLjbUTHvS4/8lQzpGidU7uOrVSWcyeApulodglJGgYWupwHs7
OatKYgZDoMHMFWI1DRZMNlyN0JWzMeuRDbDTULE9BuhD1qXyvY/x/ilF8D47j1zL
0EmTm7F2nvpzkPReP4GLuA==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
ymjh2lXOD5Ays3txSm+0yJNbP2c1M054UJ+WL16PVNwhAD5ABh4ahVuC3DF3z/FX
3cYDiR7lxWV/x2WK+a/a9TB74rSzePDQ/sdDj/VRG9cENG8DJfExZNHzjTj5AID0
IGcmUltLCq/E8RX+V+a+cw/oV2PmMWXi8XMY7C0K3yQ=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
JUxRUXPtbTYGeUiEgmst4VgWYO1I7vJQNjH6uZmraumrRuLqLVFBLSsylL+MgWfq
Z7sYeQzcBBaYHiHh/sMeIQ2ZCsho8/++bfIs4zfrTgmPQrCSk2vYSpNCxf1+MSED
ayJ0N0uX1SAOJgcKegS6YXUyGI2MR3pEh/nC10cPoF9KipbXFvdGBtdNoG5Xo4mh
BnGYF6EmX1ri7Gt5AZpoJwQDkPjkTuKHTZzLou/vT+ywz6SBWZBdO4QdkcID1MjM
V4RBfhwKQO5o2uHmKIkL56AXsmoyKqEvjKw0ExwehTj4dpal4qOeBWEu5Dqkhu//
6Teg/Xxim9TyAFa8uc4qJw==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
gFI/Sw0f8L/+WiC+O7bIOxjEgAdZb6KH8C/cyAUl1vGPuswuKyf/EEEKqkX2RO42
F0BRYITiLVMvtsYhVJQe5ylr9m/hJgImbA891lwLouqLhb2lV9hjlN66ZVrE8Z5g
ATdmj6s/oOdT0ft+TkzWQ+Kq9X0k+PfpyuoGP4wxGbkCfe/o+Atq6+J44/n5MoiD
pykJnzcIASwMQc5pKmDobhxx0Wo6+KQ7juaiH14FzG0OeduI0QM3N3xWZAY7gRyM
12qHgsNUWvGjrlLYdxecSbXo+n0Fg34C/sxn1vrv2Bcly+dB3GbO+AS7h7UiD48G
r1Hg6AUzHiWH8KA19n90mA==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 3344 )
`pragma protect data_block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`pragma protect end_protected

endclass



`pragma protect begin_protected
`pragma protect version=1
`pragma protect encrypt_agent="VCS"
`pragma protect encrypt_agent_info="U-2023.03-SP1 Build Date May 31 2023 20:25:30"
`pragma protect author="author-a"
`pragma protect author_info="author-a-details"
`pragma protect key_keyowner="Mentor Graphics Corporation"
`pragma protect key_keyname="MGC-VERIF-SIM-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
kQ6pVYyG0L/VA7yUuQ4PlBJVO8YaOC4Z02vY6cpWezOfuzZsXeF1hMr0MhOOZUhh
CDCBfsNSAWodAGlcmkUvB3pJ7pshA9yoE49qL0O5cenVIVtIfYUlIZipSfMt8M3N
cU/cqEJclV9hubVlfW6eIqEu4cduOD2++MUzfU9XMDo=

`pragma protect key_keyowner="Synopsys"
`pragma protect key_keyname="SNPS-VCS-RSA-1"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
rJnPHV3SJLwr8Lte8UXJzjvnvq74L7CX2lOvkeFKkj1g+iOnUkZEWjCcpWiL3n7X
tYfOCbpj0oOZUBF3AqFAlgKIZy3XTNzfDtHfCVUx5/fPSe2CnHNHUAi9ByrcSoZt
1jsEQQlsxZXrF85CxJp8ozmL+lm1f4DRPgWrnNrtQzw=

`pragma protect key_keyowner="Cadence Design Systems."
`pragma protect key_keyname="cds_rsa_key"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 64 )
`pragma protect key_block
Fmf7Hoknw3Kg7OAizDvPUDY9DEZnT9uI2nSIWGCQjkUiL4jPmsrsTkmhqMlL6p4t
qXUYIugnoeGSJbm3K7c3Zw==

`pragma protect key_keyowner="Aldec"
`pragma protect key_keyname="ALDEC15_001"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
pf43JPrCOIRE/WMHMt5ibhZbubxmXlKsVJWhL6SkRXUhMTJmcYnAEn7TZ+/ifL73
INBXXdmQzUCn7wVeq8NEVTxN0Fu26WXK3u1U5+nxeJOqrXsvEn3IWwuxsgFdA0C7
t/j2n35g2nRVeTRc78x6dknyqxAeEHegcRtG0J9kOrS4KtlwAFxUirnfN0WPVBKd
o1BMpXh9Qo8UdQUQKgID0spJsXexmC8PihdRfpdMqHbZU9JUhlZ/JFXtzXoA1k+Z
pP5U/DR3UM2N/X/cK9jB/gyZ5mCN9J/HiYEG+TiqOgKiSefNdIST+t2TiBHJRCDO
L5lFed1jL4Pk7w4f6dhC7Q==

`pragma protect key_keyowner="SynaptiCAD"
`pragma protect key_keyname="syncad"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 128 )
`pragma protect key_block
MXhWzmMGFurgQgAZrk20lm776W0ts5fM7gBvYOrmOtKIQAuQpTOs71nqEhrWhA6r
pIzE6t8dR+SpzMCLa/Gl5nsTPJOZVZZ3k3W5mRrnN/3ApJ5Xit4nYpS4uEb2/Sv/
3mYCGJx4eRNWFZFiajs9JwoWcjfUF0ZYHIuTjwqmiZ8=

`pragma protect key_keyowner="Xilinx"
`pragma protect key_keyname="xilinx_2016_05"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
NxlinPlQA6TXNfhbxJ5+xAO7UZQ7sVMd4J0TdSt0Edhtt59lg3Qf7nuQYdGUPBgJ
YcsC8bRNHzJhQan68vxqfUCMSlknjMygyeqPH3M8Yd1l0H/1rKWIUsoIHgoyhNXB
vDiI1QgF/FqfRF7+z4d7/0m7Fopgh4NQE0mkoQMicoz60eE/3V3cWTU9lEW5kIQO
9JVRWIhZzoiUorI0urlup9rXsmtqw7Qrp0gwgG3XhXwmKIz7BPE9pb4mRKXjjNQL
2CAh8mks2qMal9IK+4h+io/9NAx8XQkM0AIoSHoF29W2i9+Zr9ODVVkvJlDKIVs/
vUrG4X5J7lUXtjYUjWpd9w==

`pragma protect key_keyowner="Metrics Technologies Inc."
`pragma protect key_keyname="DSim"
`pragma protect key_method="rsa"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 256 )
`pragma protect key_block
mMrtNcv8qHK93qZCwYMZBlQPDwz/H4nWFsvRx8CpauZuklT6X2GzRHjdMr5FK9fM
F6eZmYShxPSmoH0hkAsfAbSIdzybKrbJKZX0iIrjonQZO1oy4nKEBOc4d/1fkZAq
JbWRdPe5AG3WW3t3uxw3uOFWo5M+f177N/k8n/zrC3NE8TeG2q1YpsoHirV5Fse9
m+MICWKbhz5quWF6H385QS4fHwy58HtwZ/mRpmC6M018j/SwoYhNvdW17MwRtiWE
uiZgWoPuUPMFs/rc+r8GP+d/L8EoRD9DqbRq8EltnYBK1gxN7daAO9DIyRIDoqyE
XQOuqHYcqoM0H8o/9j6W+w==

`pragma protect data_method="aes256-cbc"
`pragma protect encoding = (enctype = "base64", line_length = 76, bytes = 208 )
`pragma protect data_block
/ou2Ru6CCw7FRn0kweqH/pEPPcDPkhbb+Oqj33kaevGxr1txeb9CSMBvw1nm/DIM
/P4fODSygenNbz2Z5cxBZdThLvz8V2Fws9sDkS0HRAInhGfnJhWNeGDZCznaxHPQ
KoPQiparVffMkPrxJ2664UevAp+jmOxNuatxwW2AFhPrq6jmWtumIDGSlObCBb9U
h+r1bxnX5tFur/8lcg1uOl3UeXIFWhD3s09z8RmOiWUvwR1Vuh0G7BE9q2K/lW2S
vdMyCNwcRCuDpc4DEOtGkw==

`pragma protect end_protected


endpackage

`endif

// $Revision: 1.214 $

